/*= Rohde & Schwarz ZVR - Vector Network Analyzer ===========================*/

/*===========================================================================*/
/*  Please do not use global variables or arrays in the include file of      */
/*  instrument drivers that will be submitted for inclusion into the         */
/*  LabWindows Instrument Driver Library.                                    */
/*===========================================================================*/
     
#ifndef __rszv_HEADER
#define __rszv_HEADER

#include <vpptype.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************/
/*= RSIB interface support ==================================================*/
/*                                                                           */
/* The RSIB interface is a R&S defined protocol for remote control of R&S    */
/* spectrum and network analyzers. In addition to the standard VISA          */
/* attributes, the RSIB passport supports the following manufacturer specific*/
/* attributes:                                                               */
/*                                                                           */
/*****************************************************************************/
#ifndef __RSVIRSIB_H__

#define RS_ATTR_RSIB_SRE     (0x3FFC0001UL)     /* Switch a device to local or remote */
#define RS_ATTR_RSIB_LOC     (0x3FFC0002UL)     /* Switch a device temporarily to local */
#define RS_ATTR_RSIB_VER     (0x3FFC0003UL)     /* Passport Release Version */

#endif /* __RSVIRSIB_H__ */

/*****************************************************************************/
/*= Define Instrument Specific Error/Warning Codes Here =====================*/
/*****************************************************************************/
#define VI_ERROR_INSTR_INTERPRETING_RESPONSE    (_VI_ERROR+0x3FFC0803L)

#define VI_ERROR_INSTR_PARAMETER9               (_VI_ERROR+0x3FFC0809L)
#define VI_ERROR_INSTR_PARAMETER10              (_VI_ERROR+0x3FFC080AL)
#define VI_ERROR_INSTR_PARAMETER11              (_VI_ERROR+0x3FFC080BL)
#define VI_ERROR_INSTR_PARAMETER12              (_VI_ERROR+0x3FFC080CL)
#define VI_ERROR_INSTR_PARAMETER13              (_VI_ERROR+0x3FFC080DL)
#define VI_ERROR_INSTR_PARAMETER14              (_VI_ERROR+0x3FFC080EL)
#define VI_ERROR_INSTR_PARAMETER15              (_VI_ERROR+0x3FFC080FL)

#define VI_INSTR_WARNING_OFFSET                           (0x3FFC0900L)
#define RSZV_WARN_TIME_SWEEP           (VI_INSTR_WARNING_OFFSET + 0x0L)

#define VI_INSTR_ERROR_OFFSET                   (_VI_ERROR+0x3FFC0900L)

#define RSZV_ERROR_NOT_DISPLAYED              (VI_INSTR_ERROR_OFFSET + 0x01L)
#define RSZV_ERROR_OPTION_NOT_AVAILABLE       (VI_INSTR_ERROR_OFFSET + 0x02L)
#define RSZV_ERROR_INSTRUMENT_ERROR           (VI_INSTR_ERROR_OFFSET + 0xF0L)

#define RSZV_VAL_INFINITE                      VI_TMO_INFINITE
#define RSZV_VAL_IMMEDIATE                     VI_TMO_IMMEDIATE
/*****************************************************************************/
/*= GLOBAL USER-CALLABLE FUNCTION DECLARATIONS (Exportable Functions) =======*/
/*****************************************************************************/

ViStatus _VI_FUNC rszv_init (ViRsrc resourceName,
                   ViBoolean IDQuery,
                   ViBoolean resetDevice,
                   ViPSession instrSession);

/*- Application Functions ---------------------------------------------------*/
ViStatus _VI_FUNC rszv_appExample (ViSession instrSession,
                   ViReal64 startFrequencyHz,
                   ViReal64 stopFrequencyHz,
                   ViBoolean format,
                   ViPInt32 count,
                   ViReal64 _VI_FAR data[]);

/*- Configuration Functions -------------------------------------------------*/
ViStatus _VI_FUNC rszv_confChannel (ViSession instrSession,
                   ViInt32 channel);

ViStatus _VI_FUNC rszv_confStimulusConf (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 stimulus,
                   ViReal64 parameter,
                   ViInt32 unit);

  /*- System Configuration --------------------------------------------------*/
    /*- Measure Mode --------------------------------------------------------*/
      /*- Time Domain -------------------------------------------------------*/
ViStatus _VI_FUNC rszv_confTimeDomain (ViSession instrSession,
                   ViInt32 channel,
                   ViBoolean domain,
                   ViBoolean timeGate);

ViStatus _VI_FUNC rszv_confTimeDomainGate (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 gateFunction,
                   ViReal64 sidelobeSuppressiondB);

ViStatus _VI_FUNC rszv_confTimeDomainGateStartStop (ViSession instrSession,
                   ViInt32 channel,
                   ViReal64 starts,
                   ViReal64 stops);

ViStatus _VI_FUNC rszv_confTimeDomainGateCenterSpan (ViSession instrSession,
                   ViInt32 channel,
                   ViReal64 centers,
                   ViReal64 spans);

ViStatus _VI_FUNC rszv_confTimeDomainTransform (ViSession instrSession,
                   ViInt32 channel,
                   ViBoolean method,
                   ViBoolean stimulus,
                   ViBoolean type,
                   ViInt32 lowpass,
                   ViReal64 lowpassDCSParam,
                   ViInt32 XAxis);

ViStatus _VI_FUNC rszv_confTimeDomainWindow (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 filterFunction,
                   ViReal64 sidelobe);
      /*- Compress COI TOI --------------------------------------------------*/
ViStatus _VI_FUNC rszv_confNonLinMeas (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 function);

ViStatus _VI_FUNC rszv_ConfigureCompressionPointMeas (ViSession instrSession,
	                 ViInt32 channel,
	                 ViReal64 maxLimit,
	                 ViReal64 minLimit,
	                 ViReal64 settlingTimes,
	                 ViBoolean compPoint,
	                 ViReal64 XDBCompPoint,
	                 ViInt32 source,
	                 ViBoolean check);

ViStatus _VI_FUNC rszv_ConfigureSOIMeasurement (ViSession instrSession,
                   ViInt32 channel,
                   ViReal64 maxLimit,
                   ViReal64 minLimit,
                   ViReal64 settlingTimes,
                   ViBoolean intcPoint,
                   ViReal64 freqOffset,
                   ViBoolean measFunc,
                   ViInt32 source,
                   ViBoolean check);

ViStatus _VI_FUNC rszv_ConfigureTOIMeasurement (ViSession instrSession,
                   ViInt32 channel,
                   ViReal64 maxLimit,
                   ViReal64 minLimit,
                   ViReal64 settlingTimes,
                   ViBoolean intcPoint,
                   ViReal64 freqOffset,
                   ViBoolean measSideb,
                   ViInt32 source,
                   ViBoolean check);
                   
    /*- Measure Mode --------------------------------------------------------*/
ViStatus _VI_FUNC rszv_ConfigureExternalSource (ViSession instrSession, 
                   ViBoolean source,
                   ViInt32 GPIBAddress,
                   ViBoolean link,
                   ViInt32 deviceType,
                   ViString userDefined,
                   ViBoolean state);
                   
ViStatus _VI_FUNC rszv_confMode (ViSession instrSession,
                   ViInt32 mode,
                   ViInt32 channel,
                   ViBoolean speed);

ViStatus _VI_FUNC rszv_confModeInput (ViSession instrSession,
                   ViInt32 input1,
                   ViInt32 input2);

ViStatus _VI_FUNC rszv_confMeasFreqConv (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 frequencyConvers);

ViStatus _VI_FUNC rszv_confDefMixerBaseFreq (ViSession instrSession,
				   ViInt32 channel,
                   ViInt32 fundamentalFreq,
                   ViBoolean localOscillator);

ViStatus _VI_FUNC rszv_confDefMixerFixedFreq (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 control,
                   ViReal64 fixedValueHz);

ViStatus _VI_FUNC rszv_confDefMixerBand (ViSession instrSession,
                   ViInt32 channel,
                   ViBoolean band);
                   
ViStatus _VI_FUNC rszv_confReferenceMixer (ViSession instrSession,
                  ViBoolean state);
                  
ViStatus _VI_FUNC rszv_confReferenceOsc (ViSession instrSession, 
                  ViBoolean source,
                  ViInt32 extFreq);

ViStatus _VI_FUNC rszv_confMeasDefArbit (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 systemFrequencies,
                   ViBoolean state,
                   ViInt32 numerator,
                   ViInt32 denominator,
                   ViReal64 offsetHz,
                   ViBoolean frequency);
                   
ViStatus _VI_FUNC rszv_confSweepType (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 sweepType);

    /*- Setup Configuration -------------------------------------------------*/
ViStatus _VI_FUNC rszv_confSetupTime (ViSession instrSession,
                   ViInt32 day,
                   ViInt32 month,
                   ViInt32 year,
                   ViInt32 hour,
                   ViInt32 minute,
                   ViInt32 second);

  /*- Copy Configuration ----------------------------------------------------*/
ViStatus _VI_FUNC rszv_confCopySetting (ViSession instrSession,
                   ViInt32 function,
                   ViInt32 window,
                   ViInt32 quadrant);

ViStatus _VI_FUNC rszv_confCopyComment (ViSession instrSession,
                   ViInt32 channel,
                   ViString comment);

ViStatus _VI_FUNC rszv_confDeviceSetting (ViSession instrSession,
                   ViBoolean device,
                   ViInt32 language,
                   ViInt32 connection,
                   ViString fileName,
                   ViInt32 GPIBAddress,
                   ViBoolean deviceReset,
                   ViBoolean formfeed,
                   ViBoolean paperfeed,
                   ViBoolean orientation);

ViStatus _VI_FUNC rszv_confHCDevice (ViSession instrSession,
                   ViInt32 deviceNumber,
                   ViInt32 dataFormat,
                   ViInt32 destination,
                   ViInt32 GPIBAddress,
                   ViBoolean preset,
                   ViBoolean formFeed,
                   ViBoolean paperFeed,
                   ViBoolean resolution,
                   ViBoolean pageOrientation);

ViStatus _VI_FUNC rszv_confColorSetting (ViSession instrSession,
                   ViBoolean color);

  /*- Sweep Configuration ---------------------------------------------------*/
ViStatus _VI_FUNC rszv_confSweepCoupling (ViSession instrSession,
                   ViBoolean coupledChannels);

ViStatus _VI_FUNC rszv_confSweepMode (ViSession instrSession,
				   ViInt32 channel,
				   ViInt32 sweep);

ViStatus _VI_FUNC rszv_confSweepTime (ViSession instrSession,
                   ViInt32 channel,
                   ViBoolean sweepTime,
                   ViReal64 editSweepTimes);

ViStatus _VI_FUNC rszv_confSweepNumber (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 numberofSweeps,
                   ViBoolean continuousSweep);

ViStatus _VI_FUNC rszv_confSweepDirection (ViSession instrSession,
				   ViInt32 channel,
                   ViBoolean sweepDirection);

ViStatus _VI_FUNC rszv_confSweepSegment (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 function,
                   ViInt32 index,
                   ViReal64 startHz,
                   ViReal64 stopHz,
                   ViInt32 points,
                   ViReal64 sourcePowerdBm,
                   ViBoolean sweepTime,
                   ViReal64 sweepTimes,
                   ViInt32 averageFactor,
                   ViInt32 IFBandwidth,
                   ViBoolean LOtoRF);

ViStatus _VI_FUNC rszv_confSweepNumberPoints (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 arbitraryPoints);

ViStatus _VI_FUNC rszv_confStepSizeLinLog (ViSession instrSession,
                   ViInt32 channel,
                   ViBoolean stepSizeType,
				   ViReal64 stepSizeHz,
				   ViReal64 pointsperDec);

ViStatus _VI_FUNC rszv_confSweepTrigger (ViSession instrSession,
                   ViInt32 defineTrigger,
                   ViReal64 triggerDelays,
                   ViBoolean trigger,
                   ViBoolean slope,
                   ViReal64 timerPeriods,
                   ViInt32 hours,
                   ViInt32 minutes,
                   ViInt32 seconds);
                   
ViStatus _VI_FUNC rszv_confSweepSource (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 source,
                   ViReal64 parameter,
                   ViInt32 unit);

ViStatus _VI_FUNC rszv_confSweepSourcePower (ViSession instrSession,
                   ViInt32 port1,
                   ViInt32 port2);

ViStatus _VI_FUNC rszv_confSweepAvg (ViSession instrSession,
                   ViInt32 channel,
                   ViBoolean average,
                   ViInt32 avgFactor,
                   ViBoolean avgType);
                   
ViStatus _VI_FUNC rszv_confSweepBandwidth (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 IFBandwidth);

  /*- Response Configuration ------------------------------------------------*/
    /*- Meas Configuration --------------------------------------------------*/
ViStatus _VI_FUNC rszv_confResMeas (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 meas,
                   ViInt32 complexConvers);

ViStatus _VI_FUNC rszv_confResMeasInput (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 input,
                   ViBoolean drivePort,
                   ViInt32 unit);

ViStatus _VI_FUNC rszv_confResMeasRatio (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 ratio,
                   ViBoolean drivePort,
                   ViInt32 numerator,
                   ViInt32 denominator);
  /*- Response Configuration ------------------------------------------------*/
ViStatus _VI_FUNC rszv_confResFormat (ViSession instrSession,
				   ViInt32 channel,
				   ViInt32 format);

ViStatus _VI_FUNC rszv_confResFormatGDelay (ViSession instrSession,
                   ViInt32 channel,
                   ViBoolean apertureMode,
                   ViInt32 stepAperture,
                   ViReal64 frequencyApertureHz);

ViStatus _VI_FUNC rszv_confResScale (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 function,
                   ViReal64 parameter,
                   ViInt32 unit);

ViStatus _VI_FUNC rszv_confDiagram (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 diagramType);
                   
ViStatus _VI_FUNC rszv_confDisplay (ViSession instrSession,
                   ViInt32 displayType,
                   ViBoolean expand);

ViStatus _VI_FUNC rszv_confTraceOperations (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 function,
                   ViInt32 selectDefaults);

ViStatus _VI_FUNC rszv_confTraceSmoothing (ViSession instrSession,
                   ViInt32 channel,
                   ViBoolean smoothing,
                   ViReal64 smoothingAperture);

ViStatus _VI_FUNC rszv_confDefineMath (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 operand1,
                   ViInt32 operator1,
                   ViInt32 operand2,
                   ViInt32 operator2,
                   ViInt32 operand3);
  /*- Marker Configuration --------------------------------------------------*/
    /*- Normal Configuration ------------------------------------------------*/
ViStatus _VI_FUNC rszv_confMarker (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 marker,
                   ViReal64 position,
                   ViInt32 unit,
                   ViBoolean state,
                   ViBoolean trace);

ViStatus _VI_FUNC rszv_confMarkerMode (ViSession instrSession,
                   ViInt32 channel,
                   ViBoolean coupled,
                   ViBoolean markerMode);

ViStatus _VI_FUNC rszv_confMarkerConvers (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 conversion);

ViStatus _VI_FUNC rszv_confMarkerFormat (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 format);

  /*- Marker Configuration --------------------------------------------------*/
ViStatus _VI_FUNC rszv_confMarkerSearch (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 searchMode,
                   ViReal64 target,
                   ViInt32 targetUnit,
                   ViBoolean filterType,
                   ViInt32 filterFunction,
                   ViReal64 widthdB,
                   ViBoolean tracking);

ViStatus _VI_FUNC rszv_confMarkerDelta (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 referenceMarker,
                   ViBoolean peaktoPeak,
                   ViBoolean deltaState,
                   ViReal64 fixedPosStimulus,
                   ViReal64 fixedPosXVal,
                   ViReal64 fixedPosYVal,
                   ViInt32 stimulusUnit);

ViStatus _VI_FUNC rszv_confCalStandard (ViSession instrSession,
					ViInt32 selectKit, ViInt32 standard,
					ViString kit, ViString serialNumber,
					ViReal64 minFreq, ViReal64 maxFreq,
					ViReal64 lengthmm, ViReal64 loss,
					ViReal64 c0L0, ViReal64 c1L1,
					ViReal64 c2L2, ViReal64 c3L3,
					ViInt32 approximation);

ViStatus _VI_FUNC rszv_confMarkerEqlMkr (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 selectedMarker,
                   ViInt32 markerEqual);                    

  /*- Cal Configuration -----------------------------------------------------*/
ViStatus _VI_FUNC rszv_confCalConfig (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 function,
                   ViBoolean state);

ViStatus _VI_FUNC rszv_confCalKit (ViSession instrSession,
                   ViInt32 selectKit,
                   ViInt32 standard,
                   ViString label);

ViStatus _VI_FUNC rszv_confCalSensorCalFactor (ViSession instrSession,
                   ViBoolean useSensor,
                   ViInt32 number,
                   ViReal64 _VI_FAR frequencyHz[],
                   ViReal64 _VI_FAR calFactor[]);

ViStatus _VI_FUNC rszv_confCalPowMtrConfig (ViSession instrSession,
                   ViInt32 IECAddress,
                   ViInt32 type,
                   ViBoolean autoZero,
                   ViString userDefined);

ViStatus _VI_FUNC rszv_confCalPowerLoss (ViSession instrSession,
                   ViInt32 numberofpairs,
                   ViReal64 _VI_FAR frequencyHz[],
				   ViReal64 _VI_FAR attenuationdB[],
				   ViBoolean state);

ViStatus _VI_FUNC rszv_confCalOffsetConf (ViSession instrSession,
                   ViBoolean port,
                   ViReal64 magnitudedB,
                   ViReal64 phaseDeg,
                   ViReal64 setDielectric,
                   ViReal64 delayTimes,
                   ViReal64 lengthmm,
                   ViInt32 delay);

ViStatus _VI_FUNC rszv_confCalPortType (ViSession instrSession,
                   ViInt32 port1Connector,
                   ViInt32 port2Connector);
  /*- Memory Configuration --------------------------------------------------*/
ViStatus _VI_FUNC rszv_confMemoryItem (ViSession instrSession,
                   ViInt32 items,
                   ViBoolean generalSetup,
                   ViBoolean colorSetup,
                   ViBoolean HWSettings,
                   ViBoolean hardcopy,
                   ViBoolean calData,
                   ViBoolean calKitData,
                   ViBoolean macros,
                   ViBoolean lines,
                   ViBoolean ASCIIData);
                   
ViStatus _VI_FUNC rszv_confMemoryTraces (ViSession instrSession,
                   ViInt32 memoryTrace,
                   ViBoolean state);

  /*- Lines Configuration ---------------------------------------------------*/
ViStatus _VI_FUNC rszv_confStateLimit (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 line,
                   ViBoolean state);

ViStatus _VI_FUNC rszv_confLimitLinesCartesian (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 line,
                   ViInt32 noofSections,
                   ViReal64 _VI_FAR start[],
                   ViReal64 _VI_FAR stop[],
                   ViReal64 _VI_FAR startUpperLim[],
                   ViReal64 _VI_FAR startLowerLim[],
                   ViReal64 _VI_FAR stopUpperLim[],
                   ViReal64 _VI_FAR stopLowerLim[],
                   ViInt32 complexConvers,
                   ViInt32 format,
                   ViInt32 sweep,
                   ViInt32 XSpacing,
                   ViInt32 YSpacing);

ViStatus _VI_FUNC rszv_confLimitLinesPolar (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 line,
                   ViReal64 radius,
                   ViInt32 complexConvers,
                   ViInt32 sweep,
                   ViInt32 XSpacing,
                   ViInt32 YSpacing);

ViStatus _VI_FUNC rszv_confLimitLinesSmith (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 line,
                   ViReal64 radius,
                   ViReal64 XPosition,
                   ViReal64 YPosition,
                   ViInt32 complexConvers,
                   ViInt32 sweep,
                   ViInt32 XSpacing);

/*- Action/Status Functions -------------------------------------------------*/
ViStatus _VI_FUNC rszv_actCopyFile (ViSession instrSession,
                   ViBoolean function,
                   ViString sourceFile,
                   ViString destinationFile);

ViStatus _VI_FUNC rszv_actDeleteFile (ViSession instrSession,
                   ViBoolean deleteSource,
                   ViString fileorDirectory);

ViStatus _VI_FUNC rszv_actMakeDir (ViSession instrSession,
                   ViString directoryName);
                   
ViStatus _VI_FUNC rszv_actFormatDisk (ViSession instrSession);

ViStatus _VI_FUNC rszv_actTrigger (ViSession instrSession);

ViStatus _VI_FUNC rszv_actMarkersOff (ViSession instrSession,
                   ViInt32 channel);

ViStatus _VI_FUNC rszv_actMarkerSearch (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 marker,
                   ViInt32 function,
                   ViPReal64 XValue,
                   ViPReal64 YValue);

ViStatus _VI_FUNC rszv_actAutoscale (ViSession instrSession,
                   ViInt32 channel);

    /*- Sweep ---------------------------------------------------------------*/
ViStatus _VI_FUNC rszv_actSweepStart (ViSession instrSession);

ViStatus _VI_FUNC rszv_actSweAvgReset (ViSession instrumentHandle, ViInt32 channel);

    /*- Calibration ---------------------------------------------------------*/
ViStatus _VI_FUNC rszv_actCalInstallKit (ViSession instrSession,
                                         ViString sourceFile);

ViStatus _VI_FUNC rszv_actCalOffsetAutoLength (ViSession instrSession,
                   ViBoolean port);

      /*- Full Two Port -----------------------------------------------------*/
ViStatus _VI_FUNC rszv_actCalFTPMethod (ViSession instrSession, 
                   ViInt32 channel,
                   ViInt32 method);

ViStatus _VI_FUNC rszv_actCalFTPMeas (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 calMeas);

      /*- Full One Port -----------------------------------------------------*/
ViStatus _VI_FUNC rszv_actCalFOPMethod (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 fullOnePort);

ViStatus _VI_FUNC rszv_actCalFOPMeas (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 calMeas);

      /*- One Path Two Port -------------------------------------------------*/
ViStatus _VI_FUNC rszv_actCalOPTPMethod (ViSession instrSession,
                   ViInt32 channel,
                   ViBoolean onePathTwoPort);

ViStatus _VI_FUNC rszv_actCalOPTPMeas (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 calMeas);

      /*- Trans Norm --------------------------------------------------------*/
ViStatus _VI_FUNC rszv_actCalTNMethod (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 transNorm);

ViStatus _VI_FUNC rszv_actCalTNMeas (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 calMeas);

      /*- Refl Norm ---------------------------------------------------------*/
ViStatus _VI_FUNC rszv_actCalRNMethod (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 reflNorm);

ViStatus _VI_FUNC rszv_actCalRNMeas (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 calMeas);

	  /*- Trans and Refl Norm -----------------------------------------------*/
ViStatus _VI_FUNC rszv_actCalTRNMethod (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 transandReflNorm);

ViStatus _VI_FUNC rszv_actCalTRNMeas (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 calMeas);

ViStatus _VI_FUNC rszv_actCalPowerCal (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 numberofReading,
                   ViInt32 powerCal,
                   ViReal64 valuedBm);
  
  /*- Copy ------------------------------------------------------------------*/
ViStatus _VI_FUNC rszv_actCopyStart (ViSession instrSession,
                   ViBoolean device);

/*- Data Functions ----------------------------------------------------------*/
ViStatus _VI_FUNC rszv_dataMemoryData (ViSession instrSession,
                   ViInt32 function,
                   ViString path,
                   ViString filename,
                   ViString comment,
                   ViInt32 formatoftheFile,
                   ViInt32 formatforData,
                   ViBoolean mode,
                   ViBoolean separator,
                   ViInt32 source);

ViStatus _VI_FUNC rszv_dataReadTrace (ViSession instrSession,
                   ViBoolean size,
                   ViBoolean typeData,
                   ViInt32 dataSource,
                   ViInt32 dataFrom,
                   ViPInt32 count,
                   ViReal64 _VI_FAR data[]);

ViStatus _VI_FUNC rszv_dataMarkerData (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 marker,
                   ViPReal64 XValue,
                   ViPReal64 realValue,
                   ViPReal64 imaginaryValue);

ViStatus _VI_FUNC rszv_dataPtP (ViSession instrSession,
                   ViInt32 channel,
                   ViPReal64 peaktoPeak,
                   ViPReal64 average,
                   ViPReal64 minimum,
                   ViPReal64 maximum,
                   ViPReal64 standardDeviation);
                   
ViStatus _VI_FUNC rszv_dataSegmentCount (ViSession instrSession,
                   ViInt32 channel,
                   ViPInt32 count);

ViStatus _VI_FUNC rszv_dataLimitFail (ViSession instrSession,
                   ViInt32 channel,
                   ViPInt32 fail);

/*- Utility Functions -------------------------------------------------------*/
ViStatus _VI_FUNC rszv_WaitForOPC (ViSession instrSession);

ViStatus _VI_FUNC rszv_setCheckStatus (ViSession instrSession,
				   ViBoolean checkStatus);

ViStatus _VI_FUNC rszv_setTimeout (ViSession instrSession,
                   ViUInt32 maxTimeout);

ViStatus _VI_FUNC rszv_writeInstrData (ViSession instrSession,
                   ViString writeBuffer);

ViStatus _VI_FUNC rszv_readInstrData (ViSession instrSession,
                   ViInt32 numberBytesToRead,
                   ViChar _VI_FAR readBuffer[],
                   ViPInt32 numBytesRead);

ViStatus _VI_FUNC rszv_reset (ViSession instrSession);

ViStatus _VI_FUNC rszv_self_test (ViSession instrSession,
                   ViPInt16 selfTestResult,
                   ViChar _VI_FAR selfTestMessage[]);

ViStatus _VI_FUNC rszv_error_query (ViSession instrSession,
                   ViPInt32 errorCode,
                   ViChar _VI_FAR errorMessage[]);

ViStatus _VI_FUNC rszv_error_message (ViSession instrSession,
                   ViStatus statusCode,
                   ViChar _VI_FAR message[]);

ViStatus _VI_FUNC rszv_revision_query (ViSession instrSession,
                   ViChar _VI_FAR instrumentDriverRevision[],
                   ViChar _VI_FAR firmwareRevision[]);

ViStatus _VI_FUNC rszv_close (ViSession instrSession);


/*- Obsolete Functions ------------------------------------------------------*/
/*- These functions have been deprecated and may not
     be supported in future versions of this driver. ------------------------*/
ViStatus _VI_FUNC rszv_confExterSource (ViSession instrSession,
                   ViBoolean source,
                   ViInt32 GPIBAddress,
                   ViBoolean link,
                   ViInt32 deviceType,
                   ViString userDefined);
/* Use rszv_ConfigureExternalSource instead of rszv_confExterSource */

ViStatus _VI_FUNC rszv_confDefCompMeas (ViSession instrSession,
                   ViInt32 channel,
                   ViReal64 powerMaxLimitdBm,
                   ViReal64 powerMinLimitdBm,
                   ViReal64 settlingTimes,
                   ViBoolean compPoint,
                   ViReal64 XDBCompPoint,
                   ViInt32 source);
/* Use rszv_ConfigureCompressionPointMeas instead of rszv_confDefCompMeas */

ViStatus _VI_FUNC rszv_confDefSoiMeas (ViSession instrSession,
                   ViInt32 channel,
                   ViReal64 powerMaxLimitdBm,
                   ViReal64 powerMinLimitdBm,
                   ViReal64 settlingTimes,
                   ViBoolean intcPoint,
                   ViReal64 freqOffsetof2source,
                   ViBoolean measFunc,
                   ViInt32 source);
/* Use rszv_ConfigureSOIMeasurement instead of rszv_confDefSoiMeas */

ViStatus _VI_FUNC rszv_confDefToiMeas (ViSession instrSession,
                   ViInt32 channel,
                   ViReal64 powerMaxLimitdBm,
                   ViReal64 powerMinLimitdBm,
                   ViReal64 settlingTimes,
                   ViBoolean intcPoint,
                   ViReal64 freqOffsetof2source,
                   ViBoolean measSideb,
                   ViInt32 source);
/* Use rszv_ConfigureTOIMeasurement instead of rszv_confDefToiMeas */


#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif

/*****************************************************************************/
/*=== END INCLUDE FILE ======================================================*/
/*****************************************************************************/

#endif
