/*=Rohde&Schwarz ZV Series Network Vector Analyzers (ZVC,ZVCE,ZVR,ZVRE,ZVRL)=*/
/* LabWindows/CVI 4.0.1 Instrument Driver                                    */
/* Original Release:                                                         */
/* By: Zdenek Rykala, ELCOM a.s., DVI, Czech Republic                        */
/*                                                                           */
/* Should you have any technical questions please contact the hotline of     */
/* Rohde & Schwarz Vertriebs-GmbH Rohde & Schwarz Support Center             */
/*                                                                           */
/* e-mail: CustomerSupport@rsd.rohde-schwarz.com                             */
/*                                                                           */
/*                                                                           */
/* Modification History:                                                     */
/*                                                                           */
/*  Rev 4.3.4  06/2003  CVI 6.0 by Martin Koutny                             */
/*      - source code verification, bug fixing                               */
/*                                                                           */
/*  Rev 4.3.3  04/2003  CVI 6.0 by Martin Koutny                             */
/*      - documentation improvements                                         */
/*                                                                           */
/*  Rev 4.3.2  02/2003  CVI 6.0 by Werner Klotzsche                          */
/*      - For Agilent VISA Version L01 or higer and Agilent GPIB board       */
/*          added "\n" in I/O functions                                      */
/*                                                                           */
/*  Rev 4.3.1, 02/2003, CVI 6.0 by JK                                        */
/*      - Fixed for use in earlier versions of VISA without TCPIP support    */
/*                                                                           */
/*  Rev 4.3, 12/2002, CVI 6.0 by Martin Koutny                               */
/*      - Included support for RSIB interface                                */
/*      - LabWindows/CVI library <formatio.h> is replaced by its ANSI_C      */
/*        equivalent                                                         */
/*      - Multiplatform support for binary transfers is included             */
/*      - Code cleanup & code verification                                   */
/*                                                                           */
/*  Rev 4.22, 12/2001, CVI 6.0                                               */
/*                  Fixed rszv_ConfigureExternalSource function              */
/*                  Modified by Zdenek Rykala                                */
/*                                                                           */
/*  Rev 4.21, 11/2001, CVI 6.0                                               */
/*                  Added null termination for read buffers in following     */
/*                  functions:                                               */
/*                    rszv_confChannel                                       */
/*                    rszv_confDisplay                                       */
/*                    rszv_confMarkerDelta                                   */
/*                    rszv_actMarkerSearch                                   */
/*                    rszv_dataMarkerData                                    */
/*                    rszv_dataPtP                                           */
/*                    rszv_dataSegmentCount                                  */
/*                    rszv_dataLimitFail                                     */
/*                    rszv_confSweepType                                     */
/*                    rszv_self_test                                         */
/*                    rszv_defaultInstrSetup                                 */
/*                    rszv_sysStatus                                         */
/*                    rszv_isChannelDisplayed                                */
/*                    rszv_getSweepMode                                      */
/*                  Modified by Zdenek Rykala                                */
/*                                                                           */
/*  Rev 4.2, 11/2001, CVI 6.0                                                */
/*                  The word 'delete' changed to 'deleteSource'              */
/*                  New functions:                                           */
/*                    rszv_ConfigureExternalSource                           */
/*                    rszv_ConfigureCompressionPointMeas                     */
/*                    rszv_ConfigureSOIMeasurement                           */
/*                    rszv_ConfigureTOIMeasurement                           */
/*                    rszv_confHCDevice                                      */
/*                    rszv_confReferenceOsc                                  */
/*                    rszv_confReferenceMixer                                */
/*                  Modified functions:                                      */
/*                    rszv_confResMeas - added new values for parameter meas */
/*                                                                           */
/*  Rev 4.1, 12/2000, CVI 5.5                                                */
/*                  Fixed parameter checking for ZVx models in following     */
/*                  functions:                                               */
/*                    rszv_confCalPort                                       */
/*                    rszv_confCalKit                                        */
/*                    rszv_confCalStandard                                   */
/*                  Modified by Zdenek Rykala                                */
/*                                                                           */
/*  Rev 4.0, 10/2000, CVI 5.0.1                                              */
/*                  Added support for ZVK.                                   */
/*                  Modified by Zdenek Rykala                                */
/*                                                                           */
/*  Rev 3.2, 03/2000, CVI 5.0.1                                              */
/*                  Added support for ZVM.                                   */
/*                  - Functions rsvz_confMode and rszv_confSweepSource       */
/*                    was modified.                                          */
/*                  - Added some new functions: rszv_confModeInputs,         */
/*                                              rszv_confSweepSourcePower    */
/*                                                                           */
/*                  Added two a new functions: rszv_actCalInstallKit         */
/*                                             rszv_confCalStandard          */
/*                  Added RS-232 support                                     */
/*                                                                           */
/*                  Modified by Zdenek Rykala                                */
/*                                                                           */
/*                                                                           */
/*  Rev 3.1, 01/2000, CVI 5.0.1:                                             */
/*                  Changed data from ViChar[] to ViString for input         */
/*                  parameters.                                              */
/*                  Added channel paremeter in function rszv_actSweAvgReset  */
/*                  Fixed function rszv_confTraceOperations                  */
/*                  Modified by Zdenek Rykala                                */
/*                                                                           */
/*  Rev 3.0, 08/1999, CVI 5.0.1:                                             */
/*                  Changed data type from ViInt16 to ViInt32                */
/*                  Changed range for parameters channel, marker, ...        */
/*                  old ranges 0..3, 0..7, new ranges 1..4, 1..8             */
/*                  Calibration funtions was split up in:                    */
/*                  Old funtions:                                            */
/*                       rszv_actCalFullTwoPort                              */
/*                       rszv_actCalFullOnePort                              */
/*                       rszv_actCalOnePathTwoPort                           */
/*                       rszv_actCalTransNorm                                */
/*                       rszv_actCalReflNorm                                 */
/*                       rszv_actCalTransReflNorm                            */
/*                  New functions:                                           */
/*                       rszv_actCalPortType                                 */
/*                       rszv_actCalFTPMethod                                */
/*                       rszv_actCalFTPMeas                                  */
/*                       rszv_actCalFOPMethod                                */
/*                       rszv_actCalFOPMeas                                  */
/*                       rszv_actCalOPTPMethod                               */
/*                       rszv_actCalOPTPMeas                                 */
/*                       rszv_actCalTNMethod                                 */
/*                       rszv_actCalTNMeas                                   */
/*                       rszv_actCalRNMethod                                 */
/*                       rszv_actCalRNMeas                                   */
/*                       rszv_actCalTRNMethod                                */
/*                       rszv_actCalTRNMeas                                  */
/*                  Function rszv_confSweepAvg was split into one for setting*/
/*                  average parameters and one for the IF bandwidth:         */
/*                       rszv_confSweepAvg                                   */
/*                       rszv_confSweepBandwidth                             */
/*                  Function rszv_confSweep was split:                       */
/*                       rszv_confSweepCoupling                              */
/*                       rszv_confSweepMode                                  */
/*                       rszv_confSweepTime                                  */
/*                       rszv_confSweepNumber                                */
/*                       rszv_confSweepDirection                             */
/*                  Function rszv_confSweepNumberPoints was split up in:     */
/*                       rszv_confSweepNumberPoints                          */
/*                       rszv_confSweepLinLogSweep                           */
/*                  Function rszv_confResFormat was split up in:             */
/*                       rszv_confResFormat                                  */
/*                       rszv_confResFormatGDelay                            */
/*                  Function rszv_confTrace was split up in:                 */
/*                       rszv_confTraceOperations                            */
/*                       rszv_confSmoothing                                  */
/*                       rszv_confDefineMath                                 */
/*                  Function rszv_confMarker was split up in:                */
/*                       rszv_confMarker                                     */
/*                       rszv_confMarkerMode                                 */
/*                  Function rszv_confCalOffsetConf was split up in:         */
/*                       rszv_confCalOffsetConf                              */
/*                       rszv_actCalOffsetAutoLength                         */
/*                  Added new functions:                                     */
/*                       rszv_confTimeDomain                                 */
/*                       rszv_confTimeDomainGate                             */
/*                       rszv_confTimeDomainGateStartStop                    */
/*                       rszv_confTimeDomainGateCenterSpan                   */
/*                       rszv_confTimeDomainTransform                        */
/*                       rszv_confTimeDomainWindow                           */
/*                       rszv_confNonLinMeas                                 */
/*                       rszv_confDefCompMeas                                */
/*                       rszv_confDefSoiMeas                                 */
/*                       rszv_confDefToiMeas                                 */
/*                       rzsv_confCalPowerLoss                               */
/*                  Removed following functions:                             */
/*                       rszv_operationComplete                              */
/*                       rszv_actCopyAbort                                   */
/*                  Add new function for limit checking:                     */
/*                       rszv_confStateLimit                                 */
/*                       rszv_confLimitLinesCartesian                        */
/*                       rszv_confLimitLinesPolar                            */
/*                       rszv_confLimitLinesSmith                            */
/*                       rszv_dataLimitFail                                  */
/*                                                                           */
/*                  Renamed function from rszv_dataFromInstr to              */
/*                  rszv_dataReadTrace and added control for the source of   */
/*                  the data.                                                */
/*                  Driver is based on firmware revision 1.61                */
/*                  Driver has function for enables/disables status checking */
/*                  and function for set timeout value                       */
/*                  Driver checking displayed channels.                      */
/*                                                                           */
/*                  Modified by Zdenek Rykala                                */
/*                                                                           */
/*                                                                           */
/*  Rev 2.1, 03/1999, CVI 5.0.1:                                             */
/*                  Removed bug in Default Instrument Setup                  */
/*                  Modified by Zdenek Rykala                                */
/*                                                                           */
/*  Rev 2.0, 03/1999, CVI 5.0.1                                              */
/*                  Changed the instrument driver Prefix and filenames from  */
/*                  RSZVR* to RSZV* and added support for the instrument     */
/*                  models ZVC, and ZVCE.                                    */
/*                  Modified by Zdenek Rykala                                */
/*                                                                           */
/*===========================================================================*/
#include <visa.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include "rszv.h"

#define RSZV_REVISION      "Rev 4.3.4, 06/2003, CVI 6.0" /* Instrument driver revision */
#define BUFFER_SIZE         512L                       /* File I/O buffer size */
#define DATA_BUFFER         32050L                     /* Data buffer size */
#define LIMIT_BUFFER_SIZE   2048

/*****************************************************************************/
/*= DRIVER-DEPENDENT MACROS =================================================*/
/*****************************************************************************/
#define CHECKERR( fCal) if (rszv_status = (fCal), rszv_status < VI_SUCCESS) \
                            return rszv_status; else

#define CHECKERRCU(fCal) if (rszv_status = (fCal), rszv_status < VI_SUCCESS) \
                            return rszv_initCleanUp (rmSession, instrSession, rszv_status); else

#define ZVRL             0
#define ZVRE             1
#define ZVCE             2
#define ZVR              3
#define ZVC              4
#define ZVM              5
#define ZVK              6

#define RSZV_FREQ_SWEEP   0
#define RSZV_POWER_SWEEP  1
#define RSZV_TIME_SWEEP   2

#define isZVCx( fCal) ((fCal) == ZVC || (fCal) == ZVCE)
#define isZVRL( fCal) ((fCal) == ZVRL)
#define isZVM( fCal)  ((fCal) == ZVM)
#define isZVK( fCal)  ((fCal) == ZVK)
#define isZVMK( fCal) (((fCal) == ZVK) || ((fCal) == ZVM))

#define isZVR_B25( options) \
    (options & (1 << 14))
#define isZVR_B10( options) \
    (options & (1 << 16))
#define isZVR_B21( options) \
    (options & (1 << 10))
#define isZVR_B22( options) \
    (options & (1 << 11))
#define isZVR_B23( options) \
    (options & (1 << 12))
#define isZVR_B24( options) \
    (options & (1 << 13))
#define isZVR_B6( options) \
    (options & (1 << 2))


#define MAX_POINT           4002

/*****************************************************************************/
/*= INSTRUMENT-DEPENDENT COMMAND ARRAYS =====================================*/
/*****************************************************************************/
static ViString optionsArr[] = {"ZVR-B1", "ZVR-B4", "ZVR-B6", "ZVR-B7", "ZVR-B8",
                                "ZVR-K9", "ZVR-B14", "ZVR-B15", "ZVR-B16", "ZVR-B17",
                                "ZVR-B21", "ZVR-B22", "ZVR-B23", "ZVR-B24", "ZVR-B25",
                                "ZVR-B2", "ZVR-B10", VI_NULL};
static ViString instTypeArr[] = {"ZVRL", "ZVRE", "ZVCE", "ZVR", "ZVC", "ZVM", "ZVK", VI_NULL};
static ViString confStates[] = {"OFF","ON"};
static ViString confUnitArr[] = {"Hz","kHz","MHz","GHz","dBm","dB","dB/GHz"};
static ViString confTDGate[] = {"RECT", "HAMM", "HANN", "BOHM", "DCH"};
static ViString confTDLowpass[] = {"KFST","KDFR","MINS"};
static ViString confTDMethod[] = {"CHIR", "FFT"};
static ViString confTDStimulus[] = {"STEP","IMP"};
static ViString confTDType[] = {"LPAS","BPAS"};
static ViString confTDXaxis[] = {"TIME","DIST", "HDIS"};
static ViString confNLM[] = {"COMP","SOI","TOI","OFF"};
static ViString confEGenType[] = {"HP8340A","SME02","SME03","SME06","SMG",
                                  "SMGL","SMGU","SMH","SMHU","SMP02","SMP03",
                                  "SMP04","SMP22","SMT02","SMT03","SMT06"};
static ViString confEGenLink[] = {"TTL","GPIB"};
static ViString confExtSourceState[] = {"REM","LOC"};
static ViString confSOIMF[] = {"DIFF","SUM"};
static ViString confSOISource[] = {"IESRC1","IESRC2","ESRC12"};
static ViString confTOISID[] = {"USB","LSB"};
static ViString confMeasMode[] = {"INT","BYP","FPOR"};
static ViString confMeasSpeed[] = {"NORM","FAST"};
static ViString confSourcePower[] = {"NORM","HIGH"};
static ViString confCompPoint[] = {"OUTP","INP"};
static ViString confGenSource[] = {"INT","ESRC1","ESRC2"};
static ViString confMeasSysFreq[] = {"FREQ:CONV:ARB","FREQ:CONV:ARB:IFR",
                                     "EFR1","EFR2"};
static ViString confMeasArbitFreq[] = {"SWE", "CW"};
static ViString confMeasFrCoArr[] = {"FUND","SHAR","THAR","MIX","ARB"};
static ViString confMeasMixFund[] = {"RF","LO","IF"};
static ViString confMeasMixLoex[] = {"SOURCE1","SOURCE2"};
static ViString confSweepType[] = {"XFR","XTIM","XPOW"};
static ViString confMeasMixCont[] = {"RFF","LOF","IFF"};
static ViString confMeasMixTfr[] = {"BAND1","BAND2"};
static ViString confStimArr[] = {"STAR","STOP","CENT","SPAN"};
static ViString confCopyQuad[] = {"FULL","QUAD2","QUAD3","QUAD1","QUAD4"};
static ViString confCopyLang[] = {"HPGL","PCL4","PCL4_C","PCL4_C3","PCL5",
                                  "LAS","DESKJ","DESKJ_C","DESKJ_C3","POST",
                                  "EPSON24","EPSON24C","WMF","PCX"};
static ViString confDataFormatArr[] = {"HPGL","HPGL_LS","HP7470","HP7470LS","DESKJ","DESKJ_C",
                                   "DESKJ_C3","EPSON24","EPSON24C","PCL4","PCL4_C",
                                   "PCL4_C3","PCL5","LASERJ","POST","ESCP","WMF","PCX"};
static ViString confCopyOri[] = {"PORT","LAND"};
static ViString confCopyRes[] = {"150","300"};
static ViString confCopyDes[] = {"SYST:COMM:SER1","SYST:COMM:SER2",
                                 "SYST:COMM:CENT","SYST:COMM:GPIB","MMEM"};
static ViString confSweDir[] = {"UP","DOWN"};                               
static ViString confSweCoup[] = {"NONE","ALL"};
static ViString confSweSegLR[] = {"NEG","POS"};
static ViString confSweSource[] ={"POW","POW:SLOP","POW:CAMP:A1","POW:CAMP:A2",
                                  "FREQ","POW:EXT1","POW:EXT1:SLOP",
                                  "POW:CAMP:ESRC1","POW:EXT2","POW:EXT2:SLOP",
                                  "POW:CAMP:ESRC2","OUTP1:ATT","INP1:ATT",
                                  "INP2:ATT","OUTP2:ATT"};
static ViString confSweSegIFB[] = {"1Hz","3Hz","10Hz","30Hz","100Hz","300Hz",
                                   "1kHz","3kHz","10kHz","MAX"};
static ViString confSweAveType[] = {"SWE","POIN"};
static ViString confSweTrigLink[] = {"SWEEP","POINT"};
static ViString confMeasSFRE[] = {"XFR:POW:S11","XFR:POW:S21","XFR:POW:S12",
                                  "XFR:POW:S22","XFR:POW:KFAC","XFR:POW:MUF1","XFR:POW:MUF2",
                                  "XFR:POW:Y11","XFR:POW:Y21","XFR:POW:Y12","XFR:POW:Y22",
                                  "XFR:POW:Z11","XFR:POW:Z21","XFR:POW:Z12","XFR:POW:Z22",
                                  "XFR:POW:YREL11","XFR:POW:YREL21","XFR:POW:YREL12","XFR:POW:YREL22",
                                  "XFR:POW:ZREL11","XFR:POW:ZREL21","XFR:POW:ZREL12","XFR:POW:ZREL22",
                                  "XFR:VOLT:DCIN1","XFR:VOLT:DCIN2","XFR:POW:EFF"};
static ViString confMeasSPOW[] = {"XPOW:POW:S11","XPOW:POW:S21","XPOW:POW:S12",
                                  "XPOW:POW:S22","XPOW:POW:KFAC","XPOW:POW:MUF1","XPOW:POW:MUF2",
                                  "XPOW:POW:Y11","XPOW:POW:Y21","XPOW:POW:Y12","XPOW:POW:Y22",
                                  "XPOW:POW:Z11","XPOW:POW:Z21","XPOW:POW:Z12","XPOW:POW:Z22",
                                  "XPOW:POW:YREL11","XPOW:POW:YREL21","XPOW:POW:YREL12","XPOW:POW:YREL22",
                                  "XPOW:POW:ZREL11","XPOW:POW:ZREL21","XPOW:POW:ZREL12","XPOW:POW:ZREL22",
                                  "XPOW:VOLT:DCIN1","XPOW:VOLT:DCIN2","XPOW:POW:EFF"};
static ViString confMeasSTIM[] = {"XTIM:POW:S11","XTIM:POW:S21","XTIM:POW:S12",
                                  "XTIM:POW:S22","XTIM:POW:KFAC","XTIM:POW:MUF1","XTIM:POW:MUF2",
                                  "XTIM:POW:Y11","XTIM:POW:Y21","XTIM:POW:Y12","XTIM:POW:Y22",
                                  "XTIM:POW:Z11","XTIM:POW:Z21","XTIM:POW:Z12","XTIM:POW:Z22",
                                  "XTIM:POW:YREL11","XTIM:POW:YREL21","XTIM:POW:YREL12","XTIM:POW:YREL22",
                                  "XTIM:POW:ZREL11","XTIM:POW:ZREL21","XTIM:POW:ZREL12","XTIM:POW:ZREL22",
                                  "XTIM:VOLT:DCIN1","XTIM:VOLT:DCIN2","XTIM:POW:EFF"};
static ViString confMeasConv[] = {"S","SINV","ZREL","Z","YREL","Y"};
static ViString confMeasIFRE[] = {"XFR:POW:A1","XFR:POW:B1","XFR:POW:B2",
                                  "XFR:POW:A2"};
static ViString confMeasIPOW[] = {"XPOW:POW:A1","XPOW:POW:B1","XPOW:POW:B2",
                                  "XPOW:POW:A2"};
static ViString confMeasInput[] = {"A1","B1","B2","A2"};
static ViString confMeasInpUn[] = {"mW","W","uV","mV","V","dBm","dBW","dBuV",
                                   "dBmV","dBV"};
static ViString confMeasITIM[] = {"XTIM:POW:A1","XTIM:POW:B1","XTIM:POW:B2",
                                  "XTIM:POW:A2"};
static ViString confMeasRFRE[] = {"XFR:POW:RAT B1,ABSA1","XFR:POW:RAT B2,ABSA1",
                                  "XFR:POW:RAT B1,A1","XFR:POW:RAT B2,A1",
                                  "XFR:POW:RAT B1,A2","XFR:POW:RAT B2,A2",
                                  "XFR:POW:RAT B1,B2","XFR:POW:RAT B2,B1"};
static ViString confMeasRPOW[] = {"XPOW:POW:RAT B1,ABSA1","XPOW:POW:RAT B2,ABSA1",
                                  "XPOW:POW:RAT B1,A1","XPOW:POW:RAT B2,A1",
                                  "XPOW:POW:RAT B1,A2","XPOW:POW:RAT B2,A2",
                                  "XPOW:POW:RAT B1,B2","XPOW:POW:RAT B2,B1"};
static ViString confMeasRTIM[] = {"XTIM:POW:RAT B1,ABSA1","XTIM:POW:RAT B2,ABSA1",
                                  "XTIM:POW:RAT B1,A1","XTIM:POW:RAT B2,A1",
                                  "XTIM:POW:RAT B1,A2","XTIM:POW:RAT B2,A2",
                                  "XTIM:POW:RAT B1,B2","XTIM:POW:RAT B2,B1"};
static ViString confMeasRatio[] = {"A1","B1","B2","A2","ABSA1","ABSA2"};
static ViString confMeasPort[] = {"PORT1","PORT2"};
static ViString confResScale[] = {"AUTO ONCE","PDIV","RLEV","RPOS","TOP",
                                  "BOTT","OFFS"};
static ViString confResForm[] = {"COMP","MAGN","PHAS","REAL","IMAG","SWR",
                                 "GDEL","L","C","UPH"};
static ViString confResForMod[] = {"STEP","FREQ"};
static ViString confResDiagram[] = {"CLIN","CLOG","CDB","CSEG","PLIN","PLOG",
                                    "PDB","PSEG","SMIT","ISM","CHAR"};
static ViString confResDisplay[] = {"SING","DOV","DSPL","QOV","QDSP","QQSP"};
static ViString confResScaleUnit[] = {"PCT","DBM","DB","DBW","W","MW","UW",
                                      "NW","PW","V","MV","UV","NV","PV","DBV",
                                      "DBMV","DBUV","DEG","KDEG","MDEG","UDEG",
                                      "NDEG","PDEG","S","MS","US","NS","PS",
                                      "OHM","GOHM","MOHM","KOHM","SIE","MSIE",
                                      "USIE","NSIE","H","MH","UH","NH","PH",
                                      "FH","F","MF","uF","NF","PF","FF","UNIT",
                                      "MUNIT","UUNIT","NUNIT","PUNIT","FUNIT",""};
static ViString confRefSourceArr[] = {"INT","EXT"};                                      
static ViString confChannelMem[] = {"CH1DATA","CH2DATA","CH3DATA","CH4DATA",
                                    "MDAT1","MDAT2","MDAT3","MDAT4","MDAT5",
                                    "MDAT6","MDAT7","MDAT8"};
static ViString confMath[] = {"+","-","*","/"};
static ViString confMarkConv[] = {"S","SINV","Z","ZREL","Y","YREL"};
static ViString confMarkForm[] = {"MLIN","MDB","PHAS","REAL","IMAG","SWR",
                                  "GDEL","MLPH","MDPH","COMP","L","C","RLC"};
static ViString confMarkUnits[] = {"Hz","s","dBm","dB","UNIT","DEG","S","H",
                                   "F","OHM","SIE"};
static ViString confMarkTrace[] = {"CHMEM","CHDATA"};
static ViString confMarkMode[] = {"CONT","DISC"};
static ViString confMarkDelta[] = {"MARKER1","MARKER2","MARKER3","MARKER4",
                                   "MARKER5","MARKER6","MARKER7","MARKER8",
                                   "FIX"};
static ViString confMarkSeaBFM[]= {"BST","BPAS"};
static ViString confMarkSeaFun[] = {"BWID ","QFAC","SFAC 60,3","SFAC 60,6"};
static ViString confMarkSeaUni[] = {"dB","dBm","UNIT","DEG","S","OHM","SIE",
                                    "H","F"};
static ViString confMarkMkr[] = {"STAR","STOP","CENT","REF"};
static ViString confCalConfArr[] = {"STAT","INT:STAT","POW"};
static ViString confCalStandardApp[] = {"OPEN","SHORT"};
static ViString confCalKit[] = {"N50","N75","SMA","PC7","PC35", "USER1", "USER2", "PC292"};
static ViString confCalKitSt[] = {"MMTH","FFTH","MFTH","MMLINE1","FFLINE1",
                                  "MFLINE1","MMLINE2","FFLINE2","MFLINE2",
                                  "MMAT","FFAT","MFAT","MMSN","FFSN","MFSN",
                                  "MOPE","FOPE","MSH","FSH","MREF","FREF",
                                  "MMTC","FMTC","MSM","FSM"};
static ViString confCalPMT[] = {"NRV","NRVD","NRVS"};
static ViString confCalSCF[] = {"BSEN","ASEN"};
static ViString confLimSweepArr[] = {"F","T","P"};
static ViString confLimXSpacingArr[] = {"LIN","LOG","SEG", "SIN"};
static ViString confLimYSpacingArr[] = {"LIN","LOG","DB"};
static ViString confLimitUnitsArr[] = {"Hz","s","dBm"};

static ViString actCalFTPort[] = {"N50FEMALE","N50MALE","N75FEMALE","N75MALE",
                                  "PC7","SMAFEMALE","SMAMALE","PC35FEMALE",
                                  "PC35MALE","UFEMALE1", "UFEMALE2", "UMALE2",
                                  "PC292FEMALE","PC292MALE"};
static ViString actCalFTPMeth[] = {"TOM","TRM","TRL","TNA","TOSM","TOMX",
                                   "FUND"};
static ViString actCalFTPMeas[] = {"ACQ THR","ACQ OPEN1","ACQ OPEN2","ACQ MATCH1",
                                   "ACQ MATCH2","ACQ SLIDE1","ACQ SLIDE2","ACQ REFL1",
                                   "ACQ REFL2","ACQ LINE1","ACQ LINE2","ACQ ATT",
                                   "ACQ NET","ACQ SHORT1","ACQ SHORT2","ACQ MATCH12",
                                   "ACQ SHORT12","ACQ M1S2","ACQ S1M2","SAVE"};
static ViString actCalFOPMeth[] = {"FOPORT12","FOPORT1","FOPORT2"};
static ViString actCalFOPMeas[] = {"ACQ OPEN1","ACQ SHORT1","ACQ MATCH1","ACQ OPEN2","ACQ SHORT2",
                                   "ACQ MATCH2","ACQ SLIDE1","ACQ SLIDE2","SAVE"};
static ViString actCalOPTMeth[] = {"FOPT","ROPT"};
static ViString actCalOPTMeas[] = {" OPEN1"," SHORT1"," MATCH1"," THR",
                                   " OPEN2"," SHORT2"," MATCH2"," SLIDE1",
                                   " SLIDE2",":SAVE"};
static ViString actCalTNMeth[] = {"FRTRANS","FTRANS","RTRANS"};
static ViString actCalTNMeas[] = {" THR",":SAVE"};
static ViString actCalRNMeth[] = {"REFL12","REFL1","REFL2"};
static ViString actCalRNMeas[] = {" OPEN1"," OPEN2",":SAVE"};
static ViString actCalTRNMeth[] = {"TPORT","FTREF1","RTREF2"};
static ViString actCalTRNMeas[] = {" THR"," OPEN1"," OPEN2",":SAVE"};
static ViString actCalPow[] = {"A1","A2","ESRC1 ","ESRC2 ","B1","B2"};
static ViString actMarkSearch[] = {"SEAR","SEAR:NEXT","SEAR:RIGHT","SEAR:LEFT",
                                   "MIN","MAX"};
static ViString dataMemFileType[] = {"ASC","TOUC","SCOM"};
static ViString dataMemDataForm[] = {"COMP","MLPH","MDPH"};
static ViString dataMemMode[] = {"NEW","APP"};
static ViString dataMemSep[] = {"COMM","POIN"};
static ViString dataMemSour[] = {"DDAT","MDAT","FDAT","TDAT","CVD", "CDAT"};
static ViString datTypeFromInst[] = {"TRAC?","TRAC:STIM?"};
static ViString datFromInstr[]={"CH1DATA","CH2DATA","CH3DATA","CH4DATA",
                                "CH1MEM","CH2MEM","CH3MEM","CH4MEM",
                                "MDATA1","MDATA2","MDATA3","MDATA4","MDATA5",
                                "MDATA6","MDATA7","MDATA8"};
/*****************************************************************************/
/*= INSTRUMENT-DEPENDENT STATUS/RANGE STRUCTURE  ============================*/
/*****************************************************************************/
/* rszv_stringValPair is used in the rszv_errorMessage function              */
/* rszv_statusDataRanges is used to track session dependent status & ranges  */
/*===========================================================================*/
typedef struct  rszv_stringValPair
{
   ViStatus stringVal;
   ViString stringName;
}  rszv_tStringValPair;
 
struct rszv_statusDataRanges {
    ViInt32     instType; /* Defines type of instrument. 0 - ZVRL; 1 - ZVRE; 2 - ZVCE; 3 - ZVR; 4 - ZVC, 5 - ZVM, 6 - ZVK */
    ViReal64    minFreq;
    ViReal64    maxFreq;
    ViReal64    minPow;
    ViReal64    maxPow;
    ViInt32     options;
    ViUInt32    timeout;
    ViInt32     displayChannels;
    ViBoolean   checkStatus;
    ViBoolean   disp2trace[4];
    ViBoolean   externalMeas;
    ViChar instrDriverRevision[256];
};

typedef struct rszv_statusDataRanges *rszv_instrRange;

/*****************************************************************************/
/*= UTILITY ROUTINE DECLARATIONS (Non-Exportable Functions) =================*/
/*****************************************************************************/
ViBoolean rszv_invalidViBooleanRange (ViBoolean val);
ViBoolean rszv_invalidViInt32Range (ViInt32 val, ViInt32 min, ViInt32 max);
ViBoolean rszv_invalidViReal64Range (ViReal64 val, ViReal64 min, ViReal64 max);
ViStatus rszv_isChannelDisplayed (ViSession instrSession, ViInt32 channel);
ViStatus rszv_isChanDispCache (ViSession instrSession, ViInt32 channel);
ViStatus rszv_getSweepMode (ViSession instrSession, ViInt32 channel, ViPInt32 sweepMode);
ViStatus rszv_initCleanUp (ViSession openRMSession, ViPSession openInstrSession, ViStatus currentStatus);
ViStatus rszv_defaultInstrSetup (ViSession openInstrSession);

/*****************************************************************************/
/*------ INSERT INSTRUMENT-DEPENDENT UTILITY ROUTINE DECLARATIONS HERE ------*/
/*****************************************************************************/
ViStatus rszv_sysStatus (ViSession instrSession);
void rszv_SWAP_32(unsigned char *data, long points);
void rszv_SWAP_64(unsigned char *data, long points);

/*****************************************************************************/
/*====== USER-CALLABLE FUNCTIONS (Exportable Functions) =====================*/
/*****************************************************************************/

/*===========================================================================*/
/* Function: Initialize                                                      */
/* Purpose:  This function opens the instrument, queries the instrument      */
/*           for its ID, and initializes the instrument to a known state.    */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_init (ViRsrc resourceName, ViBoolean IDQuery,
                    ViBoolean resetDevice, ViPSession instrSession)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViSession   rmSession = 0;
    ViUInt32    retCnt = 0;
    ViByte      rdBuffer[BUFFER_SIZE];
    ViUInt16    interface = VI_INTF_GPIB;

    /*- Check input parameter ranges ----------------------------------------*/
    if (rszv_invalidViBooleanRange (IDQuery))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViBooleanRange (resetDevice))
        return VI_ERROR_PARAMETER3;

    /*- Open instrument session ---------------------------------------------*/
    CHECKERR( viOpenDefaultRM (&rmSession));

    if ((rszv_status = viOpen (rmSession, resourceName, VI_LOAD_CONFIG, VI_NULL, instrSession)) < 0)
        {
        viClose (rmSession);
        return rszv_status;
        }

    /* io session owned by driver now */
    CHECKERRCU( viGetAttribute (*instrSession, VI_ATTR_INTF_TYPE, &interface));

    /*- Configure VISA Formatted I/O ----------------------------------------*/
    CHECKERRCU( viSetAttribute (*instrSession, VI_ATTR_TMO_VALUE, 10000));
    CHECKERRCU( viSetBuf (*instrSession, VI_READ_BUF|VI_WRITE_BUF, 4000));
    CHECKERRCU( viSetAttribute (*instrSession, VI_ATTR_WR_BUF_OPER_MODE, VI_FLUSH_ON_ACCESS));
    CHECKERRCU( viSetAttribute (*instrSession, VI_ATTR_RD_BUF_OPER_MODE, VI_FLUSH_ON_ACCESS));
    
    if (interface == VI_INTF_ASRL)  /* Serial Port */
        {
        CHECKERRCU( viSetAttribute (*instrSession, VI_ATTR_TERMCHAR, '\n'));
        CHECKERRCU( viSetAttribute (*instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE));
        CHECKERRCU( viSetAttribute (*instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR));
        /* Changed to VI_ASRL_END_NONE due to Agilent VISA */
        CHECKERRCU( viSetAttribute (*instrSession, VI_ATTR_ASRL_END_OUT, VI_ASRL_END_NONE));
        }
    else /* GPIB, RSIB */
        {
        /* VI_ATTR_SEND_END_EN will stay with this attribute set to VI_TRUE */
        if ((rszv_status = viSetAttribute (*instrSession, VI_ATTR_SEND_END_EN,
            VI_TRUE)) < 0)
            return rszv_initCleanUp (rmSession, instrSession, rszv_status);
        }

    /* Interface specific operations */
    switch (interface)
        {
        case VI_INTF_ASRL: /* Serial Interface. Go to remote mode. */
            CHECKERRCU( viWrite (*instrSession, "@REM\n", 5, &retCnt));
        break;
#ifdef VI_INTF_TCPIP
        case VI_INTF_TCPIP: /* RSIB Interface. Go to remote mode. */
            CHECKERRCU( viSetAttribute (*instrSession, RS_ATTR_RSIB_SRE, 1));
        break;
#endif        
        }

    /*- Identification Query ------------------------------------------------*/
    if (IDQuery)
        {
        CHECKERRCU( viQueryf (*instrSession, "*IDN?\n", "%[^\r\n]", rdBuffer));

        if (!strstr(rdBuffer, "Rohde&Schwarz,ZV")) 
            return rszv_initCleanUp (rmSession, instrSession, VI_ERROR_FAIL_ID_QUERY);
        }
        
    /*- Reset instrument ----------------------------------------------------*/
    if (resetDevice)
        rszv_status = rszv_reset (*instrSession);
    else  /*- Send Default Instrument Setup ---------------------------------*/
        rszv_status = rszv_defaultInstrSetup (*instrSession);

    CHECKERRCU( rszv_status);
    CHECKERRCU( rszv_sysStatus (*instrSession));
    
    return rszv_status;
}

/*===========================================================================*/
/*  Function: Application Example                                            */
/*  Purpose:  This function illustrates typical measuring task for a network */
/*            analyzer. The described measured task is transmission          */
/*            measurement of magnitude and phase.                            */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_appExample (ViSession instrSession, 
                    ViReal64 startFrequencyHz, ViReal64 stopFrequencyHz,
                    ViBoolean format, ViPInt32 count, ViReal64 _VI_FAR data[])
{
    ViStatus        rszv_status = VI_SUCCESS;
    ViInt32         tmpFormat;
    rszv_instrRange instrPtr;

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));

    if (rszv_invalidViReal64Range (startFrequencyHz, instrPtr -> minFreq, instrPtr -> maxFreq))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViReal64Range (stopFrequencyHz, instrPtr -> minFreq, instrPtr -> maxFreq))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViBooleanRange (format))
        return VI_ERROR_PARAMETER4;

    tmpFormat = (format == VI_TRUE) ? 1 : 2;

    /*- Set up measurement parameters ----------------------------------------*/
    CHECKERR( rszv_confChannel (instrSession, 1));  
    CHECKERR( rszv_confSweepNumber (instrSession, 1, 1, VI_FALSE));
    CHECKERR( rszv_confStimulusConf (instrSession, 1, 0, startFrequencyHz, 0));
    CHECKERR( rszv_confStimulusConf (instrSession, 1, 1, stopFrequencyHz, 0));
    CHECKERR( rszv_confResMeas (instrSession, 1, 1, 0));
    CHECKERR( rszv_confResFormat (instrSession, 1, tmpFormat));
    CHECKERR( rszv_actSweepStart (instrSession));

    CHECKERR( rszv_WaitForOPC (instrSession));
    /*- Read out measurement results -----------------------------------------*/
    CHECKERR(rszv_dataReadTrace (instrSession, VI_FALSE, VI_FALSE, 0, 0, count, data));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Channel Configuration                                          */
/*  Purpose:  This function selects the active channel of the analyzer.      */
/*  The currently active display channel is indicated by the LED above       */
/*  the corresponding key.                                                   */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confChannel (ViSession instrSession, ViInt32 channel)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      buffer[BUFFER_SIZE];
    ViInt32     i;
    rszv_instrRange instrPtr;

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    
    CHECKERR( viQueryf (instrSession, ":INST CHANNEL%ld;:DISP:FORM?\n", "%[^\r\n]",
        channel, buffer));

    for (i = 0; i < 6; i++)
        {
        if (strstr((ViChar *)buffer, confResDisplay[i]))
            break;
        }

    if (i == 6)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    if (i < 3)
        {
        instrPtr -> displayChannels = (1 << channel);
        if (i != 0)
            instrPtr -> displayChannels |= (channel % 2) ? (1<<(channel+1)) : (1<<(channel-1));
        }
    else
        instrPtr -> displayChannels = 0x1E;

    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Stimulus Configuration                                         */
/*  Purpose:  This function defines the limits and size of the sweep range.  */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confStimulusConf (ViSession instrSession, ViInt32 channel,
                    ViInt32 stimulus, ViReal64 parameter, ViInt32 unit)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViReal64    min, max;
    ViByte      wrtBuf[BUFFER_SIZE];
    rszv_instrRange instrPtr;

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));
    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (stimulus, 0, 3))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViInt32Range (unit, 0, 6))
        return VI_ERROR_PARAMETER5;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    if (unit <= 3)
        {
        static ViReal64 constArr[] = {0, 1.0e3, 1.0e6, 1.0e9};
        ViReal64 newpar;

        /*- Frequency Sweep Selected ------------------*/
        min = instrPtr -> minFreq; max = instrPtr -> maxFreq;

        if (stimulus == 2)
            {    /*- Center -*/
            min += 1.0e-4; max -= 1.0e-4;
            }
        else if (stimulus == 3)
            {   /*- Span -*/
            min = 10.0e-3;
            max = (instrPtr -> maxFreq) - (instrPtr -> minFreq) - 10.0e-3;
            }
        
        newpar = (unit) ? (parameter * constArr[unit]) : parameter;

        if (rszv_invalidViReal64Range (newpar, min , max))
            return VI_ERROR_PARAMETER4;
        sprintf (wrtBuf, ":SENS%ld:FREQ:%s %f%s", channel, confStimArr[stimulus],
            parameter, confUnitArr[unit]);
        }
    else if (unit == 6)
        {
        if (rszv_invalidViReal64Range (parameter,  1.0e-3, 127500.0))
            return VI_ERROR_PARAMETER4;
        if (stimulus != 1)
            return VI_ERROR_PARAMETER3;
        sprintf (wrtBuf, ":SENS%ld:SWE:TIME %fs", channel, parameter);
        }
    else
        { /*- Power Sweep Selected --------------------*/
        min = instrPtr -> minPow; max = instrPtr -> maxPow;

        if (stimulus == 2)
            { /*- Center -*/
            min += 0.1;
            max -= 0.1;
            }
        else if (stimulus == 3)
            { /*- Span -*/
            if (unit == 4)
                return VI_ERROR_PARAMETER5;

            min = 0.1; 
            max = (instrPtr -> maxPow) - (instrPtr -> minPow) - 0.1;
            }

        if (rszv_invalidViReal64Range (parameter, min, max))
            return VI_ERROR_PARAMETER4;

        sprintf (wrtBuf, ":SOUR%ld:POW:%s %f%s", channel,
            confStimArr[stimulus], parameter, confUnitArr[unit]);
        }

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Time Domain Configurations                                     */
/*  Purpose:  This function enables/disables time/freq domain.               */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confTimeDomain (ViSession instrSession, ViInt32 channel,
                ViBoolean domain, ViBoolean timeGate)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];
    
    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViBooleanRange (domain))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViBooleanRange (timeGate))
        return VI_ERROR_PARAMETER4;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":CALC%ld:TRAN:TIME:STAT %s;:CALC%ld:FILT:TIME:STAT %s", 
         channel, confStates[(domain==VI_TRUE)],
         channel, confStates[(timeGate==VI_TRUE)]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));
    
    return rszv_status;
}

/*===========================================================================*/
/*  Function: Time Domain Gate                                               */
/*  Purpose:  This function configures the time domain gate.                 */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confTimeDomainGate (ViSession instrSession,
                ViInt32 channel, ViInt32 gateFunction, ViReal64 sidelobe)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (gateFunction, 0, 4))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViReal64Range (sidelobe, 10.0, 120.0))
        return VI_ERROR_PARAMETER4;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    if (gateFunction == 4)
        sprintf (wrtBuf, ":CALC%ld:FILT:TIME:WIND %s;:CALC%ld:FILT:TIME:DCH %f",
            channel, confTDGate[gateFunction], channel, sidelobe);
    else
        sprintf (wrtBuf, ":CALC%ld:FILT:TIME:WIND %s", channel,
            confTDGate[gateFunction]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Time Domain Gate Start Stop                                    */
/*  Purpose:  This function defines start and stop time of the gate.         */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confTimeDomainGateStartStop (ViSession instrSession,
                ViInt32 channel, ViReal64 start, ViReal64 stop)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));
    sprintf (wrtBuf, ":CALC%ld:FILT:TIME:STAR %f;STOP %f", channel, start, stop);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf,strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Time Domain Gate Center Span                                   */
/*  Purpose:  This function defines center and span time of the gate.        */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confTimeDomainGateCenterSpan (ViSession instrSession,
                ViInt32 channel, ViReal64 center, ViReal64 span)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];
    
    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    
    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":CALC%ld:FILT:TIME:CENT %f;SPAN %f", channel, center, span);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Time Domain Transform                                          */
/*  Purpose:  This function configures transformation type.                  */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confTimeDomainTransform (ViSession instrSession,
                ViInt32 channel, ViBoolean method, ViBoolean stimulus,
                ViBoolean type, ViInt32 lowpass, ViReal64 lowpassDCSParam,
                ViInt32 XAxis)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViBooleanRange (method))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViBooleanRange (stimulus))
        return VI_ERROR_PARAMETER4;
    if (rszv_invalidViBooleanRange (type))
        return VI_ERROR_PARAMETER5;
    if (rszv_invalidViInt32Range (lowpass, 0, 2))
        return VI_ERROR_PARAMETER6;
    if (rszv_invalidViReal64Range (lowpassDCSParam, -1.0e9, 1.0e9))
        return VI_ERROR_PARAMETER7;
    if (rszv_invalidViInt32Range (XAxis, 0, 2))
        return VI_ERROR_PARAMETER8;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    if (type == VI_FALSE)
        sprintf (wrtBuf, ":CALC%ld:TRAN:TIME:LPAS %s;", channel,
            confTDLowpass[lowpass]);
    else
        sprintf (wrtBuf, ":CALC%ld:TRAN:TIME:LPAS %s;:CALC%ld:TRAN:TIME:METH %s;"
            "STIM %s;TYPE %s;XAX %s;LPAS:DCSP %f",
            channel,
            confTDLowpass[lowpass],
            channel,
            confTDMethod[(method == VI_TRUE)?1:0],
            confTDStimulus[(stimulus == VI_TRUE)?1:0],
            confTDType[(type == VI_TRUE)?1:0], 
            confTDXaxis[XAxis],
            lowpassDCSParam);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: No Linear Measurement                                          */
/*  Purpose:  This function configures Non Linear Measurement.               */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confNonLinMeas (ViSession instrSession, ViInt32 channel,
                ViInt32 function)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];
    
    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (function, 0, 3))
        return VI_ERROR_PARAMETER3;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));
    sprintf (wrtBuf, ":SENS%ld:FUNC 'XFR:NLIN %s'", channel, confNLM[function]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: External Source Config                                         */
/*  Purpose:  This function configures external source.                      */
/*  Mote:  Obsolete function. New function rszv_rszv_ConfigureExternalSource */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confExterSource (ViSession instrSession, 
                ViBoolean source, ViInt32 GPIBAddress, ViBoolean link,
                ViInt32 deviceType, ViString userDefined)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViBooleanRange (source))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (GPIBAddress, 1, 31))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViBooleanRange (link))
        return VI_ERROR_PARAMETER4;
    if (rszv_invalidViInt32Range (deviceType, 0, 16))
        return VI_ERROR_PARAMETER5;
    if (deviceType == 16)
        {
        if (userDefined)
            {
            if (strlen(userDefined) > 8)
                return VI_ERROR_PARAMETER6;
            }
        else
            return VI_ERROR_PARAMETER6;
        }

    if (link == VI_TRUE)
        sprintf (wrtBuf, ":SYST:COMM:RDEV:GEN%ld:TYPE '%s';LINK %s;:SYST:COMM:GPIB:RDEV:GEN%ld:ADDR %ld",
             ((source == VI_FALSE)?2:1), 
             ((deviceType == 16) ? userDefined : confEGenType[deviceType]),
             confEGenLink[(link==VI_TRUE)?1:0], ((source == VI_FALSE)?2:1),
             GPIBAddress);
    else
        sprintf (wrtBuf, ":SYST:COMM:RDEV:GEN%ld:TYPE '%s';LINK %s",
             ((source == VI_FALSE)?2:1), 
             ((deviceType == 16) ? userDefined : confEGenType[deviceType]),
             confEGenLink[(link==VI_TRUE)?1:0]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Configure External Source                                      */
/*  Purpose:  This function configures external source.                      */
/*     Note:  Old function rszv_confExterSource is obsolete from Rew. 4.2    */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_ConfigureExternalSource (ViSession instrSession, 
                ViBoolean source, ViInt32 GPIBAddress, ViBoolean link,
                ViInt32 deviceType, ViString userDefined, ViBoolean state)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViChar      wrtBuf[BUFFER_SIZE];
    ViChar      *p2buffer;
    
    if (rszv_invalidViBooleanRange (source))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (GPIBAddress, 1, 31))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViBooleanRange (link))
        return VI_ERROR_PARAMETER4;
    if (rszv_invalidViInt32Range (deviceType, 0, 16))
        return VI_ERROR_PARAMETER5;

    p2buffer = wrtBuf;

    if (deviceType == 16)
        {
        if (userDefined)
            {
            if (strlen(userDefined) > 8)
                return VI_ERROR_PARAMETER6;
            }
        else
            return VI_ERROR_PARAMETER6;
        }

    if (rszv_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER7;
    
    p2buffer = wrtBuf;
    p2buffer += sprintf(p2buffer, ":SYST:COMM:RDEV:GEN%d:TYPE '%s';LINK %s",
         ((source == VI_FALSE)?2:1), 
         ((deviceType == 16) ? userDefined : confEGenType[deviceType]),
         confEGenLink[(link==VI_TRUE)?1:0]);

    if (link == VI_TRUE)
        {
        p2buffer += sprintf(p2buffer, ";:SYST:COMM:GPIB:RDEV:GEN%ld:ADDR %ld", 
                      ((source == VI_FALSE)?2:1), GPIBAddress);
        }

    p2buffer += sprintf(p2buffer,";:SYST:COMM:RDEV:GEN%d:CONT %s\n", 
                   ((source == VI_FALSE)?2:1),
                    confExtSourceState[state]);

    CHECKERR( viWrite (instrSession, (ViByte*)wrtBuf, p2buffer-wrtBuf, VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Compression Point Measurement                                  */
/*  Purpose:  This function defines parameters for the compression point     */
/*            measurement.                                                   */
/*  Mote:  Obsolete function. New function rszv_ConfigureCompressionPointMeas*/
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confDefCompMeas (ViSession instrSession,
                ViInt32 channel, ViReal64 maxLimit, ViReal64 minLimit,
                ViReal64 settlingTimes, ViBoolean compPoint, 
                ViReal64 XDBCompPoint, ViInt32 source)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViReal64Range (settlingTimes, 0.0, 1000.0))
        return VI_ERROR_PARAMETER5;
    if (rszv_invalidViBooleanRange (compPoint))
        return VI_ERROR_PARAMETER6;
    if (rszv_invalidViReal64Range (XDBCompPoint, 0.1, 10.0))
        return VI_ERROR_PARAMETER7;
    if (rszv_invalidViInt32Range (source, 0, 2))
        return VI_ERROR_PARAMETER8;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));
    
    sprintf (wrtBuf, ":SOUR%ld:POW:NLIN:COMP:RANG:UPP %f;LOW %f;:SENS%ld:FREQ:NLIN:COMP:STIM %f;"
                    ":SENS%ld:FUNC 'XFR:NLIN:COMP:CPO %s';FUNC 'XFR:NLIN:COMP:LEV %f';"
                    ":SOUR%ld:FREQ:NLIN:COMP %s",
        channel, maxLimit, minLimit, channel, settlingTimes,
        channel, confCompPoint[compPoint], XDBCompPoint,
        channel, confGenSource[source]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Compression Point Measurement                                  */
/*  Purpose:  This function defines parameters for the compression point     */
/*            measurement.                                                   */
/*     Note:  Old function rszv_confDefCompMeas is obsolete from Rew. 4.2    */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_ConfigureCompressionPointMeas (ViSession instrSession,
                ViInt32 channel, ViReal64 maxLimit, ViReal64 minLimit,
                ViReal64 settlingTimes, ViBoolean compPoint, 
                ViReal64 XDBCompPoint, ViInt32 source, ViBoolean check)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViChar      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViReal64Range (settlingTimes, 0.0, 1000.0))
        return VI_ERROR_PARAMETER5;
    if (rszv_invalidViBooleanRange (compPoint))
        return VI_ERROR_PARAMETER6;
    if (rszv_invalidViReal64Range (XDBCompPoint, 0.1, 10.0))
        return VI_ERROR_PARAMETER7;
    if (rszv_invalidViInt32Range (source, 0, 2))
        return VI_ERROR_PARAMETER8;
    if (rszv_invalidViBooleanRange (check))
        return VI_ERROR_INSTR_PARAMETER9;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf(wrtBuf, ":SOUR%ld:POW:NLIN:COMP:RANG:UPP %Lf;LOW %Lf;"
                      ":SENS%ld:FREQ:NLIN:COMP:STIM %Lf;"
                      ":SENS%ld:FUNC 'XFR:NLIN:COMP:CPO %s'"
                      ";FUNC 'XFR:NLIN:COMP:LEV %Lf';FUNC 'XFR:NLIN:COMP:CHEC %s';"
                      ":SOUR%ld:FREQ:NLIN:COMP %s",
        channel, maxLimit, minLimit, channel, settlingTimes,
        channel, confCompPoint[compPoint], XDBCompPoint, confStates[check],
        channel, confGenSource[source]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Second Order Intercept Meas                                    */
/*  Purpose:  This function defines parameters the measurement of the 2nd    */
/*            order intercept.                                               */
/*  Mote:     Obsolete function. New function rszv_ConfigureSOIMeasurement.  */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confDefSoiMeas (ViSession instrSession,
                ViInt32 channel, ViReal64 maxLimit,
                ViReal64 minLimit,ViReal64 settlingTimes,
                ViBoolean intcPoint, ViReal64 freqOffset,
                ViBoolean measFunc, ViInt32 source)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViReal64Range (settlingTimes, 0.0, 1000.0))
        return VI_ERROR_PARAMETER5;
    if (rszv_invalidViBooleanRange (intcPoint))
        return VI_ERROR_PARAMETER6;
    if (rszv_invalidViBooleanRange (measFunc))
        return VI_ERROR_PARAMETER8;
    if (rszv_invalidViInt32Range (source, 0, 2))
        return VI_ERROR_INSTR_PARAMETER9;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":SOUR%ld:POW:NLIN:SOI:RANG:UPP %f;LOW %f;"
                     ":SENS%ld:FREQ:NLIN:SOI:STIM %f;"
                    ":SENS%ld:FUNC 'XFR:NLIN:SOI:IPO %s';FUNC 'XFR:NLIN:SOI:FREQ %s';"
                    ":SOUR%ld:FREQ:NLIN:SOI %s;SOI:OFFS %f",
        channel, maxLimit, minLimit, channel, settlingTimes,
        channel, confCompPoint[intcPoint], confSOIMF[measFunc], 
        channel, confSOISource[source], freqOffset);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Second Order Intercept Meas                                    */
/*  Purpose:  This function defines parameters the measurement of the 2nd    */
/*            order intercept.                                               */
/*     Note:  Old function rszv_confDefSoiMeas is obsolete from Rew. 4.2     */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_ConfigureSOIMeasurement (ViSession instrSession,
                ViInt32 channel, ViReal64 maxLimit,
                ViReal64 minLimit,ViReal64 settlingTimes,
                ViBoolean intcPoint, ViReal64 freqOffset,
                ViBoolean measFunc, ViInt32 source, ViBoolean check)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViChar      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViReal64Range (settlingTimes, 0.0, 1000.0))
        return VI_ERROR_PARAMETER5;
    if (rszv_invalidViBooleanRange (intcPoint))
        return VI_ERROR_PARAMETER6;
    if (rszv_invalidViBooleanRange (measFunc))
        return VI_ERROR_PARAMETER8;
    if (rszv_invalidViInt32Range (source, 0, 2))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rszv_invalidViBooleanRange (check))
        return VI_ERROR_INSTR_PARAMETER10;
  
    CHECKERR( rszv_isChanDispCache (instrSession, channel));
    
    sprintf(wrtBuf, ":SOUR%ld:POW:NLIN:SOI:RANG:UPP %Lf;LOW %Lf;"
                      ":SENS%ld:FREQ:NLIN:SOI:STIM %Lf;"
                      ":SENS%ld:FUNC 'XFR:NLIN:SOI:IPO %s'"
                      ";FUNC 'XFR:NLIN:SOI:FREQ %s'"
                      ";FUNC 'XFR:NLIN:SOI:CHEC %s';"
                      ":SOUR%ld:FREQ:NLIN:SOI %s;SOI:OFFS %Lf",
        channel, maxLimit, minLimit, channel, settlingTimes,
        channel, confCompPoint[intcPoint], confSOIMF[measFunc], confStates[check],
        channel, confSOISource[source], freqOffset);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Third Order Intercept Measureme                                */
/*  Purpose:  This function defines parameters of the 3rd order intercept    */
/*            measurement.                                                   */
/*  Mote:     Obsolete function. New function rszv_ConfigureTOIMeasurement.  */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confDefToiMeas (ViSession instrSession, ViInt32 channel,
                ViReal64 maxLimit, ViReal64 minLimit, ViReal64 settlingTimes,
                ViBoolean intcPoint, ViReal64 freqOffset, ViBoolean measSideb,
                ViInt32 source)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViReal64Range (settlingTimes, 0.0, 1000.0))
        return VI_ERROR_PARAMETER5;
    if (rszv_invalidViBooleanRange (intcPoint))
        return VI_ERROR_PARAMETER6;
    if (rszv_invalidViBooleanRange (measSideb))
        return VI_ERROR_PARAMETER8;
    if (rszv_invalidViInt32Range (source, 0, 2))
        return VI_ERROR_INSTR_PARAMETER9;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));
    
    sprintf (wrtBuf, ":SOUR%ld:POW:NLIN:TOI:RANG:UPP %f;LOW %f;"
                     ":SENS%ld:FREQ:NLIN:TOI:STIM %f;"
                     ":SENS%ld:FUNC 'XFR:NLIN:TOI:IPO %s'"
                     ";FUNC 'XFR:NLIN:TOI:SID %s';"
                     ":SOUR%ld:FREQ:NLIN:TOI %s;TOI:OFFS %f",
        channel, maxLimit, minLimit, channel, settlingTimes,
        channel, confCompPoint[intcPoint], confTOISID[measSideb],
        channel, confSOISource[source], freqOffset);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Third Order Intercept Measurement                              */
/*  Purpose:  This function defines parameters of the 3rd order intercept    */
/*            measurement.                                                   */
/*     Note:  Old function rszv_confDefToiMeas is obsolete from Rew. 4.2     */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_ConfigureTOIMeasurement (ViSession instrSession, ViInt32 channel,
                ViReal64 maxLimit, ViReal64 minLimit, ViReal64 settlingTimes,
                ViBoolean intcPoint, ViReal64 freqOffset, ViBoolean measSideb,
                ViInt32 source, ViBoolean check)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViChar      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViReal64Range (settlingTimes, 0.0, 1000.0))
        return VI_ERROR_PARAMETER5;
    if (rszv_invalidViBooleanRange (intcPoint))
        return VI_ERROR_PARAMETER6;
    if (rszv_invalidViBooleanRange (measSideb))
        return VI_ERROR_PARAMETER8;
    if (rszv_invalidViInt32Range (source, 0, 2))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rszv_invalidViBooleanRange (check))
        return VI_ERROR_INSTR_PARAMETER10;
 
    CHECKERR( rszv_isChanDispCache (instrSession, channel));
    
    sprintf (wrtBuf, ":SOUR%ld:POW:NLIN:TOI:RANG:UPP %Lf;LOW %Lf;"
                     ":SENS%ld:FREQ:NLIN:TOI:STIM %Lf;"
                     ":SENS%ld:FUNC 'XFR:NLIN:TOI:IPO %s'"
                     ";FUNC 'XFR:NLIN:TOI:SID %s';FUNC 'XFR:NLIN:TOI:CHEC %s';"
                     ":SOUR%ld:FREQ:NLIN:TOI %s;TOI:OFFS %Lf",
        channel, maxLimit, minLimit, channel, settlingTimes,
        channel, confCompPoint[intcPoint], confTOISID[measSideb], confStates[check],
        channel, confSOISource[source], freqOffset);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Time Domain Window                                             */
/*  Purpose:  This function configures filtering (also called weighting,     */
/*            profiling or windowing) the frequency-domain data.             */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confTimeDomainWindow (ViSession instrSession,
                ViInt32 channel, ViInt32 filterFunction, ViReal64 sidelobe)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (filterFunction, 0, 4))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViReal64Range (sidelobe, 10.0, 120.0))
        return VI_ERROR_PARAMETER4;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    if (filterFunction == 4)
        sprintf (wrtBuf, ":CALC%ld:TRAN:TIME:WIND %s;DCH %f",
            channel, confTDGate[filterFunction], sidelobe);
    else
        sprintf (wrtBuf, ":CALC%ld:TRAN:TIME:WIND %s",
            channel, confTDGate[filterFunction]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Measure Mode                                                   */
/*  Purpose:  This function defines the type of measurement performed with   */
/*            the test set (internal, external, full-port) and speed of      */
/*            measure(Fast or Normal).                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confMode (ViSession instrSession, ViInt32 mode,
                ViInt32 channel, ViBoolean speed)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];
    rszv_instrRange instrPtr;

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));
    
    if (!isZVMK(instrPtr->instType))
        {
        if (rszv_invalidViInt32Range (mode, 0, 2))
            return VI_ERROR_PARAMETER2;
        }

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER3;        
    if (rszv_invalidViBooleanRange (speed))
        return VI_ERROR_PARAMETER4;

    /*- Is Channel displayed? -----------------------------------------------*/
    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    if (isZVMK(instrPtr->instType))
        sprintf (wrtBuf, ":SENS%ld:DET %s", channel, confMeasSpeed[(speed==VI_TRUE)?1:0]);
    else
        {
        if (!isZVR_B25(instrPtr -> options))
            if (mode == 1)
                return RSZV_ERROR_OPTION_NOT_AVAILABLE;

        sprintf (wrtBuf, ":INP:BRID %s;:SENS%ld:DET %s",
             confMeasMode[mode], channel, confMeasSpeed[(speed==VI_TRUE)?1:0]);
        }

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    instrPtr -> externalMeas = (mode == 1) ? VI_TRUE : VI_FALSE;

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Measure Mode                                                   */
/*  Purpose:  This function configures ...                                   */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confModeInput (ViSession instrSession, ViInt32 input1, ViInt32 input2)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];
    rszv_instrRange instrPtr;

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));
    if (!isZVMK(instrPtr->instType))
        return RSZV_ERROR_OPTION_NOT_AVAILABLE;

    if (isZVR_B23(instrPtr -> options))
        {
        if (rszv_invalidViInt32Range (input1, 0, 1))
            return VI_ERROR_PARAMETER2;

        sprintf (wrtBuf, ":INP1:BRID %s;", confMeasMode[input1]);
        }
    else if (input1 != 0)
        return VI_ERROR_PARAMETER2;

    if (isZVR_B24(instrPtr -> options))
        {
        if (rszv_invalidViInt32Range (input2, 0, 1))
            return VI_ERROR_PARAMETER3;        

        sprintf (wrtBuf, ":INP1:BRID %s;:INP2:BRID %s;", confMeasMode[input1],
            confMeasMode[input2]);
        }
    else if (input2 != 0)
        return VI_ERROR_PARAMETER3;

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;       
}

/*===========================================================================*/
/*  Function: Frequency Convers                                              */
/*  Purpose:  This function activates, dectivates freguency-converting       */
/*            operating modes.                                               */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confMeasFreqConv (ViSession instrSession, ViInt32 channel,
                ViInt32 frequencyConvers)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];
    ViUInt32    retCnt = 0;

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (frequencyConvers, 0, 4))
        return VI_ERROR_PARAMETER3;

    /*- Is Channel displayed? -----------------------------------------------*/
    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":SENS%ld:FREQ:CONV %s", channel,
       confMeasFrCoArr[frequencyConvers]);  

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), &retCnt));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Define Mixer Base Frequency                                    */
/*  Purpose: This function configurations Mixer Meas.                        */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confDefMixerBaseFreq (ViSession instrSession,
                ViInt32 channel, ViInt32 fundamentalFreq,
                ViBoolean localOscillator)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];
    
    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (fundamentalFreq, 0, 2))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViBooleanRange (localOscillator))
        return VI_ERROR_PARAMETER4;

    /*- Is Channel displayed? -----------------------------------------------*/
    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":SENS%ld:FREQ:CONV:MIX:FUND %s;LOEX %s",
       channel, confMeasMixFund[fundamentalFreq], confMeasMixLoex[(localOscillator==VI_TRUE)?1:0]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}
                             
/*===========================================================================*/
/*  Function: Define Mixer Fixed Frequency                                   */
/*  Purpose:  This function configures fixed frequency.                      */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confDefMixerFixedFreq (ViSession instrSession,
                ViInt32 channel, ViInt32 control, ViReal64 fixedValueHz)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];
    
    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (control, 0, 2))
        return VI_ERROR_PARAMETER3;

    /*- Is Channel displayed? -----------------------------------------------*/
    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":SENS%ld:FREQ:CONV:MIX:%s %fHz",
       channel, confMeasMixCont[control], fixedValueHz);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Define Mixer Band                                              */
/*  Purpose:  This function configures mixer band.                           */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confDefMixerBand (ViSession instrSession,
                ViInt32 channel, ViBoolean band)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];
    
    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViBooleanRange (band))
        return VI_ERROR_PARAMETER3;

    /*- Is Channel displayed? -----------------------------------------------*/
    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":SENS%ld:FREQ:CONV:MIX:TFR %s",
       channel, confMeasMixTfr[band]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/* Function: Reference Mixer                                                 */
/* Purpose:  This function controls the reference mixer ports                */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confReferenceMixer (ViSession instrSession, ViBoolean state)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViChar      buffer[BUFFER_SIZE];
    rszv_instrRange instrPtr;

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr)); 

    if (rszv_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER2;
    if (isZVK(instrPtr -> instType) || isZVM(instrPtr -> instType))
        return RSZV_ERROR_OPTION_NOT_AVAILABLE;
    if (!isZVR_B6(instrPtr -> options))
        return RSZV_ERROR_OPTION_NOT_AVAILABLE;

    sprintf (buffer, ":OUTP:RMIX %s", state ? "ON" : "OFF");

    sprintf(buffer+strlen(buffer),"\n"); 
    CHECKERR( viWrite (instrSession, buffer, strlen (buffer), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/* Function: Reference Oscillator                                            */
/* Purpose:  This function selects the reference oscillator, and configures  */
/*           the external frequency if necssary.                             */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confReferenceOsc (ViSession instrSession, ViBoolean source,
                ViInt32 extFreq)
{
    ViStatus rszv_status = VI_SUCCESS;
    ViChar buffer[BUFFER_SIZE];

    if (rszv_invalidViBooleanRange (source))
        return VI_ERROR_PARAMETER2;

    if (source == VI_FALSE)
        sprintf (buffer, ":ROSC:SOUR %s", confRefSourceArr[source]);
    else
        {
        if (rszv_invalidViInt32Range (extFreq, 1000000, 16000000))
            return VI_ERROR_PARAMETER3;

        sprintf (buffer, ":ROSC:SOUR %s;:ROSC:EXT:FREQ %ld",
            confRefSourceArr[source], extFreq);
        }

    sprintf(buffer+strlen(buffer),"\n"); 
    CHECKERR( viWrite (instrSession, buffer, strlen (buffer), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));
    
    return rszv_status;
}

/*===========================================================================*/
/*  Function: Define Arbitrary                                               */
/*  Purpose: This function defines the Arbitrary system frequencies table.   */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confMeasDefArbit (ViSession instrSession, ViInt32 channel,
                ViInt32 systemFrequencies, ViBoolean state,
                ViInt32 numerator, ViInt32 denominator, ViReal64 offsetHz,
                ViBoolean frequency)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (systemFrequencies, 0, 3))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER4;
    if (rszv_invalidViInt32Range (numerator, -99, 99))
        return VI_ERROR_PARAMETER5;
    if (rszv_invalidViInt32Range (denominator, -99, 99))
        return VI_ERROR_PARAMETER6;
    if (rszv_invalidViReal64Range (offsetHz, -1000.0e9, 1000.0e9))
        return VI_ERROR_PARAMETER7;
    if (rszv_invalidViBooleanRange (frequency))
        return VI_ERROR_PARAMETER8;

    /*- Is Channel displayed? -----------------------------------------------*/
    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    switch(systemFrequencies)
        {
        case 0: /* - Receive -------------------------------------------------*/
              sprintf (wrtBuf, ":SENS%ld:%s %ld,%ld,%fHz,%s",
                   channel, confMeasSysFreq[systemFrequencies],
                   numerator, denominator, offsetHz,confMeasArbitFreq[frequency]);
              break;
        case 1: /* - Internal ------------------------------------------------*/
              sprintf (wrtBuf, ":SOUR%ld:%s %ld,%ld,%fHz,%s", channel,
                   confMeasSysFreq[systemFrequencies], numerator, denominator,
                   offsetHz,confMeasArbitFreq[frequency]);
              break;
        case 2: /* - External1 and External2 ----------------------------------*/
        case 3:
              sprintf (wrtBuf, ":SOUR%ld:FREQ:CONV:ARB:%s %s,%ld,%ld,%fHz,%s",
                   channel, confMeasSysFreq[systemFrequencies],
                   confStates[(state==VI_TRUE)?1:0], numerator, denominator,
                   offsetHz, confMeasArbitFreq[frequency]);
              break;
        default:
              wrtBuf[0] = 0;
              break;
        }

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}                                          

/*===========================================================================*/
/*  Function: Sweep Type                                                     */
/*  Purpose:  This function selects the sweep variable.                      */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confSweepType (ViSession instrSession, ViInt32 channel,
                 ViInt32 sweepType)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      buffer[BUFFER_SIZE];
    ViByte      tmp[30];
    ViChar      *p2buffer;

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (sweepType, 0, 2))
        return VI_ERROR_PARAMETER3;

    /* - Sweep Setting --------------------------------------------------------*/
    CHECKERR( rszv_isChanDispCache (instrSession, channel));
    CHECKERR( viQueryf (instrSession, ":SENS%ld:FUNC?\n", "%[^\r\n]", channel, buffer));

    if (strstr((ViChar *)buffer, "NLIN"))
        {
        sprintf (buffer, ":SENS%ld:FUNC 'XFR:NLIN:COMP OFF'", channel);

        sprintf(buffer+strlen(buffer),"\n");
        CHECKERR( viWrite (instrSession, buffer, strlen (buffer), VI_NULL));
        }

    if ((p2buffer = strchr((ViChar *)buffer, ':')) == VI_NULL)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    strcpy((char *)tmp, p2buffer);

    /*- Change Sweep with the same setting ------------------------------------*/
    sprintf (buffer, ":SENS%ld:FUNC '%s%s", channel, confSweepType[sweepType], tmp);

    sprintf(buffer+strlen(buffer),"\n"); 
    CHECKERR( viWrite (instrSession, buffer, strlen (buffer), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}


/*===========================================================================*/
/*  Function: Date and Time                                                  */
/*  Purpose:  This function selects the sweep variable.                      */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confSetupTime (ViSession instrSession, ViInt32 day,
                ViInt32 month, ViInt32 year, ViInt32 hour, ViInt32 minute,
                ViInt32 second)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (day, 1, 31))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (month, 1, 12))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViInt32Range (year, 0, 9999))
        return VI_ERROR_PARAMETER4;
    if (rszv_invalidViInt32Range (hour, 0, 23))
        return VI_ERROR_PARAMETER5;
    if (rszv_invalidViInt32Range (minute, 0, 59))
        return VI_ERROR_PARAMETER6;
    if (rszv_invalidViInt32Range (second, 0, 59))
        return VI_ERROR_PARAMETER7;

    sprintf (wrtBuf, ":SYST:DATE %ld,%ld,%ld;:SYST:TIME %ld,%ld,%ld",
       year, month, day, hour, minute, second);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Copy Setting                                                   */
/*  Purpose:  This function selects window which will be printed and position*/
/*            on the printed page.                                           */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confCopySetting (ViSession instrSession, 
                ViInt32 function, ViInt32 window, ViInt32 quadrant)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (function, 0, 2))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (window, 1, 4))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViInt32Range (quadrant, 0, 4))
        return VI_ERROR_PARAMETER4;

    switch (function)
        { 
        case 0: /*- Copy Screen is selected ---------------------------------- */
              sprintf (wrtBuf, ":HCOP:ITEM:ALL;:HCOP:PAGE:DIM:%s",
                  confCopyQuad[quadrant]);
             break;
        case 1: /*- Copy Screen is selected ---------------------------------- */
              sprintf (wrtBuf, ":HCOP:ITEM:WIND%ld:TRAC:STAT ON;:HCOP:PAGE:DIM:%s",
                  window, confCopyQuad[quadrant]);
             break;
        case 2: /*- Copy Screen is selected ---------------------------------- */
              sprintf (wrtBuf, ":HCOP:ITEM:WIND%ld:TABL:STAT ON;:HCOP:PAGE:DIM:%s",
                  window, confCopyQuad[quadrant]);
             break;
        default:
              wrtBuf[0] = 0;
             break;
        }

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL))
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Comment or Label text                                          */
/*  Purpose:  This functions enters commentary for individual diagrams       */
/*            or label.                                                      */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confCopyComment (ViSession instrSession,
                ViInt32 channel, ViString comment)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];
    
    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;

    if (comment)
        {
        if (strlen (comment) > 120)
            return VI_ERROR_PARAMETER3;
        }
    else
        return VI_ERROR_PARAMETER3;

    sprintf (wrtBuf, ":HCOP:ITEM:WIND%ld:TEXT \"%s\"", channel, comment);  

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}                                       
                           
/*===========================================================================*/
/*  Function: Device Setting                                                 */
/*  Purpose:  This function selection/configuration of the two output devices*/
/*            and for the connection of the devices to an output medium.     */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confDeviceSetting (ViSession instrSession,
          ViBoolean device, ViInt32 language, ViInt32 connection,
          ViString fileName, ViInt32 GPIBAddress,
          ViBoolean deviceReset, ViBoolean formfeed, ViBoolean paperfeed,
          ViBoolean orientation)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      buffer[BUFFER_SIZE];
    ViByte      wrtBuf[BUFFER_SIZE*2];

    if (rszv_invalidViBooleanRange (device))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (language, 0, 13))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViInt32Range (connection, 0, 4))
        return VI_ERROR_PARAMETER4;
    if (fileName)
        {
        if (strlen (fileName) > 120)
            return VI_ERROR_PARAMETER5;
        }
    else
        return VI_ERROR_PARAMETER5;
    if (rszv_invalidViInt32Range (GPIBAddress, 0, 30))
        return VI_ERROR_PARAMETER6;
    if (rszv_invalidViBooleanRange (deviceReset))
        return VI_ERROR_PARAMETER7;
    if (rszv_invalidViBooleanRange (formfeed))
        return VI_ERROR_PARAMETER8;
    if (rszv_invalidViBooleanRange (paperfeed))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rszv_invalidViBooleanRange (orientation))
        return VI_ERROR_INSTR_PARAMETER10;

    if (device == VI_FALSE)
        {
    /*- Seting Device 1 -------------------------------------------------------*/
         sprintf (buffer, ":HCOP:DEV:LANG1 %s;PRES1 %s;:HCOP:PAGE:ORI1 %s"
         ";:HCOP:ITEM:FFE1:STAT %s;:HCOP:ITEM:PFE1:STAT %s;:HCOP:DEST1 \"%s\"",
              confCopyLang[language], confStates[(deviceReset==VI_TRUE)?1:0],
              confCopyOri[(orientation==VI_TRUE)?1:0],
              confStates[(formfeed==VI_TRUE)?1:0], confStates[(paperfeed==VI_TRUE)?1:0],
              confCopyDes[connection]);
        }
    else
        {
        /*- Seting Device 2 -------------------------------------------------------*/
         sprintf (buffer, ":HCOP:DEV:LANG2 %s;PRES2 %s;:HCOP:PAGE:ORI2 %s"
         ";:HCOP:ITEM:FFE2:STAT %s;:HCOP:ITEM:PFE2:STAT %s;:HCOP:DEST2 \"%s\"",
              confCopyLang[language], confStates[(deviceReset==VI_TRUE)?1:0],
              confCopyOri[(orientation==VI_TRUE)?1:0],
              confStates[(formfeed==VI_TRUE)?1:0], confStates[(paperfeed==VI_TRUE)?1:0],
              confCopyDes[connection]);
        }

    /*- Printed to File --------------------------------------------------------*/
    if (connection == 4)
        sprintf (wrtBuf, "%s;:MMEM:NAME \"%s\"", buffer, fileName);

    /*- GPIB Conection ---------------------------------------------------------*/
    if (connection == 3)
        sprintf (wrtBuf, "%s;:SYST:COMM:GPIB:RDEV:PRIN%ld:ADDR %ld", buffer,
            (ViInt32)((device==VI_TRUE) ? 2 : 1), GPIBAddress);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/* Function: Hardcopy Device                                                 */
/* Purpose:  This function selects the interface and configuration for the   */
/*           hardcopy. The destination, data format, paper feed, form feed,  */
/*           and preset are also configured.                                 */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confHCDevice (ViSession instrSession,
                ViInt32 deviceNumber, ViInt32 dataFormat, ViInt32 destination,
                ViInt32 GPIBAddress, ViBoolean preset, ViBoolean formFeed,
                ViBoolean paperFeed, ViBoolean resolution, ViBoolean pageOrientation)
{
    ViChar      wrtBuf[BUFFER_SIZE],
                buffer[BUFFER_SIZE];
    ViStatus    rszv_status = VI_SUCCESS;

    if (rszv_invalidViInt32Range (deviceNumber, 1, 2))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (dataFormat, 0, 17))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViInt32Range (destination, 0, 4))
        return VI_ERROR_PARAMETER4;
    if (rszv_invalidViBooleanRange (preset))
        return VI_ERROR_PARAMETER6;
    if (rszv_invalidViBooleanRange (formFeed))
        return VI_ERROR_PARAMETER7;
    if (rszv_invalidViBooleanRange (paperFeed))
        return VI_ERROR_PARAMETER8;
    if (rszv_invalidViBooleanRange (resolution))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rszv_invalidViBooleanRange (pageOrientation))
        return VI_ERROR_INSTR_PARAMETER10;

    sprintf (buffer, "HCOPY:DEV:LANG%ld %s;:HCOPY:DEST%ld '%s'"
        ";:HCOPY:DEV:PRES%ld %s;:HCOP:ITEM:FFE%ld:STAT %s"
        ";:HCOP:ITEM:PFE%ld:STAT %s;:HCOP:DEV:RES%ld %s;:HCOP:PAGE:ORI%ld %s",
        deviceNumber, confDataFormatArr[dataFormat], deviceNumber,
        confCopyDes[destination], deviceNumber, confStates[preset],
        deviceNumber, confStates[formFeed], deviceNumber, confStates[paperFeed],
        deviceNumber, confCopyRes[resolution], deviceNumber,
        confCopyOri[pageOrientation]);

    if (destination == 0) /* GPIB */ 
        {
        if (rszv_invalidViInt32Range (GPIBAddress, 1, 30))
            return VI_ERROR_PARAMETER5;
        sprintf (wrtBuf, "%s;:SYST:COMM:GPIB:RDEV%ld:ADDR %ld", buffer,
                 deviceNumber, GPIBAddress);
        }

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Color Setting                                                  */
/*  Purpose:  This function selects between color and monochrome printout.   */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confColorSetting (ViSession instrSession,
                ViBoolean color)

{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViBooleanRange (color))
        return VI_ERROR_PARAMETER2;

    sprintf (wrtBuf, ":HCOP:DEV:COL %s", confStates[color]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Sweep Coupling                                                 */
/*  Purpose:  This function sets the sweep coupling.                         */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confSweepCoupling (ViSession instrSession,
                   ViBoolean coupledChannels)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViBooleanRange (coupledChannels))
        return VI_ERROR_PARAMETER2;

    sprintf (wrtBuf, ":INST:COUP %s", confSweCoup[(coupledChannels==VI_TRUE)?1:0]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite( instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Sweep Mode                                                     */
/*  Purpose:  This function sets the sweep in the active display channel.    */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confSweepMode (ViSession instrSession, ViInt32 channel,
                   ViInt32 sweep)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (sweep, 0, 3))
        return VI_ERROR_PARAMETER3;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    switch (sweep)
        {
        case 0: /*- Single Point is selected --------------------------------*/
               sprintf (wrtBuf, ":SENS%ld:FREQ:MODE CW", channel);
               break;
        case 1: /*- Lin Sweep is selected -----------------------------------*/
               sprintf (wrtBuf, ":SENS%ld:FREQ:MODE SWE;:SENS%ld:SWE:SPAC LIN",
                     channel, channel);
               break;
        case 2: /*- Log Sweep is selected -----------------------------------*/
               sprintf (wrtBuf, ":SENS%ld:FREQ:MODE SWE;:SENS%ld:SWE:SPAC LOG",
                     channel, channel);
               break;
        default:  /*- Seg Sweep is selected ----------------------------------*/ 
               sprintf (wrtBuf, ":SENS%ld:FREQ:MODE SEGM", channel);
               break;      
        }

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite( instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Sweep Time                                                     */
/*  Purpose:  This function sets the sweep time in the selected channel.     */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confSweepTime (ViSession instrSession, ViInt32 channel,
                   ViBoolean sweepTime,
                   ViReal64 editSweepTimes)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViBooleanRange (sweepTime))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViReal64Range (editSweepTimes,  140.96e-6, 1000.0))
        return VI_ERROR_PARAMETER4;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    if (!sweepTime)
        sprintf (wrtBuf, ":SENS%ld:SWE:TIME:AUTO %s;:SENS%ld:SWE:TIME %fs",
            channel, confStates[(sweepTime==VI_TRUE)?1:0],
            channel, editSweepTimes);
    else
        sprintf (wrtBuf, ":SENS%ld:SWE:TIME:AUTO %s", channel,
            confStates[(sweepTime==VI_TRUE)?1:0]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite( instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Sweep Number                                                   */
/*  Purpose:  This function sets the number of sweeps and continuous mode    */
/*            in the selected channel.                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confSweepNumber (ViSession instrSession, ViInt32 channel,
                   ViInt32 numberofSweeps,
                   ViBoolean continuousSweep)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (numberofSweeps, 0, 32767))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViBooleanRange (continuousSweep))
        return VI_ERROR_PARAMETER4;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    if (!continuousSweep)
        sprintf (wrtBuf, ":INIT:CONT %s;:SENS%ld:SWE:COUN %ld",
            confStates[(continuousSweep==VI_TRUE)?1:0],
            channel, numberofSweeps);
    else
        sprintf (wrtBuf, ":INIT:CONT %s",
            confStates[(continuousSweep==VI_TRUE)?1:0]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite( instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Sweep Direction                                                */
/*  Purpose:  This function sets the sweep direction in the selected channel.*/
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confSweepDirection (ViSession instrSession,
                   ViInt32 channel,
                   ViBoolean sweepDirection)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViBooleanRange (sweepDirection))
        return VI_ERROR_PARAMETER3;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":SENS%ld:SWE:DIR %s", channel,
        confSweDir[(sweepDirection==VI_TRUE)?1:0]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite( instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status; 
}

/*===========================================================================*/
/*  Function: Define Sweep Segment                                           */
/*  Purpose:  This function editing the sweep list.                          */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confSweepSegment (ViSession instrSession, ViInt32 channel,
                ViInt32 function, ViInt32 index, ViReal64 startHz, ViReal64 stopHz,
                ViInt32 points, ViReal64 sourcePowerdBm,
                ViBoolean sweepTime, ViReal64 sweeptimes,
                ViInt32 averageFactor, ViInt32 IFBandwidth, ViBoolean LOtoRF)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];
    rszv_instrRange instrPtr;

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (function, 0, 2))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViInt32Range (index, 1, 50))
        return VI_ERROR_PARAMETER4;
    if (rszv_invalidViReal64Range (startHz, instrPtr -> minFreq, instrPtr -> maxFreq))
        return VI_ERROR_PARAMETER5;
    if (rszv_invalidViReal64Range (stopHz, instrPtr -> minFreq, instrPtr -> maxFreq))
        return VI_ERROR_PARAMETER6;
    if (rszv_invalidViInt32Range (points, 1, 2001))
        return VI_ERROR_PARAMETER7;
    if (rszv_invalidViReal64Range (sourcePowerdBm, -25.0, 0.0))
        return VI_ERROR_PARAMETER8;
    if (rszv_invalidViBooleanRange (sweepTime))
        return VI_ERROR_INSTR_PARAMETER9;
    if (rszv_invalidViReal64Range (sweeptimes, 25.8182e-3, 1.0e6))
        return VI_ERROR_INSTR_PARAMETER10;
    if (rszv_invalidViInt32Range (averageFactor, 1, 1000))
        return VI_ERROR_INSTR_PARAMETER11;
    if (rszv_invalidViInt32Range (IFBandwidth, 0, 9))
        return VI_ERROR_INSTR_PARAMETER12;        
    if (rszv_invalidViBooleanRange (LOtoRF))
        return VI_ERROR_INSTR_PARAMETER13;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    switch(function)
        {
        case 0: /*- Define New Segment --------------------------------------*/ 
            if (sweepTime == VI_FALSE)
                {
                 sprintf (wrtBuf, ":SENS%ld:SEGM:DEF%ld %fHz,%fHz,%ld,%fdBm,%fs,%ld,%s,%s",
                      channel, index, startHz, stopHz, points,
                      sourcePowerdBm, sweeptimes, averageFactor,
                      confSweSegIFB[IFBandwidth],
                      confSweSegLR[(LOtoRF==VI_TRUE)?1:0]);
                }
            else
                {
                 sprintf (wrtBuf, ":SENS%ld:SEGM:DEF%ld %fHz,%fHz,%ld,%fdBm,AUTO,%ld,%s,%s",
                      channel, index, startHz, stopHz, points,
                      sourcePowerdBm, averageFactor,
                      confSweSegIFB[IFBandwidth],
                      confSweSegLR[(LOtoRF==VI_TRUE)?1:0]);
                }
            break;
        case 1:
            sprintf (wrtBuf, ":SENS%ld:SEGM:DEL%ld", channel, index);
            break;
        default: /*- Delete All Segments ---------------------------------------*/
            sprintf (wrtBuf, ":SENS%ld:SEGM:CLE", channel);
            break;
        }

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}


/*===========================================================================*/
/*  Function: Define Number of Points                                        */
/*  Purpose:  This function defining the number of sweep points.             */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confSweepNumberPoints (ViSession instrSession,
                   ViInt32 channel,
                   ViInt32 arbitraryPoints)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;  
    if (rszv_invalidViInt32Range (arbitraryPoints, 2, 2001))
        return VI_ERROR_PARAMETER3; 

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":SENS%ld:SWE:POIN %ld", channel, arbitraryPoints);
    
    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Define Lin and Log Sweep                                       */
/*  Purpose:  This function defines the step width for linear sweep or the   */
/*            number of steps per decade for the logarithmic sweep.          */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confStepSizeLinLog (ViSession instrSession,
                   ViInt32 channel,
                   ViBoolean stepSizeType,
                   ViReal64 stepSizeHz,
                   ViReal64 pointsperDec)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViBooleanRange (stepSizeType))
        return VI_ERROR_PARAMETER3;      

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    if (stepSizeType)
        {
        if (rszv_invalidViReal64Range (pointsperDec, 0.4, 354.29))
            return VI_ERROR_PARAMETER5;
        sprintf (wrtBuf, ":SENS%ld:SWE:PDEC %f", channel, pointsperDec);
        }
    else
        {
        if (rszv_invalidViReal64Range (stepSizeHz, 2.00e6, 3.99e9))
            return VI_ERROR_PARAMETER4;
        sprintf (wrtBuf, ":SENS%ld:SWE:STEP %fHz", channel, stepSizeHz);
        }

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}
                  
/*===========================================================================*/
/*  Function: Define Trigger                                                 */
/*  Purpose:  This function settings the trigger mode.                       */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confSweepTrigger (ViSession instrSession,
                ViInt32 defineTrigger, ViReal64 triggerDelays,
                ViBoolean trigger, ViBoolean slope, ViReal64 timerPeriods,
                ViInt32 hours, ViInt32 minutes, ViInt32 seconds)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (defineTrigger, 0, 5))
        return VI_ERROR_PARAMETER2;
    if (defineTrigger)
        {
        if (rszv_invalidViReal64Range (triggerDelays, 0.0, 255.0))
            return VI_ERROR_PARAMETER3;
        if (rszv_invalidViBooleanRange (trigger))
            return VI_ERROR_PARAMETER4;
        }

    switch(defineTrigger)
        { 
        case 0: /*- Immediate trigger is selected ---------------------------*/
            sprintf (wrtBuf, ":TRIG:SOUR IMM");
            break;
        case 1: /*- External trigger is selected ----------------------------*/
            if (rszv_invalidViBooleanRange (slope))
                return VI_ERROR_PARAMETER5;
            sprintf (wrtBuf, ":TRIG:SOUR EXT;HOLD %fs;LINK \"%s\";SLOP %s",
                triggerDelays, confSweTrigLink[(trigger==VI_TRUE)?1:0],
                confSweSegLR[(slope==VI_TRUE)?1:0]); 
            break;
        case 2: /*- Line trigger is selected --------------------------------*/
            sprintf (wrtBuf, ":TRIG:SOUR LINE;HOLD %fs;LINK \"%s\"",
                triggerDelays, confSweTrigLink[(trigger==VI_TRUE)?1:0]);
            break;
        case 3: /*- Periodic Timer is selected ------------------------------*/
            if (rszv_invalidViReal64Range (timerPeriods, 100.0e-6, 86399.9999))
                return VI_ERROR_PARAMETER6;

            sprintf (wrtBuf, ":TRIG:SOUR TIM;LINK \"%s\";TIM %fs",
            confSweTrigLink[(trigger==VI_TRUE)?1:0], timerPeriods); 
            break;
        case 4: /*- Real Time Clock is selected -----------------------------*/
            sprintf (wrtBuf, ":TRIG:SOUR RTCL;HOLD %fs;LINK \"%s\";RTCL %ld,%ld,%ld",
                triggerDelays, confSweTrigLink[(trigger==VI_TRUE)?1:0],
                hours, minutes, seconds);
            break;
        case 5: /*- Manual trigger is selected ------------------------------*/
            if (rszv_invalidViInt32Range (hours, 0, 23))
                return VI_ERROR_PARAMETER7;
            if (rszv_invalidViInt32Range (minutes, 0, 59))
                return VI_ERROR_PARAMETER8;
            if (rszv_invalidViInt32Range (seconds, 0, 59))
                return VI_ERROR_INSTR_PARAMETER9;

            sprintf (wrtBuf, ":TRIG:SOUR MAN;HOLD %fs;LINK \"%s\"",
                triggerDelays, confSweTrigLink[(trigger==VI_TRUE)?1:0]);
            break;
        }

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Source Configuration                                           */
/*  Purpose:  This function setting the fixed parameter of the sweep.        */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confSweepSource (ViSession instrSession, ViInt32 channel,
                ViInt32 source, ViReal64 parameter, ViInt32 unit)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];
    ViReal64    min = 0.0,
                max = 0.0;
    ViBoolean   isRange = VI_TRUE;

    if (rszv_invalidViInt32Range (source, 0, 14))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViInt32Range (unit, 0, 6))
        return VI_ERROR_PARAMETER5;
    switch (source)
        {
        case 0:
            min = -27.0; max = 20.0;
            if (unit != 4)
                return VI_ERROR_PARAMETER5;
            break;
        case 1:
            min = -40.0; max = 40.0;
            if (unit != 6)
                return VI_ERROR_PARAMETER5;
            break;
        case 2:
        case 3:
        case 7:
        case 10:
            min = -300.0; max = 200.0;
            if (unit != 4)
                return VI_ERROR_PARAMETER5;
            break;
        case 11:
        case 12:
        case 13:
        case 14:
            min = 0.0; max = 70.0;
            if (unit != 5)
                return VI_ERROR_PARAMETER5;
            break;
        case 4:
            {
            ViReal64 tmpArr[]={0, 1.0e3, 1.0e6, 1.0e9};
            ViReal64 newParam;
            rszv_instrRange instrPtr;

            isRange = VI_FALSE;
            if (unit > 3)
                return VI_ERROR_PARAMETER5;
            
            newParam = (tmpArr[unit]) ? parameter*tmpArr[unit] : parameter;
            CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));

            if (rszv_invalidViReal64Range (newParam, instrPtr -> minFreq, instrPtr -> maxFreq))
                return VI_ERROR_PARAMETER4;
            }
            break;
        default:
            isRange = VI_FALSE;
            break;
        }

    if (isRange)
        {
        if (rszv_invalidViReal64Range (parameter, min, max))
            return VI_ERROR_PARAMETER4;
        }

    if (source > 10)
        { /*- General setting -----------------------------------------------*/
        sprintf (wrtBuf, ":%s %f%s", confSweSource[source], parameter,
             confUnitArr[unit]);
        } 
    else 
        { /*- Channel specific setting --------------------------------------*/
        if (rszv_invalidViInt32Range (channel, 1, 4))
            return VI_ERROR_PARAMETER2;

        CHECKERR( rszv_isChanDispCache (instrSession, channel));
        sprintf (wrtBuf, ":SOUR%ld:%s %f%s", channel, confSweSource[source],
             parameter, confUnitArr[unit]);  
        }

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Source Configuration                                           */
/*  Purpose:  This function configures additional power for the specified    */
/*            port.                                                          */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confSweepSourcePower (ViSession instrSession, ViInt32 port1,
                                             ViInt32 port2)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];
    rszv_instrRange instrPtr;

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));
    if (!isZVMK(instrPtr -> instType))
        return RSZV_ERROR_OPTION_NOT_AVAILABLE;

    if (isZVR_B21(instrPtr -> options))
        {
        if (rszv_invalidViInt32Range (port1, 0, 1))
            return VI_ERROR_PARAMETER2;

        sprintf (wrtBuf, ":OUTP1:POW %s;", confSourcePower[port1]);
        }
    else if (port1 != 0)
        return VI_ERROR_PARAMETER2;

    if (isZVR_B22(instrPtr -> options))
        {
        if (rszv_invalidViInt32Range (port2, 0, 1))
            return VI_ERROR_PARAMETER3;

        sprintf (wrtBuf, ":OUTP1:POW %s;:OUTP2:POW %s",
            confSourcePower[port1],
            confSourcePower[port2]);
        }
    else if (port2 != 0)
        return VI_ERROR_PARAMETER3;

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Avg Configuration                                              */
/*  Purpose:  This function setting the averaging function.                  */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confSweepAvg (ViSession instrSession, ViInt32 channel,
                ViBoolean average, ViInt32 avgFactor, ViBoolean avgType)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;  
    if (rszv_invalidViBooleanRange (average))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViInt32Range (avgFactor, 0, 10000))
        return VI_ERROR_PARAMETER4;
    if (rszv_invalidViBooleanRange (avgType))
        return VI_ERROR_PARAMETER5;
    
    CHECKERR( rszv_isChanDispCache (instrSession, channel));
    
    if (average)
        {
        sprintf (wrtBuf, ":SENS%ld:AVER:STAT %s;COUNT %ld;MODE %s",
             channel, confStates[(average==VI_TRUE)?1:0], avgFactor,
             confSweAveType[(avgType==VI_TRUE)?1:0]);
       }
    else
       sprintf (wrtBuf, ":SENS%ld:AVER:STAT OFF", channel);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Bandwidth                                                      */
/*  Purpose:  This function setting the bandwidth of the digital receiver    */
/*            filter on the intermediate frequency.                          */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confSweepBandwidth (ViSession instrSession, ViInt32 channel,
                                           ViInt32 IFBandwidth)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];
    
    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;  
    if (rszv_invalidViInt32Range (IFBandwidth, 0, 9))
        return VI_ERROR_PARAMETER6;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":SENS%ld:BAND %s", channel, confSweSegIFB[IFBandwidth]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Meas Configuration                                             */
/*  Purpose:  This function selects measurement of S-parameters.             */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confResMeas (ViSession instrSession, ViInt32 channel,
                ViInt32 meas, ViInt32 complexConvers)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE],
                buffer[BUFFER_SIZE/2];
    ViInt32     swType = RSZV_FREQ_SWEEP;
    rszv_instrRange instrPtr;

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (meas, 0, 25))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViInt32Range (complexConvers, 0, 5))
        return VI_ERROR_PARAMETER4;
    
    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));
    if (isZVRL(instrPtr->instType))
        {
        if (meas > 1)
            return VI_ERROR_PARAMETER3;
        }

    /*- Type of Sweep -------------------------------------------------------*/
    CHECKERR( rszv_getSweepMode( instrSession, channel, &swType));

    if (meas < 4)
        sprintf (buffer, ";:CALC%ld:TRAN:COMP %s", channel, confMeasConv[complexConvers]);
    else
        buffer[0] = 0;

    switch(swType)
        {
        /*- Frequency Sweep is set ------------------------------------------*/
        case RSZV_FREQ_SWEEP:
          sprintf (wrtBuf, ":SENS%ld:FUNC \"%s\"%s", channel, confMeasSFRE[meas],
            buffer);
            break;
        /*- Power Sweep is set ----------------------------------------------*/
        case RSZV_POWER_SWEEP:
            sprintf (wrtBuf, ":SENS%ld:FUNC \"%s\"%s", channel, confMeasSPOW[meas],
            buffer);
            break;
        /*- Time Sweep is set -----------------------------------------------*/
        case RSZV_TIME_SWEEP:
            sprintf (wrtBuf, ":SENS%ld:FUNC \"%s\"%s", channel, confMeasSTIM[meas],
            buffer);
            break;
        }

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Input Configuration                                            */
/*  Purpose:  This function direct measurement of the input signals to the   */
/*            instrument.                                                    */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confResMeasInput (ViSession instrSession, ViInt32 channel,
                ViInt32 input, ViBoolean drivePort, ViInt32 unit)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE],
                buffer[BUFFER_SIZE/2];
    ViInt32     swType;
    rszv_instrRange instrPtr;

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (input, 0, 3))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViBooleanRange (drivePort))
        return VI_ERROR_PARAMETER4;
    if (rszv_invalidViInt32Range (unit, 0, 9))
        return VI_ERROR_PARAMETER5;

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));
    if (isZVRL(instrPtr->instType))
        {
        if (input == 3)
            return VI_ERROR_PARAMETER3;
        }

    /*- Type of Sweep ---------------------------------------------------------*/
    CHECKERR( rszv_getSweepMode( instrSession, channel, &swType));

    if (isZVRL(instrPtr->instType) && (!(instrPtr -> externalMeas)))
        /*- Not supported for ZVRL ----------------------------------------*/
        sprintf (buffer, ";:OUTP:DPORT %s", confMeasPort[(drivePort==VI_TRUE)?1:0]);
    else
        buffer[0] = 0;

    switch(swType)
        {
        /*- Frequency Sweep is set ------------------------------------------*/
        case RSZV_FREQ_SWEEP:
                sprintf (wrtBuf, ":SENS%ld:FUNC \"%s\";:CALC%ld:UNIT:POW:%s%s",
                     channel, confMeasIFRE[input], channel,
                     confMeasInput[input], confMeasInpUn[unit], buffer);
               break;
        /*- Power Sweep is set ----------------------------------------------*/
        case RSZV_POWER_SWEEP: 
                sprintf (wrtBuf, ":SENS%ld:FUNC \"%s\";:CALC%ld:UNIT:POW:%s%s",
                     channel, confMeasIPOW[input], channel,
                     confMeasInput[input], confMeasInpUn[unit], buffer);
               break;
        /*- Time Sweep is set -----------------------------------------------*/               
        case RSZV_TIME_SWEEP:
                sprintf (wrtBuf, ":SENS%ld:FUNC \"%s\";:CALC%ld:UNIT:POW:%s%s",
                     channel, confMeasITIM[input], channel,
                     confMeasInput[input], confMeasInpUn[unit], buffer);
               break;
        }

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Ratio Configuration                                            */
/*  Purpose:  This function calculations of any desired quotients from the   */
/*            input signals.                                                 */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confResMeasRatio (ViSession instrSession, ViInt32 channel,
                ViInt32 ratio, ViBoolean drivePort, ViInt32 numerator,
                ViInt32 denominator)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE],
                buffer[BUFFER_SIZE/2];
    ViInt32     swType;
    rszv_instrRange instrPtr;

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;  
    if (rszv_invalidViInt32Range (ratio, 0, 8))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViBooleanRange (drivePort))
        return VI_ERROR_PARAMETER4;
    if (rszv_invalidViInt32Range (numerator,0,5))
        return VI_ERROR_PARAMETER5;
    if (rszv_invalidViInt32Range (denominator,0,5))
        return VI_ERROR_PARAMETER6;

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));
    if (instrPtr -> externalMeas)
        if (ratio == 4 || ratio == 5)
            return VI_ERROR_PARAMETER3;
        else if (ratio == 8)
            if ((numerator == 1 || numerator == 2) && denominator == 3)
                return VI_ERROR_PARAMETER6;

    /*- Type of Sweep ---------------------------------------------------------*/
    CHECKERR( rszv_getSweepMode( instrSession, channel, &swType));

    if (((instrPtr -> instType) != ZVRL) && (!(instrPtr -> externalMeas)))
         /*- Not supported for ZVRL ----------------------------------------*/
        sprintf (buffer, ";:OUTP:DPORT %s", confMeasPort[(drivePort==VI_TRUE)?1:0]);
    else
        buffer[0] = 0;

    switch(swType)
        {
        /*- Frequency Sweep is set ------------------------------------------*/
        case RSZV_FREQ_SWEEP:
            if (ratio!=8)
                {
                sprintf (wrtBuf, ":SENS%ld:FUNC \"%s\"%s", channel,
                    confMeasRFRE[ratio], buffer);
                }
            else
                {
                /*- User Defined Ratio ------------------------------------*/
                sprintf (wrtBuf, ":SENS%ld:FUNC \"XFR:POW:RAT %s,%s\"%s",
                    channel, confMeasRatio[numerator],
                    confMeasRatio[denominator], buffer);
                }
            break;
        /*- Power Sweep is set ----------------------------------------------*/
        case RSZV_POWER_SWEEP: 
            if (ratio!=8)
                {
                sprintf (wrtBuf, ":SENS%ld:FUNC \"%s\"%s", channel,
                    confMeasRPOW[ratio], buffer);
                }
            else
                {
                /*- User Defined Ratio ------------------------------------*/
                sprintf (wrtBuf, ":SENS%ld:FUNC \"XPOW:POW:RAT %s,%s\"%s",
                    channel, confMeasRatio[numerator],
                    confMeasRatio[denominator], buffer);
                }
            break;
        /*- Time Sweep is set -----------------------------------------------*/
        case RSZV_TIME_SWEEP: 
            if (ratio!=8)
                {
                sprintf (wrtBuf, ":SENS%ld:FUNC \"%s\"%s", channel,
                    confMeasRTIM[ratio], buffer);
                }
            else
                {
                /*- User Defined Ratio ------------------------------------*/
                sprintf (wrtBuf, ":SENS%ld:FUNC \"XTIM:POW:RAT %s,%s\"%s",
                    channel, confMeasRatio[numerator],
                    confMeasRatio[denominator], buffer);
                }
            break;
    }

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Format Configuration                                           */
/*  Purpose:  This function defines in witch form the complex measured       */
/*            quantity selected is displayed.                                */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confResFormat (ViSession instrSession, ViInt32 channel,
                ViInt32 format)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (format, 0, 9))
        return VI_ERROR_PARAMETER3;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":CALC%ld:FORM %s", channel, confResForm[format]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*============================================================================*/
/*  Function: Group Delay Configuration                                       */
/*  Purpose:  This function defines parameters for group delay display format.*/
/*============================================================================*/
ViStatus _VI_FUNC rszv_confResFormatGDelay (ViSession instrSession,
                ViInt32 channel, ViBoolean apertureMode,
                ViInt32 stepAperture, ViReal64 frequencyApertureHz)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];
    rszv_instrRange instrPtr;

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViBooleanRange (apertureMode))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViInt32Range (stepAperture, 1, 2001))
        return VI_ERROR_PARAMETER4;
    
    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));
    if (rszv_invalidViReal64Range (frequencyApertureHz, 10.0e-6, ((instrPtr->maxFreq) / 2.0)))
        return VI_ERROR_PARAMETER5;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    if (apertureMode == VI_TRUE)
        sprintf (wrtBuf, ":CALC%ld:GDAP:MODE %s;:CALC%ld:GDAP %fHz",
            channel, confResForMod[(apertureMode==VI_TRUE)?1:0],
            channel, frequencyApertureHz);
    else
        sprintf (wrtBuf, ":CALC%ld:GDAP:MODE %s;SCO %ld", channel,
            confResForMod[(apertureMode==VI_TRUE)?1:0], stepAperture);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Scale Configuration                                            */
/*  Purpose:  This function scaling the test diagram in the active display   */
/*            channel.                                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confResScale (ViSession instrSession, ViInt32 channel,
                ViInt32 function, ViReal64 parameter, ViInt32 unit)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (function, 1, 6))
        return VI_ERROR_PARAMETER3;

    if (function == 3)
        { /*- Reference position is selected -------------------*/
        if (rszv_invalidViReal64Range (parameter, 0.0, 100.0))
            return VI_ERROR_PARAMETER4;
        }

    if (rszv_invalidViInt32Range (unit, 0, 54))
        return VI_ERROR_PARAMETER5;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":DISP:WIND%ld:TRAC:Y:%s %f%s", channel,
         confResScale[function], parameter, confResScaleUnit[unit]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Diagram Configuration                                          */
/*  Purpose:  This function selects the diagram for the display of measured  */
/*            values.                                                        */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confDiagram (ViSession instrSession,
                ViInt32 channel, ViInt32 diagramType)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (diagramType, 0, 10))
        return VI_ERROR_PARAMETER3;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));
    sprintf (wrtBuf, ":DISP:WIND%ld:DIAG %s", channel,
        confResDiagram[diagramType]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Display Configuration                                          */
/*  Purpose:  This function configures the whole screen.                     */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confDisplay (ViSession instrSession, ViInt32 displayType,
                ViBoolean expand)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      buffer[BUFFER_SIZE];
    ViInt32     tmpChan;
    rszv_instrRange instrPtr;

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));

    if (rszv_invalidViInt32Range (displayType, 0, 5))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViBooleanRange (expand))
        return VI_ERROR_PARAMETER3;

    CHECKERR( viQueryf (instrSession, ":DISP:FORM %s;FORM:EXP %s;:INST?\n",
        "%[^\r\n]", confResDisplay[displayType], confStates[(expand==VI_TRUE)?1:0], buffer));

    CHECKERR( rszv_sysStatus (instrSession));
    
    if (displayType < 3)
        {
        sscanf((ViChar *)buffer, "CHANNEL%ld", &tmpChan);
        instrPtr -> displayChannels = (1 << tmpChan);
        if (displayType != 0)
            instrPtr -> displayChannels |= (tmpChan % 2) ? (1<<(tmpChan+1)) : (1<<(tmpChan-1));
        }
    else
        instrPtr -> displayChannels = 0x1E;

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Trace Smoothing Configuration                                  */
/*  Purpose:  This function is defines trace smoothing for selected channel. */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confTraceSmoothing (ViSession instrSession,
                   ViInt32 channel, ViBoolean smoothing,
                   ViReal64 smoothingAperture)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViBooleanRange (smoothing))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViReal64Range (smoothingAperture, 0.05, 100.0))
        return VI_ERROR_PARAMETER4;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    if (smoothing)
        sprintf (wrtBuf, ":CALC%ld:SMO:APER %f;STAT ON", channel, smoothingAperture);
    else
        sprintf (wrtBuf, ":CALC%ld:SMO:STAT OFF", channel);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Define Math                                                    */
/*  Purpose:  This function is defines math functions for selected channel.  */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confDefineMath (ViSession instrSession, ViInt32 channel,
                   ViInt32 operand1, ViInt32 operator1, ViInt32 operand2,
                   ViInt32 operator2, ViInt32 operand3)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (operand1, 0, 11))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViInt32Range (operator1, 0, 4))
        return VI_ERROR_PARAMETER4;
    if (rszv_invalidViInt32Range (operand2, 0, 11))
        return VI_ERROR_PARAMETER5;
    if (rszv_invalidViInt32Range (operator2, 0, 4))
        return VI_ERROR_PARAMETER6;
    if (rszv_invalidViInt32Range (operand3, 0, 11))
        return VI_ERROR_PARAMETER7;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    if (operator2 == 4)
        { /*- Only Two operands -------------------------------*/
        sprintf (wrtBuf, ":CALC%ld:MATH (%s%s%s)", channel,
            confChannelMem[operand1], confMath[operator1],
            confChannelMem[operand2]);
        }
    else
        { /*- all operands are active -------------------------*/
        sprintf (wrtBuf, ":CALC%ld:MATH ((%s%s%s)%s%s)", channel,
            confChannelMem[operand1], confMath[operator1],
            confChannelMem[operand2], confMath[operator2],
            confChannelMem[operand3]);
        }

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Trace Configuration                                            */
/*  Purpose:  This function storing and mathematically manipulating measured */
/*            traces.                                                        */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confTraceOperations (ViSession instrSession, ViInt32 channel,
                   ViInt32 function,
                   ViInt32 selectDefaults)
{ 
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];
    ViBoolean   isTwo = VI_FALSE;
    
    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (function, 0, 5))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViInt32Range (selectDefaults, 1, 8))
        return VI_ERROR_PARAMETER4;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    switch(function)
        {
        case 0: /*- Show Data selected --------------------------------------*/
               sprintf (wrtBuf, ":CALC%ld:MATH:STAT OFF;:DISP:WIND%ld:TRAC2 OFF",
                    channel, channel);
               break;
        case 1: /*- Show Data and Memory selected ---------------------------*/
               sprintf (wrtBuf, ":TRAC:FEED CH%ldMEM,MDATA%ld;:CALC%ld:MATH:STAT OFF;:DISP:WIND%ld:TRAC2 ON",
                    channel, selectDefaults, channel, channel);
               isTwo = VI_TRUE;
               break;
        case 2: /*- Show Math selected --------------------------------------*/
               sprintf (wrtBuf, ":CALC%ld:MATH:STAT ON;:DISP:WIND%ld:TRAC2 OFF",
                    channel, channel);
               break;
        case 3: /*- Show Math and Memory selected ---------------------------*/
               sprintf (wrtBuf, ":TRAC:FEED CH%ldMEM,MDATA%ld;:CALC%ld:MATH:STAT ON;:DISP:WIND%ld:TRAC2 ON",
                    channel, selectDefaults, channel, channel);
               isTwo = VI_TRUE;
               break;
        case 4: /*- Show Memory selected ------------------------------------*/
                sprintf (wrtBuf, ":TRAC:FEED CH%ldMEM,MDATA%ld;:CALC%ld:MATH:STAT OFF;:DISP:WIND%ld:TRAC2 ON;TRAC1 OFF",
                    channel, selectDefaults, channel, channel);
                break;
        default: /*- Data to Memory selected ---------------------------------*/
               sprintf (wrtBuf, ":TRAC:COPY MDATA%ld,CH%ldDATA",
                    selectDefaults, channel);
               break;
        }

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    if (function != 4)
        {
        rszv_instrRange instrPtr;

        CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));
        instrPtr->disp2trace[channel-1] = isTwo;
        }

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Marker Configuration                                           */
/*  Purpose:  This function defines each of the eight markers.               */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confMarker (ViSession instrSession, ViInt32 channel,
                ViInt32 marker, ViReal64 position, ViInt32 unit, ViBoolean state,
                ViBoolean trace)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];
    rszv_instrRange instrPtr;

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (marker, 1, 8))
        return VI_ERROR_PARAMETER3;  
    if (rszv_invalidViReal64Range (position, instrPtr -> minPow, instrPtr -> maxFreq))
        return VI_ERROR_PARAMETER4;
    if (rszv_invalidViInt32Range (unit, 0, 2))
        return VI_ERROR_PARAMETER5;
    if (rszv_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER6;
    if (rszv_invalidViBooleanRange (trace))
        return VI_ERROR_PARAMETER7;

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));
    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    if (state == VI_TRUE)
        {
        if (instrPtr->disp2trace[channel-1])
            sprintf (wrtBuf, ":CALC%ld:MARK%ld:STAT %s;X %f%s;TRAC %s",
                channel, marker, confStates[(state==VI_TRUE)?1:0], position,
                confMarkUnits[unit], confMarkTrace[(trace==VI_TRUE)?1:0]);
        else
            sprintf (wrtBuf, ":CALC%ld:MARK%ld:STAT %s;X %f%s",
                channel, marker, confStates[(state==VI_TRUE)?1:0], position,
                confMarkUnits[unit]);
        }
    else
        /*- Switch Off marker --------------------------------------------*/
        sprintf (wrtBuf, ":CALC%ld:MARK%ld:STAT OFF", channel, marker);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Marker Mode                                                    */
/*  Purpose:  This function defines marker mode and enables/diables marker   */
/*            coupling.                                                      */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confMarkerMode (ViSession instrSession, ViInt32 channel,
                   ViBoolean coupled, ViBoolean markerMode)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViBooleanRange (coupled))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViBooleanRange (markerMode))
        return VI_ERROR_PARAMETER4;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":CALC%ld:MARK:COUP %s;MODE %s", channel,
        confStates[(coupled==VI_TRUE)?1:0], confMarkMode[(markerMode==VI_TRUE)?1:0]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;

}

/*===========================================================================*/
/*  Function: Marker Convers                                                 */
/*  Purpose:  This function sets the conversion of the marker values.        */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confMarkerConvers (ViSession instrSession,
                ViInt32 channel, ViInt32 conversion)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (conversion, 0, 5))
        return VI_ERROR_PARAMETER3;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":CALC%ld:MARK:TRAN:COMP %s", channel,
        confMarkConv[conversion]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Marker Format                                                  */
/*  Purpose:  This function sets the format of the marker values of the      */
/*            selected display channel.                                      */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confMarkerFormat (ViSession instrSession,
                ViInt32 channel, ViInt32 format)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (format, 0, 12))
        return VI_ERROR_PARAMETER3;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":CALC%ld:MARK:FORM %s", channel, confMarkForm[format]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Search Configuration                                           */
/*  Purpose: This function positions a marker to significant points on the   */
/*           trace.                                                          */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confMarkerSearch (ViSession instrSession, ViInt32 channel,
                ViInt32 searchMode, ViReal64 target, ViInt32 targetUnit,
                ViBoolean filterType, ViInt32 filterFunction, ViReal64 widthdB,
                ViBoolean tracking)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE*2],
                buffer[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViBooleanRange (tracking))
        return VI_ERROR_PARAMETER8;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    switch(searchMode)
        {
        case 0: /*- Max Mode selected ---------------------------------------*/
               sprintf (buffer, ":CALC%ld:MARK:FUNC MAX", channel);
               break;
        case 1: /*- Min Mode selected ---------------------------------------*/
               sprintf (buffer, ":CALC%ld:MARK:FUNC MIN", channel); 
               break;
        case 2: /*- Target Mode selected ------------------------------------*/
               if (rszv_invalidViInt32Range (searchMode, 0, 3))
                    return VI_ERROR_PARAMETER3;
               if (rszv_invalidViInt32Range (targetUnit, 0, 8))
                    return VI_ERROR_PARAMETER5;

               sprintf (buffer, ":CALC%ld:MARK:FUNC:SEL TARG;TARG %f%s",
                    channel, target, confMarkSeaUni[targetUnit]);
               break;
        case 3: /*- Band Filter Mode selected -------------------------------*/
               if (rszv_invalidViBooleanRange (filterType))
                    return VI_ERROR_PARAMETER6;
               if (rszv_invalidViInt32Range (filterFunction, 0, 3))
                    return VI_ERROR_PARAMETER7;

               if (filterFunction == 0)
               /*- Width selected ----------------*/
                   sprintf (buffer, ":CALC%ld:MARK:FUNC:BWID:MODE %s;"
                       ":CALC%ld:MARK:FUNC:%s%fdB;:CALC%ld:MARK:FUNC BFIL",
                       channel, confMarkSeaBFM[(filterType==VI_TRUE)?1:0],
                       channel, confMarkSeaFun[filterFunction], widthdB,
                       channel);
               else
                   sprintf (buffer, ":CALC%ld:MARK:FUNC:BWID:MODE %s;"
                       ":CALC%ld:MARK:FUNC:%s;:CALC%ld:MARK:FUNC BFIL",
                       channel, confMarkSeaBFM[(filterType==VI_TRUE)?1:0],
                       channel, confMarkSeaFun[filterFunction], channel);
               break;
        default:
            buffer[0] = 0;
        break;
        }

    sprintf (wrtBuf, "%s;:CALC%ld:MARK:SEAR:TRAC %s", buffer, channel,
        confStates[(tracking==VI_TRUE)?1:0]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Delta Configuration                                            */
/*  Purpose:  This function defines delta markers.                           */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confMarkerDelta (ViSession instrSession, ViInt32 channel,
                ViInt32 referenceMarker, ViBoolean peaktoPeak,
                ViBoolean deltaState, ViReal64 fixedPosStimulus,
                ViReal64 fixedPosXVal, ViReal64 fixedPosYVal,
                ViInt32 stimulusUnit)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      buffer[BUFFER_SIZE];
    rszv_instrRange instrPtr;

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (referenceMarker, 1, 9))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViBooleanRange (peaktoPeak))
        return VI_ERROR_PARAMETER4;
    if (rszv_invalidViBooleanRange (deltaState))
        return VI_ERROR_PARAMETER5;
    if (rszv_invalidViReal64Range (fixedPosStimulus, -25.0, instrPtr -> maxFreq))
        return VI_ERROR_PARAMETER6;
    if (rszv_invalidViInt32Range (stimulusUnit, 0, 2))
        return VI_ERROR_INSTR_PARAMETER9;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (buffer, ":CALC%ld:MARK:FUNC:DELT:REF %s;STAT %s;:CALC%ld:MARK:FUNC:PTP:STAT %s",
       channel, confMarkDelta[referenceMarker-1],
       confStates[(deltaState==VI_TRUE)?1:0], channel, confStates[(peaktoPeak==VI_TRUE)?1:0]);

    sprintf(buffer+strlen(buffer),"\n"); 
    CHECKERR( viWrite (instrSession, buffer, strlen (buffer), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    if ((referenceMarker==9) && (deltaState==VI_TRUE))
        { /*- Fixed Pos is selected */
        /*- Format of Diagram -----------------------------------------------*/

        CHECKERR( viQueryf (instrSession, ":CALC%ld:FORM?\n", "%[^\r\n]", channel, buffer));

        /*- Testing Response ----------------------------------------------*/
        if (!strstr (buffer, "COMP"))
            {
            /*- Complex Format Selected -------------------------------------*/
            sprintf (buffer, ":CALC%ld:MARK:FUNC:DELT:REF:RPOS:POL %f%s,%f,%f",
                channel, fixedPosStimulus, confMarkUnits[stimulusUnit],
                fixedPosXVal, fixedPosYVal);
            }
        else
            { /*- Complex Format NOT selected -------------------------------*/
            sprintf (buffer, ":CALC%ld:MARK:FUNC:DELT:REF:RPOS %f%s,%f",
                channel, fixedPosStimulus, confMarkUnits[stimulusUnit],
                fixedPosYVal);
            }

        sprintf(buffer+strlen(buffer),"\n"); 
        CHECKERR( viWrite (instrSession, buffer, strlen (buffer), VI_NULL));
        CHECKERR( rszv_sysStatus (instrSession));
        }

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Marker Equal Configuration                                     */
/*  Purpose:  This function assignes stimulus or measured values of the      */
/*            selected marker to specific parameters.                        */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confMarkerEqlMkr (ViSession instrSession, ViInt32 channel,
                ViInt32 selectedMarker, ViInt32 markerEqual)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];
    
    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (selectedMarker, 1, 8))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViInt32Range (markerEqual, 0, 3))
        return VI_ERROR_PARAMETER4;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":CALC%ld:MARK%ld:FUNC:%s", channel,
       selectedMarker, confMarkMkr[markerEqual]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Cal Standard Configuration                                     */
/*  Purpose:  This function                                                  */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confCalStandard (ViSession instrSession,
                                        ViInt32 selectKit, ViInt32 standard,
                                        ViString kit, ViString serialNumber,
                                        ViReal64 minFreq, ViReal64 maxFreq,
                                        ViReal64 lengthmm, ViReal64 loss,
                                        ViReal64 c0L0, ViReal64 c1L1,
                                        ViReal64 c2L2, ViReal64 c3L3,
                                        ViInt32 approximation)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];
    ViByte      buffer[BUFFER_SIZE];
    rszv_instrRange instrPtr;

    
    if (rszv_invalidViInt32Range (selectKit, 0, 7))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (standard, 0, 24))
        return VI_ERROR_PARAMETER3;
        
    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));
        
    if (kit)
        {
        if (strlen (kit) > 10)
            return VI_ERROR_PARAMETER4;
        }
    else
        return VI_ERROR_PARAMETER4;
    
    if (serialNumber)
        {
        if (strlen (serialNumber) > 15)
            return VI_ERROR_PARAMETER5;
        }
    else
        return VI_ERROR_PARAMETER5;
    
    if (rszv_invalidViInt32Range (approximation, 0, 1))
        return VI_ERROR_INSTR_PARAMETER14;
        
    /* The 2.92mm Kit is only on ZVM and ZVK available. */
    /* The N75 Ohms Kit is not available on ZVM and ZVK.*/
    if (isZVMK(instrPtr->instType))
        {
        if (selectKit==1) 
            return VI_ERROR_PARAMETER2;
        }
    else
        {
        if (selectKit==7)
            return VI_ERROR_PARAMETER2;
        }

    sprintf(wrtBuf, ":SENS:CORR:CKIT:%s:%s \"%s\",\"%s\",%fHz,%fHz", 
        confCalKit[selectKit], confCalKitSt[standard], kit, serialNumber,
        minFreq, maxFreq);

    if (!(standard == 9 || standard == 10 || standard == 11 ||  /*- Attenuation -*/
         (standard >= 21 && standard <= 24)))                   /*- Match and Sliding Match -*/
        { /*- if NOT Attenuation, Match or Sliding Match standard -*/

        sprintf(buffer, ",%fmm", lengthmm);
        strcat (wrtBuf, buffer);

        if (standard!=19 && standard!=20 &&
            standard!=12 && standard!=13 && standard!=14)
            { /*- if NOT symm. network and reflect standard -*/

            sprintf (buffer, ",%f", loss);
            strcat (wrtBuf, buffer);

            if (standard>=15 && standard<=18)
                {
                sprintf (buffer, ",%f,%f,%f,%f", c0L0, c1L1, c2L2, c3L3);
                strcat (wrtBuf, buffer);
                }
            }
        else
            { /*- symm. network and reflect standard -*/

            sprintf (buffer, ",%f,%f,%f,%f,%s", c0L0, c1L1, c2L2, c3L3,
                confCalStandardApp[approximation]);
            strcat (wrtBuf, buffer);
            }
       }

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Calibration Configuration                                      */
/*  Purpose:  This function provides auxiliary controls for system error     */
/*            correction and power calibration.                              */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confCalConfig (ViSession instrSession, ViInt32 channel,
                ViInt32 function, ViBoolean state)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (function, 0, 2))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER4;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":SENS%ld:CORR:%s %s", channel, confCalConfArr[function],
         confStates[(state==VI_TRUE)?1:0]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}                    

/*===========================================================================*/
/*  Function: Calibration Kit                                                */
/*  Purpose:  This function defines the current calibration kit for each     */
/*            connector family.                                              */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confCalKit (ViSession instrSession, ViInt32 selectKit,
                ViInt32 standard, ViString label)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];
    rszv_instrRange instrPtr;
    ViInt32     channel;

    if (rszv_invalidViInt32Range (selectKit, 0, 7))
        return VI_ERROR_PARAMETER2;

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));
    
    for (channel = 1; channel <= 4; channel++)
        if ((instrPtr -> displayChannels) & (1 << channel)) break;
        
           
    if ((selectKit == 5) || (selectKit == 6))
        {
        sprintf (wrtBuf, ":SENS%ld:CORR:CKIT %s", channel, confCalKit[selectKit]);
        }
    else
        {
        /* The 2.92mm Kit is only on ZVM and ZVK available. */
        /* The N75 ohms Kit is not available on ZVM and ZVK.*/
        if (isZVMK(instrPtr->instType))
        {
            if (selectKit==1)
                return VI_ERROR_PARAMETER2;
        }
        else
        {
            if (selectKit==7)
                return VI_ERROR_PARAMETER2;
        }
        
        if (rszv_invalidViInt32Range (standard, 0, 24))
            return VI_ERROR_PARAMETER3;

        if (label)
            {
            if (strlen (label) > 120)
                return VI_ERROR_PARAMETER4;
            }
        else
            return VI_ERROR_PARAMETER4;
        
        sprintf (wrtBuf, ":SENS%ld:CORR:CKIT %s;:SENS%ld:CORR:CKIT:%s %s,\"%s\"",
            channel, confCalKit[selectKit], channel, confCalKit[selectKit],
            confCalKitSt[standard], label);
        }

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Sensor Cal Factor                                              */
/*  Purpose:  This function defines frequency-dependent calibration factor   */
/*            for the power sensor used.                                     */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confCalSensorCalFactor (ViSession instrSession,
                ViBoolean useSensor, ViInt32 number,
                ViReal64 _VI_FAR frequencyHz[], ViReal64 _VI_FAR calFactor[])
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE],
                buffer[BUFFER_SIZE];
    ViInt32     i;

    if (rszv_invalidViBooleanRange (useSensor))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (number, 0, 20))
        return VI_ERROR_PARAMETER3;
    if (number)
        {
        if (!frequencyHz)
            return VI_ERROR_PARAMETER4;
        if (!calFactor)
            return VI_ERROR_PARAMETER5;
        }

    sprintf (wrtBuf, ":SYST:COMM:RDEV:PMET:CFAC:SEL %s;%s %ld",
        confCalSCF[(useSensor==VI_TRUE)?1:0],
        confCalSCF[(useSensor==VI_TRUE)?1:0], number);

    for (i = 0; i < number; i++)
        {
        sprintf (buffer, ",%fHz,%fPCT", frequencyHz[i], calFactor[i]);
        strcat (wrtBuf, buffer);
        }

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Power Meter Configuration                                      */
/*  Purpose:  This function configurtions of the power meter.                */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confCalPowMtrConfig (ViSession instrSession,
                ViInt32 IECAddress, ViInt32 type, ViBoolean autoZero,
                ViString userDefined)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (IECAddress, 0, 30))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (type, 0, 3))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViBooleanRange (autoZero))
        return VI_ERROR_PARAMETER4;
    if (type == 3)
        {
        if (userDefined)
            {
            if (strlen(userDefined) > 8)
                return VI_ERROR_PARAMETER5;
            }
        else
            return VI_ERROR_PARAMETER5;
        }

    sprintf (wrtBuf, ":SYST:COMM:RDEV:PMET:TYPE \"%s\";:SYST:COMM:GPIB:RDEV:PMET:ADDR %ld"
       ";:SYST:COMM:RDEV:PMET:AZER:STAT %s",
       ((type == 3) ? userDefined : confCalPMT[type]),
       IECAddress, confStates[(autoZero==VI_TRUE)?1:0]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Power Loss List                                                */
/*  Purpose:  This function defines the power loss list which may be used for*/
/*            a power calibration.                                           */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confCalPowerLoss (ViSession instrSession,
                ViInt32 numberofpairs, ViReal64 _VI_FAR frequency[],
                ViReal64 _VI_FAR attenuation[], ViBoolean state)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE],
                buffer[BUFFER_SIZE];
    ViInt32     channel;
    rszv_instrRange instrPtr;

    if (rszv_invalidViInt32Range (numberofpairs, 0, 20))
        return VI_ERROR_PARAMETER2;

    if (numberofpairs)
        {
        if (!frequency)
            return VI_ERROR_PARAMETER3;
        if (!attenuation)
            return VI_ERROR_PARAMETER4;
        if (rszv_invalidViBooleanRange(state))
            return VI_ERROR_PARAMETER5;
        }

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));
    for (channel = 1; channel <= 4; channel++)
        {
        if ((instrPtr -> displayChannels) & (1 << channel)) break;
        }

    sprintf (wrtBuf, ":SOUR%ld:POW:CORR:LLIS %ld", channel, numberofpairs);

    if (numberofpairs)
        {
        int i;

        for (i = 0; i < numberofpairs; i++)
            {
            sprintf (buffer, ",%fHZ,%fDB", frequency[i], attenuation[i]);
            strcat (wrtBuf, buffer);
            }

        sprintf (buffer, ";:SOUR%ld:POW:CORR:LLIS:STAT %s", channel, confStates[state]);
        strcat (wrtBuf, buffer);
        }

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Offset Configuration                                           */
/*  Purpose:  This function eliminations of amplitude, phase and length      */
/*            errors.                                                        */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confCalOffsetConf (ViSession instrSession,
                ViBoolean port, ViReal64 magnitudedB, ViReal64 phaseDeg,
                ViReal64 setDielectric, ViReal64 delayTimes, ViReal64 lengthmm,
                ViInt32 delay)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE],
                buffer[BUFFER_SIZE];
    ViInt32     channel;
    rszv_instrRange instrPtr;

    if (rszv_invalidViBooleanRange (port))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViReal64Range (magnitudedB, -100.0, 100.0))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViReal64Range (phaseDeg, -360.0, 360.0))
        return VI_ERROR_PARAMETER4;
    if (rszv_invalidViInt32Range (delay, 0, 2))
        return VI_ERROR_PARAMETER8;

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));
    for (channel = 1; channel <= 4; channel++)
        {
        if ((instrPtr -> displayChannels) & (1 << channel)) break;
        }

    sprintf (wrtBuf, ":SENS%ld:CORR:OFFS%ld:MAGN %f;PHAS %f;:SENS%ld:CORR:EDEL%ld:DIEL %f",
         channel, ((port==VI_TRUE) ? 2 : 1), magnitudedB, phaseDeg,
         channel, ((port==VI_TRUE) ? 2 : 1), setDielectric);

    if (delay)
        {
        if (rszv_invalidViReal64Range (lengthmm, -3.0e9, 3.0e9))
            return VI_ERROR_PARAMETER7;
        sprintf (buffer, ";%s %f", (delay == 2)?"ELEN":"DIST", lengthmm);
        strcat (wrtBuf, buffer);
        }
    else
        {
        if (rszv_invalidViReal64Range (delayTimes, -10.0, 10.0))
            return VI_ERROR_PARAMETER6;
        sprintf (buffer, ";TIME %f", delayTimes);
        strcat (wrtBuf, buffer);
        }

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Select Item                                                    */
/*  Purpose:  This function selects the items of the data sets which will be */
/*            stored or recalled.                                            */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confMemoryItem (ViSession instrSession, ViInt32 items,
                ViBoolean generalSetup, ViBoolean colorSetup,
                ViBoolean HWSettings, ViBoolean hardcopy, ViBoolean calData,
                ViBoolean calKitData, ViBoolean macros, ViBoolean lines,
                ViBoolean asciiData)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (items, 0, 3))
        return VI_ERROR_PARAMETER2;
    
    if (!items)
        {
        if (rszv_invalidViBooleanRange (generalSetup))
            return VI_ERROR_PARAMETER3;
        if (rszv_invalidViBooleanRange (colorSetup))
            return VI_ERROR_PARAMETER4;
        if (rszv_invalidViBooleanRange (HWSettings))
            return VI_ERROR_PARAMETER5;
        if (rszv_invalidViBooleanRange (hardcopy))
            return VI_ERROR_PARAMETER6;
        if (rszv_invalidViBooleanRange (calData))
            return VI_ERROR_PARAMETER7;
        if (rszv_invalidViBooleanRange (calKitData))
            return VI_ERROR_PARAMETER8;
        if (rszv_invalidViBooleanRange (macros))
            return VI_ERROR_INSTR_PARAMETER9;
        if (rszv_invalidViBooleanRange (lines))
            return VI_ERROR_INSTR_PARAMETER10;
        if (rszv_invalidViBooleanRange (asciiData))
            return VI_ERROR_INSTR_PARAMETER11;
        }

    switch(items)
        {
        case 0: /*- User Select ---------------------------------------------*/
               sprintf (wrtBuf, ":MMEM:SEL:GSET %s;CSET %s;HWS %s;HCOP %s;CDAT %s;CKD %s;MACR %s;LIN %s;AFIL %s",
                    confStates[(generalSetup==VI_TRUE)?1:0],
                    confStates[(colorSetup==VI_TRUE)?1:0], 
                    confStates[(HWSettings==VI_TRUE)?1:0],
                    confStates[(hardcopy==VI_TRUE)?1:0],
                    confStates[(calData==VI_TRUE)?1:0],
                    confStates[(calKitData==VI_TRUE)?1:0],
                    confStates[(macros==VI_TRUE)?1:0],
                    confStates[(lines==VI_TRUE)?1:0],
                    confStates[(asciiData==VI_TRUE)?1:0]);
               break;
        case 1: /*- Enable All Items ----------------------------------------*/
               sprintf (wrtBuf, ":MMEM:SEL:ALL");
               break;
        case 2: /*- Disable All Items ---------------------------------------*/
               sprintf (wrtBuf, ":MMEM:SEL:NONE");
               break;
        case 3:/*- Default Configuration is selected ------------------------*/
               sprintf (wrtBuf, ":MMEM:SEL:DEF");
               break;
        }

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Select Memory Traces                                           */
/*  Purpose:  This function selects the Memory Traces which are stored or    */
/*            recalled.                                                      */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confMemoryTraces (ViSession instrSession,
                ViInt32 memoryTrace, ViBoolean state)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE],
                buffer[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (memoryTrace, 0, 8))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER3;

    if (!memoryTrace)
        { /*- All Memory Traces is selected ----------------*/
        ViInt32 i;
        for (i = 1; i <= 8; i++)
            {
            if (i == 1)
                sprintf (wrtBuf, ":MMEM:SEL:MTR%ld %s", i,
                    confStates[(state==VI_TRUE)?1:0]);
            else
                {
                sprintf (buffer, ";MTR%ld %s", i,
                    confStates[(state==VI_TRUE)?1:0]);
                strcat (wrtBuf, buffer);
                }
            }   
        } 
    else
        sprintf (wrtBuf, ":MMEM:SEL:MTR%ld %s", memoryTrace,
            confStates[(state==VI_TRUE)?1:0]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: State Limit Configuration                                      */
/*  Purpose:  This function enables/disables limits.                         */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confStateLimit (ViSession instrSession,
                ViInt32 channel, ViInt32 line, ViBoolean state)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (line, 1, 8))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViBooleanRange (state))
        return VI_ERROR_PARAMETER4;
        
    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":CALC%ld:LIM%ld:STAT %s", channel, line, confStates[state]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}


/*===========================================================================*/
/*  Function: Limit Lines Cartesian                                          */
/*  Purpose:  This function defines the characteristic of the currently      */
/*            active limit line in a cartesian diagram.                      */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confLimitLinesCartesian (ViSession instrSession,
                ViInt32 channel, ViInt32 line, ViInt32 noofSections,
                ViReal64 _VI_FAR start[], ViReal64 _VI_FAR stop[],
                ViReal64 _VI_FAR startUpperLim[], ViReal64 _VI_FAR startLowerLim[],
                ViReal64 _VI_FAR stopUpperLim[], ViReal64 _VI_FAR stopLowerLim[],
                ViInt32 complexConvers, ViInt32 format, ViInt32 sweep,
                ViInt32 XSpacing, ViInt32 YSpacing)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[LIMIT_BUFFER_SIZE],
                buffer[LIMIT_BUFFER_SIZE];
    ViInt32     i;

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (line, 1, 8))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViInt32Range (noofSections, 1, 20))
        return VI_ERROR_PARAMETER4;
    if (!start)
        return VI_ERROR_PARAMETER5;
    if (!stop)
        return VI_ERROR_PARAMETER6;
    if (!startUpperLim)
        return VI_ERROR_PARAMETER7;
    if (!startLowerLim)
        return VI_ERROR_PARAMETER8;
    if (!stopUpperLim)
        return VI_ERROR_INSTR_PARAMETER9;
    if (!stopLowerLim)
        return VI_ERROR_INSTR_PARAMETER10;
    if (rszv_invalidViInt32Range (complexConvers, 0, 5))
        return VI_ERROR_INSTR_PARAMETER11;
    if (rszv_invalidViInt32Range (format, 1, 6))
        return VI_ERROR_INSTR_PARAMETER12;
    if (rszv_invalidViInt32Range (sweep, 0, 2))
        return VI_ERROR_INSTR_PARAMETER13;
    if (rszv_invalidViInt32Range (XSpacing, 0, 3))
        return VI_ERROR_INSTR_PARAMETER14;
    if (rszv_invalidViInt32Range (YSpacing, 0, 2))
        return VI_ERROR_INSTR_PARAMETER15;
    if (XSpacing == 2 && sweep != 0)
        return VI_ERROR_INSTR_PARAMETER14;
    if (XSpacing == 3 && sweep == 1)
        return VI_ERROR_INSTR_PARAMETER14;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":CALC%ld:LIM%ld:RDOM:SPAC %s;COMP %s;FORM %s"
                 ";:CALC%ld:LIM%ld:CONT:DOM %s%s"
                 ";:CALC%ld:LIM%ld:CONT %f%s,%f%s", 
         channel, line, confLimYSpacingArr[YSpacing], confMeasConv[complexConvers], confResForm[format],
         channel, line, confLimSweepArr[sweep], confLimXSpacingArr[XSpacing],
         channel, line, start[0], confLimitUnitsArr[sweep], stop[0], confLimitUnitsArr[sweep]);

    for (i = 1; i < noofSections; i++)
        {
        sprintf (buffer, ",%f%s,%f%s", start[i], confLimitUnitsArr[sweep],
            stop[i], confLimitUnitsArr[sweep]);
        strcat (wrtBuf, buffer);
        }

    sprintf (buffer, ";UPP %f,%f", startUpperLim[0], stopUpperLim[0]);
    strcat (wrtBuf, buffer);

    for (i = 1; i < noofSections; i++)
        {
        sprintf (buffer, ",%f,%f", startUpperLim[i], stopUpperLim[i]);
        strcat (wrtBuf, buffer);
        }

    sprintf (buffer, ";LOW %f,%f", startLowerLim[0], stopLowerLim[0]);
    strcat (wrtBuf, buffer);

    for (i = 1; i < noofSections; i++)
        {
        sprintf (buffer, ",%f,%f", startLowerLim[i], stopLowerLim[i]);
        strcat (wrtBuf, buffer);
        }

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Limit Lines Polar                                              */
/*  Purpose:  This function defines limit line in a circular diagram.        */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confLimitLinesPolar (ViSession instrSession,
                ViInt32 channel, ViInt32 line, ViReal64 radius,
                ViInt32 complexConvers, ViInt32 sweep,
                ViInt32 XSpacing, ViInt32 YSpacing)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (line, 1, 8))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViInt32Range (complexConvers, 0, 5))
        return VI_ERROR_PARAMETER5;
    if (rszv_invalidViInt32Range (sweep, 0, 2))
        return VI_ERROR_PARAMETER6;
    if (rszv_invalidViInt32Range (XSpacing, 0, 3))
        return VI_ERROR_PARAMETER7;
    if (rszv_invalidViInt32Range (YSpacing, 0, 2))
        return VI_ERROR_PARAMETER8;
    if (XSpacing == 2 && sweep != 0)
        return VI_ERROR_PARAMETER7;
    if (XSpacing == 3 && sweep == 1)
        return VI_ERROR_PARAMETER7;
    
    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":CALC%ld:LIM%ld:RDOM:SPAC %s;COMP %s;FORM COMP"
                 ";:CALC%ld:LIM%ld:UPP:RAD %f"
                 ";:CALC%ld:LIM%ld:CONT:DOM %s%s", 
         channel, line, confLimYSpacingArr[YSpacing], confMeasConv[complexConvers],
         channel, line, radius,
         channel, line, confLimSweepArr[sweep], confLimXSpacingArr[XSpacing]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Limit Lines Smith                                              */
/*  Purpose:  This function defines limit line in a circular diagram.        */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confLimitLinesSmith (ViSession instrSession,
                ViInt32 channel, ViInt32 line, ViReal64 radius,
                ViReal64 XPosition, ViReal64 YPosition, 
                ViInt32 complexConvers, ViInt32 sweep, ViInt32 XSpacing)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (line, 1, 8))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViInt32Range (complexConvers, 0, 5))
        return VI_ERROR_PARAMETER7;
    if (rszv_invalidViInt32Range (sweep, 0, 2))
        return VI_ERROR_PARAMETER8;
    if (rszv_invalidViInt32Range (XSpacing, 0, 3))
        return VI_ERROR_INSTR_PARAMETER9;
    if (XSpacing == 2 && sweep != 0)
        return VI_ERROR_INSTR_PARAMETER9;
    if (XSpacing == 3 && sweep == 1)
        return VI_ERROR_INSTR_PARAMETER9;
        
    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":CALC%ld:LIM%ld:RDOM:SPAC SIC;COMP %s;FORM COMP"
                 ";:CALC%ld:LIM%ld:CENT %f,%f;UPP:RAD %f"
                 ";:CALC%ld:LIM%ld:CONT:DOM %s%s", 
         channel, line, confMeasConv[complexConvers],
         channel, line, XPosition, YPosition, radius,
         channel, line, confLimSweepArr[sweep], confLimXSpacingArr[XSpacing]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Copy or Move File                                              */
/*  Purpose: This function copys or moves file.                              */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_actCopyFile (ViSession instrSession, ViBoolean function,
                ViString sourceFile, ViString destinationFile)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViBooleanRange (function))
        return VI_ERROR_PARAMETER2;
    if (sourceFile)
        {
        if (strlen (sourceFile) > 120)
            return VI_ERROR_PARAMETER3;
        }
    else
        return VI_ERROR_PARAMETER3;

    if (destinationFile)
        {
        if (strlen (destinationFile) > 120)
            return VI_ERROR_PARAMETER4;
        }
    else
        return VI_ERROR_PARAMETER4;

    sprintf (wrtBuf, ":MMEM:%s \"%s\",\"%s\"", (function==VI_TRUE) ? "MOVE":"COPY",
         sourceFile, destinationFile);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_WaitForOPC (instrSession));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Delete File or Directory                                       */
/*  Purpose: This function deletes file or directory.                        */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_actDeleteFile (ViSession instrSession,
                                      ViBoolean deleteSource,
                                      ViString fileorDirectory)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViBooleanRange (deleteSource))
        return VI_ERROR_PARAMETER2;
    
    if (fileorDirectory)
        {
        if (strlen (fileorDirectory) > 120)
            return VI_ERROR_PARAMETER3;        
        }
    else
        return VI_ERROR_PARAMETER3;

    sprintf (wrtBuf, ":MMEM:%s \"%s\"", (deleteSource == VI_TRUE) ? "RDIR" : "DEL",
         fileorDirectory);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_WaitForOPC (instrSession));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Make Directory                                                 */
/*  Purpose: This function creates a new directory. .                        */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_actMakeDir (ViSession instrSession, 
                ViString directoryName)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (directoryName)
        {
        if (strlen (directoryName) > 120)
            return VI_ERROR_PARAMETER2;
        }
    else
        return VI_ERROR_PARAMETER2;

    sprintf (wrtBuf, ":MMEM:MDIR \"%s\"", directoryName);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_WaitForOPC (instrSession));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Format Diskette                                                */
/*  Purpose:  This function formats the disk in drive A in the instrument.   */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_actFormatDisk (ViSession instrSession)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    sprintf (wrtBuf, ":MMEM:INIT \"A:\"");

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_WaitForOPC (instrSession));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Send Trigger                                                   */
/*  Purpose:  This function triggers all actions waiting for a trigger event.*/
/*===========================================================================*/
ViStatus _VI_FUNC rszv_actTrigger (ViSession instrSession)
{
    ViStatus    rszv_status = VI_SUCCESS;
    
    CHECKERR( viWrite (instrSession, (ViBuf)"*TRG\n", 5, VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Autoscale                                                      */
/*  Purpose:  This function automatic scaling the test diagram in the active */
/*            display channel.                                               */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_actAutoscale (ViSession instrSession, ViInt32 channel)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":DISP:WIND%ld:TRAC:Y:AUTO ONCE", channel);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Markers Off                                                    */
/*  Purpose:  This function switches off all markers and auxiliary markers of*/
/*            the active display channel.                                    */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_actMarkersOff (ViSession instrSession, ViInt32 channel)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];
    
    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":CALC%ld:MARK:AOFF", channel);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Marker Search                                                  */
/*  Purpose:  This function actually triggers the defined search.            */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_actMarkerSearch (ViSession instrSession, ViInt32 channel,
                ViInt32 marker, ViInt32 function, ViPReal64 XValue,
                ViPReal64 YValue)
{
    ViStatus        rszv_status = VI_SUCCESS;
    ViByte          buffer[BUFFER_SIZE];
    ViReal64        tmpVal1, tmpVal2;

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (marker, 1, 8))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViInt32Range (function,0,5))
        return VI_ERROR_PARAMETER4;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    /*- Start Search --------------------------------------------------------*/
    sprintf (buffer, ":CALC%ld:MARK%ld:%s", channel, marker, actMarkSearch[function]);

    sprintf(buffer+strlen(buffer),"\n"); 
    CHECKERR( viWrite (instrSession, buffer, strlen (buffer), VI_NULL));

    CHECKERR( viQueryf (instrSession, ":CALC%ld:MARK%ld:FUNC:RESULT?\n", "%[^\r\n]", channel, marker, buffer));

    if (sscanf ((char *)buffer, "%lf,%lf", &tmpVal1, &tmpVal2) != 2)
        {
        *XValue = *YValue = 0;
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        }
    
    if (XValue)
        *XValue = tmpVal1;

    if (YValue)
        *YValue = tmpVal2;

    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Start Sweep                                                    */
/*  Purpose:  This function starts sweep. Number of sweep is defined via     */
/*            function Sweep Configuration.                                  */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_actSweepStart (ViSession instrSession)
{
    ViStatus rszv_status = VI_SUCCESS;

    CHECKERR( viWrite (instrSession, (ViBuf)":INIT\n", 6,VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Restart Average                                                */
/*  Purpose:  This function resets the result of the average function and    */
/*            restarts the measurement.                                      */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_actSweAvgReset (ViSession instrSession, ViInt32 channel)
{
    ViStatus rszv_status = VI_SUCCESS;
    
    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;

    CHECKERR( viPrintf (instrSession, ":SENS%ld:AVER:CLE\n", channel));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Install Calibration Kit                                        */
/*  Purpose:  This function installs the cal kit data from a file.           */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_actCalInstallKit (ViSession instrSession, ViString sourceFile)
{
    ViStatus    rszv_status = VI_SUCCESS;
    
    if (sourceFile)
        {
        if (strlen (sourceFile) > 120)
            return VI_ERROR_PARAMETER2;
        }
    else
        return VI_ERROR_PARAMETER5;

    CHECKERR( viPrintf (instrSession, ":SENS:CORR:CKIT:INST \"%s\"\n", sourceFile));
    CHECKERR( rszv_sysStatus (instrSession));
    return rszv_status;
}

/*===========================================================================*/
/*  Function: Auto Offset Cal Configuration                                  */
/*  Purpose:  This function automaticly eliminations of amplitude, phase and */
/*            length errors.                                                 */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_actCalOffsetAutoLength (ViSession instrSession, ViBoolean port)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];
    ViInt32     channel;
    rszv_instrRange instrPtr;

    if (rszv_invalidViBooleanRange (port))
        return VI_ERROR_PARAMETER2;

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));
    for (channel = 1; channel <= 4; channel++)
        {
        if ((instrPtr -> displayChannels) & (1 << channel)) break;
        }

    sprintf (wrtBuf, ":SENS%ld:CORR:EDEL%ld:AUTO ONCE", channel,
            ((port==VI_TRUE) ? 2 : 1));

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Define Port Type                                               */
/*  Purpose:  This function defines types of ports for a calibration.        */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_confCalPortType (ViSession instrSession,
                                       ViInt32 port1Connector,
                                       ViInt32 port2Connector)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];
    ViInt32     channel;
    rszv_instrRange instrPtr;

    if (rszv_invalidViInt32Range (port1Connector, 0, 13))
        return VI_ERROR_PARAMETER2;

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));
    for (channel = 1; channel <= 4; channel++)
        if ((instrPtr -> displayChannels) & (1 << channel)) break;

    if (isZVRL(instrPtr->instType))
        {
        sprintf (wrtBuf, ":SENS%ld:CORR:COLL:CONN1 %s", channel, actCalFTPort[port1Connector]);
        }
    else
        {
        if (rszv_invalidViInt32Range (port2Connector, 0, 13))
            return VI_ERROR_PARAMETER3;

        /* The PC292FEMALE and PC292MALE are only on ZVM and ZVK available.*/
        /* The N75FEMALE and N75MALE are not available on ZVM and ZVK.*/
        if (isZVMK(instrPtr->instType))
        {
            if ((port1Connector==2) || (port1Connector == 3))
                return VI_ERROR_PARAMETER2;
            if ((port2Connector==2) || (port2Connector == 3))
                return VI_ERROR_PARAMETER3;
        }
        else
        {
            if ((port1Connector==12) || (port1Connector == 13))
                return VI_ERROR_PARAMETER2;
            if ((port2Connector==12) || (port2Connector == 13))
                return VI_ERROR_PARAMETER3;
        }

        if (rszv_invalidViInt32Range (port2Connector, 0, 13))
            return VI_ERROR_PARAMETER3;
        sprintf (wrtBuf, ":SENS%ld:CORR:COLL:CONN1 %s;CONN2 %s",
             channel, actCalFTPort[port1Connector], actCalFTPort[port2Connector]);
        }

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Define Cal FTP Method                                          */
/*  Purpose:  This function defines a calibration method for Full Two Port   */
/*            Calibration.                                                   */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_actCalFTPMethod (ViSession instrSession, ViInt32 channel,
                ViInt32 method)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];
    
    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (method, 0, 6))
        return VI_ERROR_PARAMETER3;
    
    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":SENS%ld:CORR:COLL:METH %s", channel,
         actCalFTPMeth[method]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Full Two Port Cal Meas                                         */
/*  Purpose:  This function starts a complete calibration for two-port       */
/*            measurements.                                                  */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_actCalFTPMeas (ViSession instrSession, ViInt32 channel,
                ViInt32 calMeas)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (calMeas, 0, 19))
        return VI_ERROR_PARAMETER3;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":SENS%ld:CORR:COLL:%s", channel, actCalFTPMeas[calMeas]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_WaitForOPC (instrSession));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}


/*===========================================================================*/
/*  Function: Define Cal FOP Method                                          */
/*  Purpose:  This function defines a calibration method for Full Two Port   */
/*            Calibration                                                    */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_actCalFOPMethod (ViSession instrSession, ViInt32 channel,
                ViInt32 fullOnePort)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (fullOnePort, 0, 2))
        return VI_ERROR_PARAMETER3;
    
    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":SENS%ld:CORR:COLL:METH %s", channel, actCalFOPMeth[fullOnePort]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Full One Port Cal Meas                                         */
/*  Purpose:  This function starts a complete calibration for one-port       */
/*            measurements.                                                  */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_actCalFOPMeas (ViSession instrSession, ViInt32 channel,
                ViInt32 calMeas)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];
    
    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (calMeas,0,8))
        return VI_ERROR_PARAMETER3;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":SENS%ld:CORR:COLL:%s", channel, actCalFOPMeas[calMeas]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_WaitForOPC (instrSession));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Define Cal OPTP Method                                         */
/*  Purpose:  This function defines a calibration method for unidirectional  */
/*            calibration measurement.                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_actCalOPTPMethod (ViSession instrSession, ViInt32 channel,
                ViBoolean onePathTwoPort)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViBooleanRange (onePathTwoPort))
        return VI_ERROR_PARAMETER3;
    
    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":SENS%ld:CORR:COLL:METH %s", channel,
         actCalOPTMeth[(onePathTwoPort==VI_TRUE)?1:0]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}


/*===========================================================================*/
/*  Function: One Path Two Port Cal Meas                                     */
/*  Purpose:  This function starts undirectional calibration measurement.    */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_actCalOPTPMeas (ViSession instrSession, ViInt32 channel,
                ViInt32 calMeas)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (calMeas, 0, 9))
        return VI_ERROR_PARAMETER3;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":SENS%ld:CORR:COLL%s", channel, actCalOPTMeas[calMeas]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf,  strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_WaitForOPC (instrSession));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Trans Norm Method                                              */
/*  Purpose:  This function defines a calibration method for transmission    */
/*            normalization calibration measurement.                         */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_actCalTNMethod (ViSession instrSession, ViInt32 channel,
                ViInt32 transNorm)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (transNorm, 0, 2))
        return VI_ERROR_PARAMETER3;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":SENS%ld:CORR:COLL:METH %s", channel, actCalTNMeth[transNorm]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Trans Norm Cal Meas                                            */
/*  Purpose:  This function starts a transmission normalization calibration  */
/*            measurement.                                                   */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_actCalTNMeas (ViSession instrSession, ViInt32 channel, 
                ViInt32 calMeas)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (calMeas, 0, 9))
        return VI_ERROR_PARAMETER3;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));
        
    sprintf (wrtBuf, ":SENS%ld:CORR:COLL%s", channel, actCalTNMeas[calMeas]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf,  strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_WaitForOPC (instrSession));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Refl Norm Method                                               */
/*  Purpose:  This function defines a calibration method for a reflection    */
/*            normalization calibration measurement.                         */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_actCalRNMethod (ViSession instrSession, ViInt32 channel,
                ViInt32 reflNorm)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (reflNorm,0,2))
        return VI_ERROR_PARAMETER3;
    
    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":SENS%ld:CORR:COLL:METH %s", channel, actCalRNMeth[reflNorm]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Refl Norm Cal Meas                                             */
/*  Purpose:  This function starts a reflection normalization calibration    */
/*            measurement.                                                   */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_actCalRNMeas (ViSession instrSession, ViInt32 channel, 
                ViInt32 calMeas)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (calMeas, 0, 2))
        return VI_ERROR_PARAMETER3;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));    

    sprintf (wrtBuf, ":SENS%ld:CORR:COLL%s", channel, actCalRNMeas[calMeas]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf,  strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_WaitForOPC (instrSession));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Tran and Refl Norm                                             */
/*  Purpose:  This function starts a combined transmission and reflection    */
/*            normalization calibration measurement.                         */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_actCalTRNMethod (ViSession instrSession, ViInt32 channel,
                ViInt32 transandReflNorm)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (transandReflNorm, 0, 2))
        return VI_ERROR_PARAMETER3;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":SENS%ld:CORR:COLL:METH %s", channel, actCalTRNMeth[transandReflNorm]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf,  strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Tran and Refl Norm                                             */
/*  Purpose:  This function starts a combined transmission and reflection    */
/*            normalization calibration measurement.                         */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_actCalTRNMeas (ViSession instrSession, ViInt32 channel,
                ViInt32 calMeas)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (calMeas, 0, 3))
        return VI_ERROR_PARAMETER3;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    sprintf (wrtBuf, ":SENS%ld:CORR:COLL%s", channel, actCalTRNMeas[calMeas]);

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf,  strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_WaitForOPC (instrSession));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Power Calibration                                              */
/*  Purpose:  This function starts power claibration.                        */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_actCalPowerCal (ViSession instrSession, ViInt32 channel,
                ViInt32 numberofReading, ViInt32 powerCal, ViReal64 valuedBm)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (numberofReading,0,100))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViInt32Range (powerCal, 0, 5))
        return VI_ERROR_PARAMETER4;
    if (rszv_invalidViReal64Range (valuedBm,-300.0, 200.0))
        return VI_ERROR_PARAMETER5;      
    
    if (powerCal < 4)
        { /*- a1, a2 or external calibration is selected ------*/
        sprintf (wrtBuf, ":SOUR%ld:POW:CORR:NRE %ld;:SOUR%ld:POW:CAMP:%s %fdBm;:SOUR%ld:POW:CORR:ACQ %s",
             channel, numberofReading, channel, actCalPow[powerCal],
             valuedBm, channel, actCalPow[powerCal]);
        } 
    else 
        {  /*- b1 or b2 power calibration is selected ----------------------*/
        sprintf (wrtBuf, ":SENS%ld:CORR:POW:ACQ %s",channel, actCalPow[powerCal]);
        }


    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf,  strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_WaitForOPC (instrSession));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Start Copy                                                     */
/*  Purpose:  This function initiates the printing of measurement/instrument */
/*            status data.                                                   */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_actCopyStart (ViSession instrSession, ViBoolean device)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE];
    
    if (rszv_invalidViBooleanRange (device))
        return VI_ERROR_PARAMETER2;
                                  
    sprintf (wrtBuf, ":HCOP:IMM%ld", (ViInt32)((device==VI_TRUE) ? 2 : 1));

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_WaitForOPC (instrSession));
    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Data Operation                                                 */
/*  Purpose:  This function storing instrument settings such as instrument   */
/*            configurations or to load stored data into working memory.     */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_dataMemoryData (ViSession instrSession, ViInt32 function,
                ViString path, ViString filename, ViString comment, ViInt32 formatoftheFile,
                ViInt32 formatforData, ViBoolean mode, ViBoolean separator,
                ViInt32 source)
{ 
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      wrtBuf[BUFFER_SIZE],
                buffer[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (function, 0, 3))
        return VI_ERROR_PARAMETER2;
    if (path)
        {
        if (strlen (path) > 120)
            return VI_ERROR_PARAMETER3;
        }
    else
        return VI_ERROR_PARAMETER3;

    if (filename)
        {
        if (strlen (filename) > 8)
            return VI_ERROR_PARAMETER4;
        }
    else
        return VI_ERROR_PARAMETER4;
    
    if (!function)
        {
        if (comment)
            {
            if (strlen (comment) > 60)
                return VI_ERROR_PARAMETER5;
            }
        else
            return VI_ERROR_PARAMETER5;
            
        if (rszv_invalidViInt32Range (formatoftheFile, 0, 2))
            return VI_ERROR_PARAMETER6;
        if (rszv_invalidViInt32Range (formatforData, 0, 2))
            return VI_ERROR_PARAMETER7;
        if (rszv_invalidViBooleanRange (mode))
            return VI_ERROR_PARAMETER8;
        if (rszv_invalidViBooleanRange (separator))
            return VI_ERROR_INSTR_PARAMETER9;
        if (rszv_invalidViInt32Range (source, 0, 5))
            return VI_ERROR_INSTR_PARAMETER10;
        }

    switch(function)
        {
        case 0: /*- Save Selected -------------------------------------------*/
            switch(formatoftheFile)
                {
                case 0: /*- ASCII file selected ------------------------*/
                    sprintf (wrtBuf, ":FORM:DEXP %s;DEXP:MODE %s;DSEP %s;SOUR %s",
                        dataMemFileType[formatoftheFile], 
                        dataMemMode[(mode==VI_TRUE)?1:0],
                        dataMemSep[(separator==VI_TRUE)?1:0],
                        dataMemSour[source]);

                    if (source > 2)
                        {
                        sprintf (buffer, ";FORM %s", dataMemDataForm[formatforData]);
                        strcat (wrtBuf, buffer);
                        }
                
                    sprintf (buffer, ";:MMEM:CDIR \"%s\";COMM \"%s\";STOR:STAT 1,\"%s\"",
                         path, comment, filename);
                    strcat (wrtBuf, buffer);
                    break;
                case 1: /*- Touchstone file selected -------------------*/
                    sprintf (wrtBuf, ":FORM:DEXP %s;DEXP:FORM %s;:MMEM:"
                        "CDIR \"%s\";COMM \"%s\";STOR:STAT 1,\"%s\"",
                        dataMemFileType[formatoftheFile],
                        dataMemDataForm[formatforData],
                        path, comment, filename);
                    break;
                case 2: /*- Super Compact file selected ----------------*/
                    sprintf (wrtBuf, ":FORM:DEXP %s;DEXP:FORM %s;MODE %s"
                        ";:MMEM:CDIR \"%s\";COMM \"%s\";STOR:STAT 1,\"%s\"",
                        dataMemFileType[formatoftheFile],
                        dataMemDataForm[formatforData],
                        dataMemMode[(mode==VI_TRUE)?1:0], path, comment,
                        filename);
                break;
                }     
            break;
        case 1: /*- Recall Selected -----------------------------------------*/
            sprintf (wrtBuf, ":MMEM:CDIR \"%s\";LOAD:STAT 1,\"%s\"", path,
                filename);
            break;               
        case 2: /*- Data Set Clear Selected ---------------------------------*/
            sprintf (wrtBuf, ":MMEM:CDIR \"%s\";CLE:STAT 1,\"%s\"", path, filename);
            break;
        case 3: /*- Data Set Clear All Selected -----------------------------*/
            sprintf (wrtBuf, ":MMEM:CDIR \"%s\";CLE:ALL", path);
            break;
        }

    sprintf(wrtBuf+strlen(wrtBuf),"\n");
    CHECKERR( viWrite (instrSession, wrtBuf, strlen (wrtBuf), VI_NULL));
    CHECKERR( rszv_WaitForOPC (instrSession));
    CHECKERR( rszv_sysStatus (instrSession));
    
    if (function == 1)
        CHECKERR( rszv_defaultInstrSetup (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Data from Instrument                                           */
/*  Purpose:  This function reads the response or stimulus values of the     */
/*            trace data from the instrument.                                */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_dataReadTrace (ViSession instrSession, ViBoolean size,
                ViBoolean typeData, ViInt32 dataSource, ViInt32 dataFrom,
                ViPInt32 count, ViReal64 _VI_FAR data[])
{
    ViStatus    rszv_status = VI_SUCCESS;
    static ViByte buffer[DATA_BUFFER];
    ViChar      tmpBuf[128];
    ViInt32     tmpSize = 0;
    ViInt32     i = 0, 
                length = 0,
                lengthOfLength = 0;
    ViReal32    *p2Source32 = 0;
    ViReal64    *p2Source64 = 0,
                *p2data = data;
    ViUInt16    interface = VI_INTF_GPIB;

    if (rszv_invalidViBooleanRange (size))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViBooleanRange (typeData))
        return VI_ERROR_PARAMETER3;
    if (rszv_invalidViInt32Range (dataSource, 0, 5))
        return VI_ERROR_PARAMETER4;
    if (rszv_invalidViInt32Range (dataFrom, 0, 11))
        return VI_ERROR_PARAMETER5;
    if (!data)
        return VI_ERROR_PARAMETER7;

    sprintf (buffer, ":FORM REAL,%ld;:FORM:DEXP ASC;DEXP:SOUR %s;:%s %s", 
         ((size) ? 64 : 32), dataMemSour[dataSource],
         datTypeFromInst[typeData], datFromInstr[dataFrom]);

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_INTF_TYPE, &interface));

    sprintf(buffer+strlen(buffer),"\n"); 
    CHECKERR( viWrite (instrSession, buffer, strlen (buffer), VI_NULL));

    /* Interface specific operations */
    switch (interface)
        {
        case VI_INTF_ASRL: /* Serial Interface. */
            CHECKERR( viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_NONE));
            CHECKERR( viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_FALSE));
        
            if ((rszv_status = viRead (instrSession, buffer, 2, VI_NULL)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return rszv_status;
                }
            buffer[2]='\0';

            if (sscanf(buffer, "#%ld", &lengthOfLength) != 1)
                {
                if (count) *count = 0;
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                }

            if ((rszv_status = viRead (instrSession, buffer, lengthOfLength, VI_NULL)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return rszv_status;
                }
        
            buffer[lengthOfLength]='\0';

            if (sscanf(buffer, "%ld", &length) != 1)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                }

            if ((rszv_status = viRead (instrSession, buffer, length+2, VI_NULL)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
                viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);
                return rszv_status;
                }

            viSetAttribute (instrSession, VI_ATTR_ASRL_END_IN, VI_ASRL_END_TERMCHAR);
            viSetAttribute (instrSession, VI_ATTR_TERMCHAR_EN, VI_TRUE);

            if (size)
                {
                tmpSize = (length/8);
                /* Binary data byte order (MOTOROLA or INTEL). */
                rszv_SWAP_64(buffer, tmpSize);
                p2Source64 = (ViReal64*)(buffer);   /* Pointer to data */
                }
            else
                {
                tmpSize = (length/4);
                /* Binary data byte order (MOTOROLA or INTEL). */
                rszv_SWAP_32(buffer, tmpSize);
                p2Source32 = (ViReal32*)(buffer);   /* Pointer to data */
                }
        break;
        case VI_INTF_GPIB: default: /* GPIB Interface. Default case */
            CHECKERR( viRead (instrSession, buffer, DATA_BUFFER, VI_NULL));
            if (sscanf (buffer, "#%1d", &lengthOfLength) != 1)
                {
                if (count) *count = 0;                      
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
                }

            strncpy (tmpBuf, buffer + 2, lengthOfLength);
            tmpBuf[lengthOfLength] = 0;

            if (sscanf (tmpBuf, "%ld", &length) != 1)
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        
            if (size)
                {
                tmpSize = (length/8);
                /* Binary data byte order (MOTOROLA or INTEL). */
                rszv_SWAP_64(buffer, tmpSize);
                p2Source64 = (ViReal64*)(buffer+lengthOfLength+2);   /* Pointer to data */
                }
            else
                {
                tmpSize = (length/4);
                /* Binary data byte order (MOTOROLA or INTEL). */
                rszv_SWAP_32(buffer, tmpSize);
                p2Source32 = (ViReal32*)(buffer+lengthOfLength+2);   /* Pointer to data */
                }
        break;
        }

    if (size)
        { /*- 64 bits -*/
        for (i = 0; i < tmpSize; i++) 
            *p2data++ = *p2Source64++;
        }
    else
        {
        for (i = 0; i < tmpSize; i++) 
            *p2data++ = (ViReal64)*p2Source32++;
        }

    if (count)
        *count = tmpSize;

    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Marker Data                                                    */
/*  Purpose:  This function reads marker position for selected marker.       */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_dataMarkerData (ViSession instrSession, ViInt32 channel,
                    ViInt32 marker, ViPReal64 XValue, ViPReal64 realValue,
                    ViPReal64 imaginaryValue)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      buffer[BUFFER_SIZE];
    ViReal64    tmp1, tmp2 = 0.0;

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (rszv_invalidViInt32Range (marker, 1, 8))
        return VI_ERROR_PARAMETER3;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));
    
    if (realValue)
        *realValue = 0.0;
    if (imaginaryValue)
        *imaginaryValue = 0.0;

    if (XValue)
        {
        *XValue = 0.0;

        CHECKERR( viQueryf (instrSession, ":CALC%ld:MARK%ld:X?\n", "%[^\r\n]", channel, marker, buffer));

        if (sscanf ((ViChar *)buffer, "%lf", XValue) != 1)
            return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
        }

    /*- Format of the markers -----------------------------------------------*/
    if (realValue || imaginaryValue)
        {
        CHECKERR( viQueryf (instrSession, ":CALC%ld:MARK%ld:Y?\n", "%[^\r\n]", channel, marker, buffer));

        if (sscanf ((ViChar *)buffer, "%lf,%lf", &tmp1, &tmp2) != 2)
            {
            if (sscanf ((ViChar *)buffer, "%lf", &tmp1) != 1)
                return VI_ERROR_INSTR_INTERPRETING_RESPONSE;
            }

        if (realValue)
            *realValue = tmp1;
        if (imaginaryValue)
            *imaginaryValue = tmp2;
        }

    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Peak to Peak                                                   */
/*  Purpose:  This function reads the result of the peak-to peak value search*/
/*===========================================================================*/
ViStatus _VI_FUNC rszv_dataPtP (ViSession instrSession, ViInt32 channel,
                    ViPReal64 peaktoPeak, ViPReal64 average,
                    ViPReal64 minimum, ViPReal64 maximum,
                    ViPReal64 standardDeviation)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      buffer[BUFFER_SIZE];
    ViReal64    tmp1, tmp2, tmp3, tmp4, tmp5;

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    
    CHECKERR( rszv_isChanDispCache (instrSession, channel));
    
    if (peaktoPeak)
        *peaktoPeak = 0.0;
    if (average)
        *average = 0.0;
    if (minimum)
        *minimum = 0.0;
    if (maximum)
        *maximum = 0.0;
    if (standardDeviation)
        *standardDeviation = 0.0;

    CHECKERR( viQueryf (instrSession, ":CALC%ld:MARK:FUNC:PTP:RES? ALL\n", "%[^\r\n]", channel, buffer));

    if (sscanf ((ViChar *)buffer, "%lf,%lf,%lf,%lf,%lf", &tmp1, &tmp2, &tmp3, &tmp4, &tmp5) != 5)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    if (peaktoPeak)
        *peaktoPeak = tmp1;
    if (average)
        *average = tmp2;
    if (minimum)
        *minimum = tmp3;
    if (maximum)
        *maximum = tmp4;
    if (standardDeviation)
        *standardDeviation = tmp5;

    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Segment Count                                                  */
/*  Purpose:  This function returns the number of segments defined in segment*/
/*            list.                                                          */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_dataSegmentCount (ViSession instrSession,
                    ViInt32 channel, ViPInt32 count)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      buffer[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (!count)
        return VI_ERROR_PARAMETER3;
    else
        *count = -1;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));
    CHECKERR( viQueryf (instrSession, ":SENS%ld:SEGM:COUN?\n", "%[^\r\n]",
        channel, buffer));

    /*- Testing Response ----------------------------------------------------*/
    if (sscanf ((ViChar *)buffer, "%ld", count) != 1)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Limit Fail                                                     */
/*  Purpose:  This function returns the result of the limit check.           */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_dataLimitFail (ViSession instrSession,
                ViInt32 channel, ViPInt32 fail)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      buffer[BUFFER_SIZE];

    if (rszv_invalidViInt32Range (channel, 1, 4))
        return VI_ERROR_PARAMETER2;
    if (!fail)
        return VI_ERROR_PARAMETER3;
    else
        *fail = 1;

    CHECKERR( rszv_isChanDispCache (instrSession, channel));
    CHECKERR( viQueryf (instrSession, ":CALC%ld:LIM:FAIL?\n", "%[^\r\n]", channel, buffer));

    /*- Testing Response ----------------------------------------------------*/
    if (sscanf ((ViChar *)buffer, "%ld", fail) != 1)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    return rszv_status;
}

/*===========================================================================*/
/* Function: Set Check Status                                                */
/* Purpose:  This function enables/disbles checking of instrument status.    */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_setCheckStatus (ViSession instrSession, ViBoolean checkStatus)
{
    ViStatus rszv_status = VI_SUCCESS;
    rszv_instrRange instrPtr;

    if (rszv_invalidViBooleanRange (checkStatus))
        return VI_ERROR_PARAMETER2;

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));
    instrPtr -> checkStatus = checkStatus;

    return rszv_status;
}

/*===========================================================================*/
/* Function: Set Timeout                                                     */
/* Purpose:  This function set max timeout for function rszv_WaitForOPC.     */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_setTimeout (ViSession instrSession, ViUInt32 maxTimeout)
{
    ViStatus rszv_status = VI_SUCCESS;
    rszv_instrRange instrPtr;

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));
    instrPtr -> timeout = maxTimeout;

    return rszv_status;
}

/*===========================================================================*/
/* Function: Write To Instrument                                             */
/* Purpose:  This function writes a command string to the instrument.        */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_writeInstrData (ViSession instrSession, ViString writeBuffer)
{
    ViStatus rszv_status = VI_SUCCESS;

    CHECKERR( viPrintf (instrSession, "%s\n", writeBuffer));

    return rszv_status;
}

/*===========================================================================*/
/* Function: Read Instrument Buffer                                          */
/* Purpose:  This function reads the output buffer of the instrument.        */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_readInstrData (ViSession instrSession, ViInt32 numberBytesToRead,
                    ViChar _VI_FAR readBuffer[], ViPInt32 numBytesRead)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViUInt32    tmpCnt;

    if (numBytesRead)
        *numBytesRead = 0L;
        
    CHECKERR( viRead (instrSession, (ViBuf)readBuffer, numberBytesToRead, &tmpCnt));

    if (numBytesRead)
        *numBytesRead = (ViInt32)tmpCnt;

    return rszv_status;
}

/*===========================================================================*/
/* Function: Reset                                                           */
/* Purpose:  This function resets the instrument.  If the reset function     */
/*           is not supported by the instrument, this function returns       */
/*           the warning VI_WARN_NSUP_RESET.                                 */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_reset (ViSession instrSession)
{
    ViStatus    rszv_status = VI_SUCCESS;
    
    /*  Initialize the instrument to a known state.  */
    CHECKERR( viWrite (instrSession, (ViBuf)"*RST\n", 5, VI_NULL));
    CHECKERR( rszv_defaultInstrSetup (instrSession));

    CHECKERR( rszv_sysStatus (instrSession));

    return rszv_status;
}

/*===========================================================================*/
/* Function: Self-Test                                                       */
/* Purpose:  This function executes the instrument self-test and returns     */
/*           the result. If the self test function is not supported by the   */
/*           instrument, this function returns the warning                   */
/*           VI_WARN_NSUP_SELF_TEST.                                         */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_self_test (ViSession instrSession, ViPInt16 testResult,
                    ViChar _VI_FAR testMessage[])
{
    ViStatus    rszv_status = VI_SUCCESS;

    CHECKERR( viQueryf (instrSession, "*TST?\n", "%hd", testResult));

    sprintf (testMessage, "%s", (*testResult == 0) ? "Self-Test Passed" : "Self-Test Failed");

    return rszv_status;
}

/*===========================================================================*/
/* Function: Error Query                                                     */
/* Purpose:  This function queries the instrument error queue, and returns   */
/*           the result. If the error query function is not supported by the */
/*           instrument, this function returns the warning                   */
/*           VI_WARN_NSUP_ERROR_QUERY.                                       */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_error_query (ViSession instrSession, ViPInt32 errorCode,
                    ViChar _VI_FAR errorMessage[])
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViUInt32    retCnt = 0;
    
    CHECKERR( viWrite (instrSession, (ViBuf)":SYST:ERR?\n", 11, &retCnt));
    CHECKERR( viScanf (instrSession, "%ld,\"%[^\"]", errorCode, errorMessage));

    return rszv_status;
}

/*===========================================================================*/
/* Function: Error Message                                                   */
/* Purpose:  This function translates the error return value from the        */
/*           instrument driver into a user-readable string.                  */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_error_message (ViSession instrSession, ViStatus statusCode,
                    ViChar _VI_FAR errMessage[])
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViInt32     i;
    static rszv_tStringValPair statusDescArray[] = {
        {VI_ERROR_PARAMETER1,   "ERROR: Parameter 1 out of range"},
        {VI_ERROR_PARAMETER2,   "ERROR: Parameter 2 out of range"},
        {VI_ERROR_PARAMETER3,   "ERROR: Parameter 3 out of range"},
        {VI_ERROR_PARAMETER4,   "ERROR: Parameter 4 out of range"},
        {VI_ERROR_PARAMETER5,   "ERROR: Parameter 5 out of range"},
        {VI_ERROR_PARAMETER6,   "ERROR: Parameter 6 out of range"},
        {VI_ERROR_PARAMETER7,   "ERROR: Parameter 7 out of range"},
        {VI_ERROR_PARAMETER8,   "ERROR: Parameter 8 out of range"},
        {VI_ERROR_FAIL_ID_QUERY,"ERROR: Identification query failed"},
        {VI_ERROR_INV_RESPONSE, "ERROR: Interpreting instrument response"},
        {VI_ERROR_INSTR_INTERPRETING_RESPONSE, "ERROR: Interpreting the instrument's response"},
        {VI_ERROR_INSTR_PARAMETER9,  "ERROR: Parameter 9 out of range"},
        {VI_ERROR_INSTR_PARAMETER10,  "ERROR: Parameter 10 out of range"},
        {VI_ERROR_INSTR_PARAMETER11,  "ERROR: Parameter 11 out of range"},
        {VI_ERROR_INSTR_PARAMETER12,  "ERROR: Parameter 12 out of range"},
        {VI_ERROR_INSTR_PARAMETER13,  "ERROR: Parameter 13 out of range"},                
        {VI_ERROR_INSTR_PARAMETER14,  "ERROR: Parameter 14 out of range"},
        {VI_ERROR_INSTR_PARAMETER15,  "ERROR: Parameter 15 out of range"},
        {RSZV_WARN_TIME_SWEEP,        "WARNING: For Time Sweep not supported"},
        {RSZV_ERROR_INSTRUMENT_ERROR, "ERROR: Instrument status error"},
        {RSZV_ERROR_NOT_DISPLAYED,    "ERROR: Channel is not displayed"},
        {RSZV_ERROR_OPTION_NOT_AVAILABLE, "ERROR: Option is not available."},
        {VI_NULL, VI_NULL}
    };

    rszv_status = viStatusDesc (instrSession, statusCode, errMessage);
    if (rszv_status == VI_WARN_UNKNOWN_STATUS) {
        for (i = 0; statusDescArray[i].stringName; i++) {
            if (statusDescArray[i].stringVal == statusCode) {
                sprintf (errMessage, "%s", statusDescArray[i].stringName);
                return (VI_SUCCESS);
            }
        }
        sprintf (errMessage, "Unknown Error 0x%x[uw8p0]", statusCode);
        return (VI_WARN_UNKNOWN_STATUS);
    }
    
    rszv_status = VI_SUCCESS;
    return rszv_status;
}

/*===========================================================================*/
/* Function: Revision Query                                                  */
/* Purpose:  This function returns the driver and instrument revisions.      */
/*           If the revision query function is not supported by the          */ 
/*           instrument, this function returns the warning                   */
/*           VI_WARN_NSUP_REV_QUERY.                                         */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_revision_query (ViSession instrSession,
                    ViChar _VI_FAR driverRev[], ViChar _VI_FAR instrRev[])
{
    ViStatus rszv_status = VI_SUCCESS;
    ViUInt32 retCnt = 0;

    CHECKERR( viWrite (instrSession, (ViBuf)"*IDN?\n", 6, &retCnt));
    CHECKERR( viScanf (instrSession, "%*[^,],%*[^,],%*[^,],%[^\r\n]", instrRev));

    sprintf (driverRev, "%s", RSZV_REVISION);

    return rszv_status;
}

/*===========================================================================*/
/* Function: Close                                                           */
/* Purpose:  This function closes the instrument.                            */
/*===========================================================================*/
ViStatus _VI_FUNC rszv_close (ViSession instrSession)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViSession   rmSession;
    ViUInt16    interface = VI_INTF_GPIB;
    rszv_instrRange instrPtr;

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_RM_SESSION, &rmSession));
    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));
    CHECKERR( viGetAttribute (instrSession, VI_ATTR_INTF_TYPE, &interface));

    /* Interface specific operations */
    switch (interface)
        {
        case VI_INTF_ASRL: /* Serial Port. Go to local mode. */
            CHECKERR( viWrite (instrSession, "@LOC\n", 5, VI_NULL));
        break;
#ifdef VI_INTF_TCPIP
        case VI_INTF_TCPIP: /* RSIB Interface. Go to local mode. */
            CHECKERR( viSetAttribute (instrSession, RS_ATTR_RSIB_SRE, 0));
        break;
#endif        
        }

    if (instrPtr != NULL) 
        free (instrPtr);

    rszv_status = viClose (instrSession);
    viClose (rmSession);

    return rszv_status;
}

/*****************************************************************************/
/*= UTILITY ROUTINES (Non-Exportable Functions) =============================*/
/*****************************************************************************/

/*===========================================================================*/
/* Function: Boolean Value Out Of Range - ViBoolean                          */
/* Purpose:  This function checks a Boolean to see if it is equal to VI_TRUE */
/*           or VI_FALSE. If the value is out of range, the return value is  */
/*           VI_TRUE, otherwise the return value is VI_FALSE.                */
/*===========================================================================*/
ViBoolean rszv_invalidViBooleanRange (ViBoolean val)
{
    return (ViBoolean)((val != VI_FALSE && val != VI_TRUE) ? VI_TRUE : VI_FALSE);
}

/*===========================================================================*/
/* Function: Long Signed Integer Value Out Of Range - ViInt32                */
/* Purpose:  This function checks a long signed integer value to see if it   */  
/*           lies between a minimum and maximum value.  If the value is out  */
/*           of range, the return value is VI_TRUE, otherwise the return     */
/*           value is VI_FALSE.                                              */
/*===========================================================================*/
ViBoolean rszv_invalidViInt32Range (ViInt32 val, ViInt32 min, ViInt32 max)
{
    return (ViBoolean)((val < min || val > max) ? VI_TRUE : VI_FALSE);
}

/*===========================================================================*/
/* Function: Real (Double) Value Out Of Range - ViReal64                     */
/* Purpose:  This function checks a real (double) value to see if it lies    */  
/*           between a minimum and maximum value.  If the value is out of    */
/*           range, the return value is VI_TRUE, otherwise the return value  */
/*           is VI_FALSE.                                                    */
/*===========================================================================*/
ViBoolean rszv_invalidViReal64Range (ViReal64 val, ViReal64 min, ViReal64 max)
{
    return (ViBoolean)((val < min || val > max) ? VI_TRUE : VI_FALSE);
}

/*===========================================================================*/
/* Function: Initialize Clean Up                                             */
/* Purpose:  This function is used only by the rszv_init function.  When    */
/*           an error is detected this function is called to close the       */
/*           open resource manager and instrument object sessions and to     */
/*           set the instrSession that is returned from rszv_init to        */
/*           VI_NULL.                                                        */
/*===========================================================================*/
ViStatus rszv_initCleanUp (ViSession openRMSession,
                    ViPSession openInstrSession, ViStatus currentStatus)
{
    viClose (*openInstrSession);
    viClose (openRMSession);
    *openInstrSession = VI_NULL;
    
    return currentStatus;
}

/*===========================================================================*/
/* Function: Default Instrument Setup                                        */
/* Purpose:  This function sends a default setup to the instrument.  This    */
/*           function is called by the rszv_reset operation and by the      */
/*           rszv_init function if the reset option has not been            */
/*           selected.  This function is useful for configuring any          */
/*           instrument settings that are required by the rest of the        */
/*           instrument driver functions such as turning headers ON or OFF   */
/*           or using the long or short form for commands, queries, and data.*/                                    
/*===========================================================================*/
ViStatus rszv_defaultInstrSetup (ViSession instrSession)
{
    ViStatus    rszv_status = VI_SUCCESS,
                tmp_status = VI_SUCCESS;
    ViByte      buffer[BUFFER_SIZE];
    ViInt32     i = 0;
    rszv_instrRange instrPtr;
    
    /* Determine if the structure has been initialized for the current VISA  */
    /* Session and malloc if it has not.                                     */
    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr == NULL) 
        instrPtr = malloc (sizeof (struct rszv_statusDataRanges));

    strcpy (instrPtr -> instrDriverRevision, RSZV_REVISION);
    
    /*----------- Clear Status Structures ---------------------------------*/
    
    CHECKERR( viQueryf (instrSession, "*CLS;*IDN?\n", "%[^\r\n]", buffer));

    while (instTypeArr[i])   /*(i == 7) instTypeArr[i] == VI_NULL*/
        {  
        if (strstr((ViChar *)buffer, instTypeArr[i]))
            {
            instrPtr -> instType = i;
            break;
            }           
        i++;
        }

    instrPtr -> timeout = 10000;
    CHECKERR( viQueryf (instrSession, "*OPT?\n", "%[^\r\n]", buffer));

    instrPtr -> options = 0;
    while (optionsArr[i])   /*(i == 18) instTypeArr[i] == VI_NULL*/
        {  
        if (strstr((ViChar *)buffer, optionsArr[i]))
            instrPtr -> options |= (1<<i);

        i++;
        }

    if (isZVCx(instrPtr -> instType))
        {
        instrPtr -> minFreq = 20.0e3;
        instrPtr -> maxFreq = 8.0e9;
        if (isZVR_B25(instrPtr -> options))
            { /* Option B-25 installed*/
            instrPtr -> minPow = -25.0;
            if (isZVR_B10(instrPtr -> options))
                instrPtr -> maxPow = 17.0;
            else
                instrPtr -> maxPow = 3.0;
            }
        else
            {
            instrPtr -> minPow = -25.0;
            if (isZVR_B10(instrPtr -> options))
                instrPtr -> maxPow = 14.0;
            else
                instrPtr -> maxPow = 0.0;
            }
        }
    else if (isZVM(instrPtr -> instType))
        {
        instrPtr -> minFreq = 10.0e6;
        instrPtr -> maxFreq = 21.0e9;
        instrPtr -> minPow = -20.0;
        instrPtr -> maxPow = 5.0;
        }
    else if (isZVK(instrPtr -> instType))
        {
        instrPtr -> minFreq = 10.0e6;
        instrPtr -> maxFreq = 40.0e9;
        instrPtr -> minPow = -20.0;
        instrPtr -> maxPow = 15.0;
        }
    else
        {
        instrPtr -> maxFreq = 4.0e9;
        if (isZVR_B25(instrPtr -> options))
            {
            instrPtr -> minFreq = 10.0;
            instrPtr -> minPow = -27.0;
            if (isZVR_B10(instrPtr -> options))
                instrPtr -> maxPow = 20.0;
            else
                instrPtr -> maxPow = 7.0;
            }
        else
            {
            instrPtr -> minFreq = 9.0e3;
            instrPtr -> minPow = -27.0;
            if (isZVR_B10(instrPtr -> options))
                instrPtr -> maxPow = 13.0;
            else
                instrPtr -> maxPow = 0.0;
            }
        
        instrPtr -> minPow = -27.0;   /*- Tset set 50 ohms = -25.0 75 ohms = -27.0 -*/
        instrPtr -> maxPow = 0.0;
        }
    
    instrPtr -> externalMeas = VI_FALSE;

    if (isZVR_B25(instrPtr -> options))
        {
        CHECKERR( viQueryf (instrSession, ":INP:BRID?\n", "%[^\r\n]", buffer));
        instrPtr -> externalMeas = (ViBoolean)((strstr((char *)buffer, "BYP")) ? VI_TRUE : VI_FALSE);
        }

    instrPtr -> checkStatus = VI_TRUE;
    instrPtr -> displayChannels = 0;
    
    for (i = 1; i <= 4; i++)
        {
        instrPtr->disp2trace[i-1] = VI_FALSE;
        
        if ((tmp_status = rszv_isChannelDisplayed (instrSession, i)) >= VI_SUCCESS)
            instrPtr -> displayChannels |= (1 << i);
        else
            {
            if (tmp_status != RSZV_ERROR_NOT_DISPLAYED)
                return tmp_status;
            }
        }

    CHECKERR( viSetAttribute (instrSession, VI_ATTR_USER_DATA, (ViUInt32)instrPtr));
    CHECKERR( viWrite (instrSession, (ViBuf)"*SRE 32;*ESE 1;*CLS\n", 20, VI_NULL));
    
    return rszv_status;
}

/*=========================================================================*/
/* Function: Status                                                        */
/* Purpose:  This function reads the Standard Event Register and checks    */
/*           it for error.                                                 */
/*=========================================================================*/
ViStatus rszv_sysStatus (ViSession instrSession)
{
    ViStatus    rszv_status = VI_SUCCESS;
    rszv_instrRange instrPtr;

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));

    if (instrPtr->checkStatus)
        {
        ViByte      buffer[BUFFER_SIZE];
        ViInt32     esr;

        /*--------------- Read the Standard Event Register ------------------*/
        CHECKERR( viQueryf (instrSession, "*ESR?\n", "%[^\r\n]", buffer));

        if (sscanf ((ViChar *)buffer, "%ld", &esr) != 1)
            return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

        /*---------------- Check if any error bit was asserted --------------*/
        rszv_status = ((esr & 0x3C) != 0) ? RSZV_ERROR_INSTRUMENT_ERROR : VI_SUCCESS;
        }

    return rszv_status;
}

/*===========================================================================*/
/* Function: Swap 4 byte                                                     */
/* Purpose:  Byte order for binary transfers depends on MOTOROLA or INTEL    */
/*           formats.                                                        */
/*===========================================================================*/
void rszv_SWAP_32(unsigned char *data, long points)
{
    /* MOTOROLA (byte order 0123) or INTEL (byte order 3210). */
    unsigned int    word = 0x1122;
    unsigned char   *p2word = (unsigned char*)&word;

    if (*p2word == 0x11) /* MOTOROLA format */
    {
       unsigned char    src[4];
       long             *p2data = (long*)data;
       int              idx;

       for (idx = 0; idx < points; idx++, p2data++)
          {
              *((long *)src) = *(p2data);
              ((unsigned char *)(p2data))[0] =  ((unsigned char*)(src))[3];
              ((unsigned char *)(p2data))[1] =  ((unsigned char*)(src))[2];
              ((unsigned char *)(p2data))[2] =  ((unsigned char*)(src))[1];
              ((unsigned char *)(p2data))[3] =  ((unsigned char*)(src))[0];
          }
    }
    
   return;
}

/*===========================================================================*/
/* Function: Swap 8 byte number                                              */
/* Purpose:  Byte order for binary transfers depends on MOTOROLA or INTEL    */
/*           formats.                                                        */
/*===========================================================================*/
void rszv_SWAP_64(unsigned char *data, long points)
{
    /* MOTOROLA (byte order 0123) or INTEL (byte order 3210). */
    unsigned int    word = 0x1122;
    unsigned char   *p2word = (unsigned char*)&word;

    if (*p2word == 0x11) /* MOTOROLA format */
    {
       unsigned char    src[8];
       double           *p2data = (double*)data;
       int              idx;

       for (idx = 0; idx < points; idx++, p2data++)
          {
              *((double *)src) = *(p2data);
              ((unsigned char *)(p2data))[0] =  ((unsigned char*)(src))[7];
              ((unsigned char *)(p2data))[1] =  ((unsigned char*)(src))[6];
              ((unsigned char *)(p2data))[2] =  ((unsigned char*)(src))[5];
              ((unsigned char *)(p2data))[3] =  ((unsigned char*)(src))[4];
              ((unsigned char *)(p2data))[4] =  ((unsigned char*)(src))[3];
              ((unsigned char *)(p2data))[5] =  ((unsigned char*)(src))[2];
              ((unsigned char *)(p2data))[6] =  ((unsigned char*)(src))[1];
              ((unsigned char *)(p2data))[7] =  ((unsigned char*)(src))[0];
          }
    }
    
   return;
}

/*===========================================================================*/
/*  Function: Is Channel Displayed                                           */
/*  Purpose:  This function checks displayed channels. If channel is         */
/*            displayed, VI_SUCCESS is returned, otherwise error             */
/*            RSZV_ERROR_NOT_DISPLAYED is returned                           */
/*===========================================================================*/
ViStatus rszv_isChannelDisplayed (ViSession instrSession, ViInt32 channel)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      rdBuffer[BUFFER_SIZE];
    ViInt32     i, tmpCh;
    ViBoolean   isDisplayed = VI_TRUE;

    CHECKERR( viQueryf (instrSession, ":DISP:FORM?\n", "%[^\r\n]", rdBuffer));

    for (i = 0; i < 6; i++)
        {
        if (strstr((ViChar *)rdBuffer, confResDisplay[i]))
            break;
        }

    if (i == 6)
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    if (i < 3)
        {
        CHECKERR( viQueryf (instrSession, ":INST?\n", "%[^\r\n]", rdBuffer));

        sscanf((ViChar *)rdBuffer, "CHANNEL%ld", &tmpCh);
        isDisplayed = (ViBoolean)((tmpCh == channel) ? VI_TRUE : VI_FALSE);
        if (i != 0 && tmpCh != channel)
            {
            i = (i % 2) ? (i+1) : (i-1);
            isDisplayed = (ViBoolean)((tmpCh == channel) ? VI_TRUE : VI_FALSE);
            }
        }

    return ((isDisplayed) ? rszv_status : RSZV_ERROR_NOT_DISPLAYED);
}

/*===========================================================================*/
/*  Function: Is Channel Displayed (cache version)                           */
/*  Purpose:  This function checks displayed channels. If channel is         */
/*            displayed, VI_SUCCESS is returned, otherwise error             */
/*            RSZV_ERROR_NOT_DISPLAYED is returned                           */
/*===========================================================================*/
ViStatus rszv_isChanDispCache (ViSession instrSession, ViInt32 channel)
{
    ViStatus    rszv_status = VI_SUCCESS;
    rszv_instrRange instrPtr;

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));
    rszv_status = ((instrPtr -> displayChannels) & (1 << channel)) ? rszv_status : RSZV_ERROR_NOT_DISPLAYED;

    return rszv_status;
}

/*===========================================================================*/
/*  Function: Get Sweep Mode                                                 */
/*  Purpose:  This function returns sweep mode of the channel.               */
/*            0 - Frequency Sweep                                            */
/*            1 - Power Sweep                                                */
/*            2 - Time Sweep                                                 */
/*===========================================================================*/
ViStatus rszv_getSweepMode (ViSession instrSession, ViInt32 channel,
                            ViPInt32 sweepMode)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViByte      buffer[BUFFER_SIZE];

    CHECKERR( rszv_isChanDispCache (instrSession, channel));

    CHECKERR( viQueryf (instrSession, ":SENS%ld:FUNC?\n", "%[^\r\n]", channel,
        buffer));

    if (strstr((ViChar *)buffer, "XFR"))
        *sweepMode = RSZV_FREQ_SWEEP;
    else if (strstr((ViChar *)buffer, "XPOW"))
        *sweepMode = RSZV_POWER_SWEEP;
    else if (strstr((ViChar *)buffer, "XTIM"))
        *sweepMode = RSZV_TIME_SWEEP;
    else
        return VI_ERROR_INSTR_INTERPRETING_RESPONSE;

    return rszv_status;
    
}

/*****************************************************************************
 * Function: rszv_WaitForOPC
 * Purpose:  This function waits until the instrument has finished processing 
 *           all pending operations.
 *****************************************************************************/
ViStatus _VI_FUNC rszv_WaitForOPC (ViSession instrSession)
{
    ViStatus    rszv_status = VI_SUCCESS;
    ViUInt16    statusByte;
    ViUInt32    oldTime = 0,
                state = 0;
    rszv_instrRange instrPtr;
    ViUInt16    interface = VI_INTF_GPIB;

    CHECKERR( viGetAttribute (instrSession, VI_ATTR_USER_DATA, &instrPtr));
    CHECKERR( viGetAttribute (instrSession, VI_ATTR_INTF_TYPE, &interface));
    CHECKERR( viGetAttribute (instrSession, VI_ATTR_TMO_VALUE, &oldTime));
    CHECKERR( viSetAttribute (instrSession, VI_ATTR_TMO_VALUE, instrPtr -> timeout));

    /* Interface specific operations */
    switch (interface)
        {
        case VI_INTF_ASRL: /* Serial Interface. */
            if ((rszv_status = viQueryf (instrSession, "*OPC?\n", "%ld", &state)) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_TMO_VALUE, oldTime);
                viDiscardEvents (instrSession, VI_EVENT_SERVICE_REQ, VI_QUEUE);
                }
        break;
        case VI_INTF_GPIB: default: /* GPIB Interface. Default case */
            if ((rszv_status = viEnableEvent (instrSession, VI_EVENT_SERVICE_REQ, VI_QUEUE, VI_NULL)) < 0)
                {
                viDiscardEvents (instrSession, VI_EVENT_SERVICE_REQ, VI_QUEUE);
                return rszv_status;
                }

            CHECKERR( viDiscardEvents (instrSession, VI_EVENT_SERVICE_REQ, VI_QUEUE));

            if ((rszv_status = viPrintf (instrSession, "*OPC\n")) < 0)
                {
                viSetAttribute (instrSession, VI_ATTR_TMO_VALUE, oldTime);
                viDiscardEvents (instrSession, VI_EVENT_SERVICE_REQ, VI_QUEUE);
                return rszv_status;
                }
            /* wait for SRQ */
            CHECKERR( viSetAttribute (instrSession, VI_ATTR_TMO_VALUE, oldTime));

            if ((rszv_status = viWaitOnEvent (instrSession, VI_EVENT_SERVICE_REQ, instrPtr -> timeout, VI_NULL, VI_NULL)) < 0)
                {
                viDiscardEvents (instrSession, VI_EVENT_SERVICE_REQ, VI_QUEUE);
                return rszv_status;
                }

            if ((rszv_status = viDisableEvent (instrSession, VI_EVENT_SERVICE_REQ, VI_QUEUE)) < 0)
                {
                viDiscardEvents (instrSession, VI_EVENT_SERVICE_REQ, VI_QUEUE);
                return rszv_status;
                }

            /* clean up after SRQ */
            if ((rszv_status = viPrintf (instrSession, "*CLS\n")) < 0)
                {
                viDiscardEvents (instrSession, VI_EVENT_SERVICE_REQ, VI_QUEUE);
                return rszv_status;
                }
            if ((rszv_status = viReadSTB (instrSession, &statusByte)) < 0)
                {
                viDiscardEvents (instrSession, VI_EVENT_SERVICE_REQ, VI_QUEUE);
                return rszv_status;
                }
        break;
        }

    return rszv_status;
}

/*****************************************************************************/
/*=== END INSTRUMENT DRIVER SOURCE CODE =====================================*/
/*****************************************************************************/
